knownSchemas = {
    "8FAPq5h6gdV51Vcr": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "XjGNEvQmy6OXtEGF": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": "plain"},
            {"id": 2, "inputType": "plain"},
            {"id": 3, "inputType": "plain"},
            {"id": 7, "inputType": "plain"},
            {"id": 101, "inputType": " "},
            {"id": 102, "inputType": " "},
            {"id": 103, "inputType": " "},
            {"id": 105, "inputType": " "},
        ],
    },
    "1hxNMF9lRQL2xpEA": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "fT3Ltv613pRi4WXr": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "Bright",
                "property": {
                    "unit": "",
                    "min": 11,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputType": "percent"}, {"id": 3, "inputType": ""}],
    },
    "HGZ7aIKOHk99IAoA": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": "plain"},
            {"id": 2, "inputType": " "},
            {"id": 3, "inputType": "percent"},
            {"id": 4, "inputType": " "},
        ],
    },
    "PaYQNcPunOhPeS1X": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 2500,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": "plain"},
            {"id": 2, "inputType": " "},
            {"id": 6, "inputType": ""},
            {"id": 7, "inputType": ""},
            {"id": 8, "inputType": ""},
            {"id": 9, "inputType": ""},
        ],
    },
    "XExf4P4bLRPKA3dw": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报56，实际值为0.056度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 2, "inputType": ""},
            {"id": 3, "inputType": ""},
            {"id": 4, "inputType": ""},
            {"id": 5, "inputType": ""},
            {"id": 6, "inputType": ""},
        ],
    },
    "9p017mRuEwVchApg": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 3, "inputType": "percent"}, {"id": 4, "inputType": ""}],
    },
    "ovvg6eKhVt6sb92l": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "atomizing",
                "name": "喷雾功能",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "1:连续喷雾模式；2:间歇喷雾模式；3:关闭喷雾模式",
            },
            {
                "mode": "rw",
                "code": "moodlighting",
                "name": "氛围灯",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "1:循环模式\n2:选色模式\n3:关闭",
            },
            {
                "mode": "rw",
                "code": "light2",
                "name": "彩灯",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 103, "inputType": ""}],
    },
    "t0TDGBQFFw1AZG1I": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "åŸ€å…³",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "æ¨¥åŸ®",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "äºŽåºŒ",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "å†¡æ±–",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "å½Šå…‰æ¨¥åŸ®æ•°",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "æƒ…æ™¯æ¨¥åŸ®æ•°",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "æ»”å…‰æ¨¥åŸ®",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "çŸ¤çº¡æ¨¥åŸ®",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "ç‚å½Šæ¨¥åŸ®",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "æ–‘æ–“æ¨¥åŸ®",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "2fISFtnNO1j4GWU4": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": "plain"},
            {"id": 2, "inputType": " "},
            {"id": 3, "inputType": "percent"},
            {"id": 4, "inputType": " "},
        ],
    },
    "TtXKwTMwiPpURWLJ": {
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "门帘状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
        "schemaExt": "[]",
    },
    "VDy8SyAxa6Q83vvr": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 2, "inputType": ""},
            {"id": 3, "inputType": ""},
            {"id": 4, "inputType": ""},
            {"id": 5, "inputType": ""},
            {"id": 6, "inputType": ""},
        ],
    },
    "0fHWRe8ULjtmnBNd": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputType": ""},
            {"id": 17, "inputType": ""},
            {"id": 18, "inputType": ""},
            {"id": 19, "inputType": ""},
            {"id": 20, "inputType": ""},
            {"id": 21, "inputType": ""},
            {"id": 22, "inputType": ""},
            {"id": 23, "inputType": ""},
            {"id": 24, "inputType": ""},
            {"id": 25, "inputType": ""},
        ],
    },
    "B6GeaaNA7DTT37Gr": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "CirD9U3eqQ0YKivD": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "IGzCi97RpN2Lf9cu": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": " "},
            {"id": 9, "inputType": " "},
            {"id": 17, "inputType": " "},
        ],
    },
    "mQUhiTg9kwydBFBd": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 3000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 1, "inputType": " "}, {"id": 2, "inputType": " "}],
    },
    "n8iVBAPLFKAAAszH": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputType": ""}],
    },
    "ocNB89IgPygEpdnE": {
        "schema": [
            {
                "mode": "ro",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "上报门窗开关状态",
            },
            {
                "mode": "ro",
                "code": "TamperedAlarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "mcu 上报拆除信息",
            },
            {
                "mode": "ro",
                "code": "Battery",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "mcu 上报电池电量信息",
            },
            {
                "mode": "ro",
                "code": "state",
                "name": "状态",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "上报产品是“休眠”还是“离线”",
            },
        ],
        "schemaExt": "[]",
    },
    "PUyaDrOGMhJfCExd": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "trigger": "direct",
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报56，实际值为0.056度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 2, "inputType": ""},
            {"id": 3, "inputType": ""},
            {"id": 4, "inputType": ""},
            {"id": 5, "inputType": ""},
            {"id": 6, "inputType": ""},
        ],
    },
    "rGglRM3FRxUKqJSA": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "True反转，false正常",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测报警灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取SD卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "SD卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "格式化存储卡",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测图片/视频上传",
                "id": 115,
                "type": "raw",
                "desc": '{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "停止云台转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
                "desc": "direction：方向，共8个;0-上，1-右上，2-右，3-右下，4-下，5-左下，6-左，7-左上",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测报警功能开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "分贝检测功能开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "分贝检测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "分贝报警通道",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
        ],
        "schemaExt": "[]",
    },
    "HPiNfakVX1Z9hWsO": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "JtCDjzmKcUNKEBzO": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_s1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_s2",
                "name": "开关 2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_s3",
                "name": "开关 3",
                "property": {"type": "bool"},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB",
                "property": {"type": "bool"},
                "id": 4,
                "type": "obj",
                "desc": "switch_s4修改为switch_usb1",
            },
        ],
        "schemaExt": "[]",
    },
    "ScIEYTTGvXy1uuWt": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "IAYz2WK1th0cMLmL": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "å¼€å…³",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "ç›®æ ‡æ¸©åº¦",
                "property": {
                    "unit": "â„ƒ",
                    "min": 10,
                    "max": 70,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "å½“å‰æ¸©åº¦",
                "property": {
                    "unit": "â„ƒ",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "æ¨¡å¼",
                "property": {"range": ["0", "1"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "0ï¼šå‘¨ç¨‹åº\n1ï¼šæ‰‹åŠ¨\n",
            },
            {
                "mode": "rw",
                "code": "ECO",
                "name": "ECOæ¨¡å¼",
                "property": {"type": "bool"},
                "iconname": "icon-eco",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "ç«¥é”",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "program",
                "name": "å‘¨ç¨‹åº",
                "id": 101,
                "type": "raw",
                "desc": "å¯¹åº”æ˜ŸæœŸä¸€~æ˜ŸæœŸäº”ã€æ˜ŸæœŸå…­ã€æ˜ŸæœŸæ—¥ï¼Œæ¯å¤©å…­æ®µï¼Œå¯è®¾ç½®æ¯å°æ—¶çš„æ¸©åº¦èŒƒå›´ã€‚æ¸©åº¦èŒƒå›´ä¸º5-35æ‘„æ°åº¦ã€‚",
            },
            {
                "mode": "ro",
                "code": "floorTemp",
                "name": "åœ°æ¿æ¸©åº¦",
                "property": {
                    "unit": "â„ƒ",
                    "min": 0,
                    "max": 198,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "tempSwitch",
                "name": "æ¸©åº¦åˆ‡æ¢",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 103,
                "type": "obj",
                "desc": "0ï¼šå®¤å†…æ¸©åº¦\n1ï¼šåœ°æ¸©",
            },
            {
                "mode": "ro",
                "code": "floortempFunction",
                "name": "åœ°æš–æ¸©åº¦åŠŸèƒ½",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "eyEYwtdx9VhexxLW": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "å¼€å…³",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "å»¶è¿Ÿ",
                "property": {
                    "unit": "ç§’",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "ç”µé‡",
                "property": {
                    "unit": "åº¦",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "ä¸ŠæŠ¥çš„ä¸ºæ”¾å¤§100å€ä¹‹åŽçš„å€¼ï¼Œå³ä¸ŠæŠ¥56ï¼Œå®žé™…å€¼ä¸º0.56åº¦",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "ç”µæµ",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "åŠŸçŽ‡",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "ç”µåŽ‹",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "LED",
                "name": "LEDæŽ§åˆ¶",
                "property": {"type": "bool"},
                "id": 7,
                "type": "obj",
                "desc": "è®¾å¤‡è¾“å‡ºæ—¶å¯é€šè¿‡æ­¤æŽ§ä»¶æŽ§åˆ¶çº¢ç¯äº®ç­",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": " "},
            {"id": 2, "inputType": " "},
            {"id": 7, "inputType": " "},
        ],
    },
    "gGUj6WJeZHA1QBDU": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "开关机控制。\n下发： 发送控制指令给主机，主机依据指令状态进行开关机操作。\n上报：\n当主机使用遥控器关机或者长时间静止进入关机状态后，主机会上报一个关机数据。\n当主机处于关机状态时，通过遥控器或者触摸主机的按键，主机会进入开机状态，主机会上报一个开机数据。",
            },
            {
                "mode": "ro",
                "code": "Error",
                "scope": "fault",
                "name": "故障",
                "property": {
                    "label": ["1", "2", "3", "4", "5", "6", "7", "8"],
                    "type": "bitmap",
                    "maxlen": 8,
                },
                "id": 11,
                "type": "obj",
                "desc": "0 正常；1左边扫异常 ；2右边扫异常 ；3中扫异常 ；4左轮异常；5右轮异常；6风机异常,7 跌落异常 8 主机抬起\n当主机上报后，显示错误代码，当上报0后，清楚显示。",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "剩余电量",
                "property": {
                    "unit": "％",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 14,
                "type": "obj",
                "desc": "机器定时上报电量百分比， 0% - 100%",
            },
            {
                "mode": "rw",
                "code": "open",
                "name": "开启／暂停按钮",
                "property": {"type": "bool"},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "direction",
                "name": "方向",
                "property": {"range": ["1", "2", "3", "4", "5"], "type": "enum"},
                "id": 26,
                "type": "obj",
                "desc": "向前／后／左／右／停",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["0", "1", "2", "3", "4", "5"], "type": "enum"},
                "id": 27,
                "type": "obj",
                "desc": "0: 停止 / 1:自动打扫／2:定点清扫／3:单间打扫／4:沿边打扫／5:自动回充",
            },
            {
                "mode": "rw",
                "code": "fullgo",
                "name": "充满清扫",
                "property": {"type": "bool"},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "3tDXGiKoVhBYg5zn": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 1, "inputType": "plain"}, {"id": 2, "inputType": " "}],
    },
    "W7KCgml5Qn2x5T9v": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": "plain"},
            {"id": 2, "inputType": " "},
            {"id": 3, "inputType": "percent"},
            {"id": 4, "inputType": "percent"},
        ],
    },
    "rrOujSy4Pf1BwEgV": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 3, "inputType": ""}, {"id": 4, "inputType": ""}],
    },
    "laI556gLUEUkFd7T": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": " "},
            {"id": 3, "inputType": " "},
            {"id": 4, "inputType": " "},
        ],
    },
    "6mowdiydpq6sxur9": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "D7Hl3AxFbHDS98iO": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 101, "inputType": ""},
            {"id": 102, "inputType": ""},
            {"id": 103, "inputType": ""},
            {"id": 104, "inputType": ""},
            {"id": 105, "inputType": ""},
        ],
    },
    "DEQevYCSHLnbDube": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "power",
                "name": "power",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "插座开关",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "S",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": " "},
            {"id": 2, "inputType": " "},
            {"id": 3, "inputType": " "},
            {"id": 4, "inputType": " "},
            {"id": 101, "inputType": " "},
            {"id": 102, "inputType": " "},
            {"id": 103, "inputType": ""},
            {"id": 104, "inputType": ""},
            {"id": 105, "inputType": ""},
            {"id": 106, "inputType": ""},
        ],
    },
    "oSQljE9YDqwCwTUA": {
        "schema": [
            {
                "mode": "ro",
                "code": "status",
                "name": "开关状态",
                "property": {"range": ["open", "closed"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "电池电量",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "qxJSyTLEtX5WrzA9": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 3000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "Xg7AvNi7aeRqW3fD": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": "plain"},
            {"id": 2, "inputType": "plain"},
            {"id": 9, "inputType": "plain"},
            {"id": 10, "inputType": "plain"},
            {"id": 17, "inputType": " "},
            {"id": 18, "inputType": ""},
            {"id": 19, "inputType": ""},
            {"id": 20, "inputType": ""},
            {"id": 21, "inputType": ""},
            {"id": 22, "inputType": ""},
            {"id": 23, "inputType": ""},
            {"id": 24, "inputType": ""},
            {"id": 25, "inputType": ""},
        ],
    },
    "lFJaFOExN8tbpDDC": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "VV8ZfLV6G2jY56Lx": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": [{"id": 1, "inputType": " "}, {"id": 11, "inputType": " "}],
    },
    "bX4RxnUXbwNdXWql": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习按键下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习按键下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习按键下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
        ],
        "schemaExt": "[]",
    },
    "jllh2kdbGM0QTdf1": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "switch_power",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "模式",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "temperature",
                "name": "温度",
                "property": {
                    "unit": "",
                    "min": 16,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "fan",
                "name": "风量",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "swing",
                "name": "摆风",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "MZdP3axAfnAlIc4k": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "X54enXVZyZCvH0Ar": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "pmxdTX2JLrSuJM39": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 15,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "低档\高档、ECO、",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "H",
                    "min": 0,
                    "max": 12,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TimeSet",
                "name": "定时功能",
                "property": {
                    "unit": "H",
                    "min": 0,
                    "max": 12,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "wiINnkE8ASfAJSX6": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temperature_c",
                "name": "温度",
                "property": {
                    "unit": "°C",
                    "min": 0,
                    "max": 37,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temperature_f",
                "name": "华氏温度",
                "property": {
                    "unit": "°F",
                    "min": 32,
                    "max": 99,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "exchange",
                "name": "华氏摄氏度切换",
                "property": {"type": "bool"},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "c_temperature",
                "name": "实际摄氏温度",
                "property": {
                    "unit": "°C",
                    "min": 0,
                    "max": 50,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "f_temperature",
                "name": "实际华氏温度",
                "property": {
                    "unit": "°F",
                    "min": 32,
                    "max": 122,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "appoint",
                "name": "预约",
                "property": {
                    "unit": "m",
                    "min": 0,
                    "max": 1440,
                    "range": [
                        0,
                        60,
                        120,
                        180,
                        240,
                        300,
                        360,
                        420,
                        480,
                        540,
                        600,
                        660,
                        720,
                        780,
                        840,
                        900,
                        960,
                        1020,
                        1080,
                        1140,
                        1200,
                        1260,
                        1320,
                        1380,
                        1440,
                    ],
                    "step": 1,
                    "type": "value",
                },
                "id": 7,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "appoint_flag",
                "name": "预约标志位",
                "property": {"type": "bool"},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TimerData",
                "name": "周程序",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "smartTimer",
                "name": "定时",
                "property": {"range": ["holiday", "program"], "type": "enum"},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "YWK0ZiumXZGkb8nj": {
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "窗帘状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
        "schemaExt": "[]",
    },
    "fcLzUB4zWk95xYdk": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            }
        ],
        "schemaExt": "[]",
    },
    "XCEjLKZzUQNuA": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputType": "percent1"},
            {"id": 4, "inputType": "percent1"},
        ],
    },
    "kcwceojngesde5xp": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": " "},
            {"id": 7, "inputType": "plain"},
            {"id": 9, "inputType": " "},
            {"id": 15, "inputType": " "},
            {"id": 17, "inputType": " "},
        ],
    },
    "heeU2AWVxpxfqP6D": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputType": "plain"},
            {"id": 2, "inputType": "plain"},
            {"id": 3, "inputType": "percent"},
        ],
    },
    "U3JAXVgJIsEmht9o": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
        "schemaExt": "[]",
    },
    "MA6aYCAx1vYF4pH7": {
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "窗帘状态",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
        "schemaExt": "[]",
    },
    "Okurono2XLVRV0fB": {
        "schema": [
            {
                "mode": "ro",
                "code": "PIR",
                "name": "Alarm",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "Battery",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "IRHu81DJNbMHKZSv": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "开关机控制。\n下发： 发送控制指令给主机，主机依据指令状态进行开关机操作。\n上报：\n当主机使用遥控器关机或者长时间静止进入关机状态后，主机会上报一个关机数据。\n当主机处于关机状态时，通过遥控器或者触摸主机的按键，主机会进入开机状态，主机会上报一个开机数据。",
            },
            {
                "mode": "ro",
                "code": "Error",
                "scope": "fault",
                "name": "故障",
                "property": {
                    "label": [
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                    ],
                    "type": "bitmap",
                    "maxlen": 14,
                },
                "id": 11,
                "type": "obj",
                "desc": "0:无报警1:主动轮过载 2:前跌落触发 3:左跌落触发 4:右跌落触发 5:机器离地 6:左碰撞卡住 7:右碰撞卡住 8:边刷缠绕 9:电量低于20% 10:尘盒未安装 11:风扇异常 12:滚刷异常 13:电池故障14:水箱未安装",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "剩余电量",
                "property": {
                    "unit": "％",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 14,
                "type": "obj",
                "desc": "机器定时上报电量百分比， 0% - 100%",
            },
            {
                "mode": "rw",
                "code": "power_go",
                "name": "暂停",
                "property": {"type": "bool"},
                "id": 25,
                "type": "obj",
                "desc": "0:暂停 1:工作",
            },
            {
                "mode": "rw",
                "code": "directioncontrol",
                "name": "方向控制",
                "property": {
                    "range": ["forward", "backward", "turnleft", "turnright", "stop"],
                    "type": "enum",
                },
                "id": 26,
                "type": "obj",
                "desc": "前／后／左／右／停",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "idle",
                        "auto",
                        "spot",
                        "single",
                        "wallfollow",
                        "chargego",
                    ],
                    "type": "enum",
                },
                "id": 27,
                "type": "obj",
                "desc": "idle 空闲模式、auto 自动模式 、spot 定点模式、single 单间模式、wallfollow 沿边模式、chargego 回充模式",
            },
            {
                "mode": "ro",
                "code": "Status",
                "name": "状态",
                "property": {
                    "range": [
                        "standby",
                        "working",
                        "fault",
                        "sleep",
                        "workcompleted",
                        "charging",
                        "chargecompleted",
                        "pause",
                    ],
                    "type": "enum",
                },
                "id": 28,
                "type": "obj",
                "desc": "0: 待机 1: 工作中 2: 故障 3: 休眠 4: 工作完成 5: 充电 6: 充电完成 7:暂停",
            },
            {
                "mode": "wr",
                "code": "Find_robot",
                "name": "寻找机器人",
                "property": {"type": "bool"},
                "id": 29,
                "type": "obj",
                "desc": "App触发下发1",
            },
            {
                "mode": "rw",
                "code": "Fan_seepage",
                "name": "清扫强度",
                "property": {"range": ["low", "normal", "high"], "type": "enum"},
                "id": 30,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "2si3Y6O3K2rK9XBr": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "温度调节",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 99,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": -20,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "模式",
                "property": {
                    "range": ["auto", "cold", "hot", "wet", "wind"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "auto：自动模式(feel)；cold：制冷模式；hot：制热模式；wet：除湿模式；wind：送风模式",
            },
            {
                "mode": "rw",
                "code": "windspeed",
                "name": "风量",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-dp_wind",
                "id": 5,
                "type": "obj",
                "desc": "1：高；2：中；3：低；4：自动",
            },
            {
                "mode": "rw",
                "code": "mode_ECO",
                "name": "经济模式",
                "property": {"type": "bool"},
                "iconname": "icon-eco",
                "id": 8,
                "type": "obj",
                "desc": "ECO模式",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "E0",
                        "E1",
                        "E2",
                        "E3",
                        "E4",
                        "E6",
                        "E7",
                        "E8",
                        "E9",
                        "EA",
                        "EF",
                        "EU",
                    ],
                    "type": "bitmap",
                    "maxlen": 12,
                },
                "iconname": "icon-dp_warming",
                "id": 20,
                "type": "obj",
                "desc": "E0:室内外电控板通信故障;E1:室内环境温度传感器故障;E2:室内盘管温度传感器故障;E3:室外盘管温度传感器故障;E4:系统缺氟;E6:室内电机故障或内机风扇不转;E7:室外环境温度传感器故障;E8:室外排气温度传感器故障;E9:室外IPM变频模块故障/压缩机驱动故障;EA:室外电流传感器故障;EF:室外直流风机故障;EU:室外电压传感器故障（电源电压）",
            },
            {
                "mode": "rw",
                "code": "sleep",
                "name": "睡眠模式",
                "property": {"type": "bool"},
                "iconname": "icon-dp_sleep",
                "id": 101,
                "type": "obj",
                "desc": "睡眠（SLEEP）",
            },
            {
                "mode": "rw",
                "code": "turbo",
                "name": "强力模式",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "强力（TURBO）",
            },
            {
                "mode": "rw",
                "code": "cf",
                "name": "温标切换",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "温标切换，True是华氏度，fasle是摄氏度",
            },
            {
                "mode": "rw",
                "code": "wind_up",
                "name": "上下摆风",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "上下摆风",
            },
            {
                "mode": "rw",
                "code": "wind_left",
                "name": "左右摆风",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "左右摆风",
            },
        ],
        "schemaExt": [
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "", "inputType": ""},
        ],
    },
    "xaogr3mrapdrlydm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "åŒå³1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "åŒå³2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "åŒå³3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "åŒå³4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USBåŒå³1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "åŒå³1åè®¡æ¶",
                "property": {
                    "unit": "ç§",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "åŒå³2åè®¡æ¶",
                "property": {
                    "unit": "ç§",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "åŒå³3åè®¡æ¶",
                "property": {
                    "unit": "ç§",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown4",
                "name": "åŒå³4åè®¡æ¶",
                "property": {
                    "unit": "ç§",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1åè®¡æ¶",
                "property": {
                    "unit": "ç§",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "0TmkB4TrA4et14ug": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "RW97vAmAX51GSB1w": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 7, "inputStyle": "", "inputType": " "},
        ],
    },
    "rz3vIjNqRvwnpd8m": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "wtK7fh6RgdfMoSHk": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 6, "inputStyle": "", "inputType": ""}],
    },
    "0rwvmsnhgieurwuf": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "用于wifi遥控器控制",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "bright", "inputType": "percent1"},
            {"id": 4, "inputStyle": "temp", "inputType": "percent"},
            {"id": 101, "inputStyle": "", "inputType": ""},
        ],
    },
    "eZhUXk6MmN7tmCMl": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputStyle": "", "inputType": ""}],
    },
    "FvoFqGMb7aKOHyNH": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "i22freyypqdcirq3": {
        "schema": [
            {
                "mode": "ro",
                "code": "doorcontact_state",
                "name": "门磁",
                "property": {"type": "bool"},
                "iconname": "icon-zanting",
                "id": 1,
                "type": "obj",
                "desc": "【必选】",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "id": 3,
                "type": "obj",
                "desc": "【非必选】",
            },
        ],
        "schemaExt": "[]",
    },
    "mokkxfsfgsgkahao": {
        "schema": [
            {
                "mode": "ro",
                "code": "pir_state",
                "name": "人体感应状态",
                "property": {"range": ["pir"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "【必选】\npir:表示有人经过\noff:表示没人经过（考虑到场景联动需要，加这个枚举）",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "id": 3,
                "type": "obj",
                "desc": "【必选】\n低电量\n中电量\n高电量",
            },
        ],
        "schemaExt": "[]",
    },
    "nfUvI4giCymq2Kco": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "SSJ3FnXaNsrwYYnF": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "排插开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "排插开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "排插开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ZnVGigq6xD5XXgO0": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 11, "inputStyle": "", "inputType": " "},
        ],
    },
    "cimRNeiseS1bvCY3": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "zakhnlpdiu0ycdxn": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "用于wifi遥控器控制",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": "percent1"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "hpaeslvkx4znwzae": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "bright", "inputType": "percent1"},
            {"id": 4, "inputStyle": "temp", "inputType": "percent"},
        ],
    },
    "lmnt3uyltk1xffrt": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "用于wifi遥控器控制",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": "percent1"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "rXPydNxXQS4NuSDm": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
    },
    "bSCvSjRk1eCOVna6": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "基本-状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "True反转，false正常",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测-灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测-定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测-OSS上传",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测",
                "property": {"type": "bool"},
                "iconname": "icon-yundong",
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "分贝检测-总开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "分贝检测-灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "分贝检测-消息上报",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "XFD2nSDKxFlGV5sV": {
        "schema": [
            {
                "mode": "ro",
                "code": "PIR",
                "name": "PIR",
                "property": {"range": ["pir"], "type": "enum"},
                "id": 101,
                "trigger": "direct",
                "type": "obj",
                "desc": "pir 检测",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "mcu 上报电池电量",
            },
        ],
        "schemaExt": "[]",
    },
    "d7ObubEu0zzlr1LH": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "单插开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 7, "inputStyle": "", "inputType": " "},
            {"id": 11, "inputStyle": "", "inputType": " "},
            {"id": 101, "inputStyle": "", "inputType": " "},
        ],
    },
    "vhjenVoes31SPqy9": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputStyle": "", "inputType": ""}],
    },
    "qHLNAzmrRdA9EMXl": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            }
        ],
        "schemaExt": "[]",
    },
    "wd1rx0z7bpl5psqi": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "basic_private",
                "name": "基本-设备休眠",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\nTrue休眠，false不休眠",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": [
            {"id": 110, "inputStyle": "", "inputType": ""},
            {"id": 117, "inputStyle": "", "inputType": ""},
        ],
    },
    "o92blxrzf4ta5bx9": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 9, "inputStyle": "", "inputType": ""},
        ],
    },
    "mja3yagk2wgmkvgf": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": ""},
        ],
    },
    "cfxfmzyltotnocfa": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "用于wifi遥控器控制",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": "percent1"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "rD7uqAAgQOpSA2Rx": {
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "窗帘状态",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
        "schemaExt": "[]",
    },
    "bSXSSFArVKtc4DyC": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 11,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "cya3zxfd38g4qp8d": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 11, "inputStyle": "", "inputType": " "},
        ],
    },
    "3intussjrua4r6rx": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "eEhWmpy1Mq02OBuV": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputStyle": "", "inputType": ""}],
    },
    "gl5fdiv1tc9mkvlp": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "全部开关",
                "property": {"type": "bool"},
                "id": 38,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "qHcpGiXE6DTLVSHb": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "倒计时1",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "倒计时2",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "倒计时3",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "倒计时4",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB倒计时1",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 101, "inputStyle": "", "inputType": ""},
            {"id": 102, "inputStyle": "", "inputType": ""},
            {"id": 103, "inputStyle": "", "inputType": ""},
            {"id": 104, "inputStyle": "", "inputType": ""},
            {"id": 105, "inputStyle": "", "inputType": ""},
        ],
    },
    "jjCFs0rMUp3ZO25u": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "trigger": "direct",
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报56，实际值为0.056度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "h6MjwrnldNTu4kX3": {
        "schema": [
            {
                "mode": "rw",
                "code": "Mode",
                "name": "烧水模式",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6"],
                    "type": "enum",
                },
                "id": 101,
                "type": "obj",
                "desc": "0：奶粉（45℃）\n1：蜜水 （60℃）\n2：绿茶 （85℃）\n3：红茶（除氯3分钟）\n4：煮沸\n5：保温\n6：取消",
            },
            {
                "mode": "rw",
                "code": "SetTem",
                "name": "保温温度设置",
                "property": {
                    "unit": "℃",
                    "min": 30,
                    "max": 95,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "默认70℃",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["0", "1", "2"], "type": "bitmap", "maxlen": 3},
                "id": 104,
                "type": "obj",
                "desc": "0：干烧报警\n1：水壶故障\n2：少水报警\n",
            },
            {
                "mode": "ro",
                "code": "Tem",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "state",
                "name": "当前状态",
                "property": {"range": ["0", "1", "2", "3", "4", "5"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0：未连接\n1：壶座分离\n2：空闲中\n3：加热中\n4：冷却中\n5：保温中\n",
            },
            {
                "mode": "ro",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 240,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "mcu上报",
            },
            {
                "mode": "ro",
                "code": "timer",
                "name": "运行时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 240,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "MlpvUcFGEvlwJmSp": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "plain"},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "37mnhia3pojleqfh": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "over_current_alarm",
                "name": "过流预警",
                "property": {"type": "bool"},
                "id": 7,
                "type": "obj",
                "desc": "当电流处于16.3A和18A之间时，预警，20秒后关闭电源",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "dsmjufemzocc33o0": {
        "schema": [
            {
                "mode": "ro",
                "code": "watersensor_state",
                "name": "水浸检测状态",
                "property": {"range": ["alarm", "normal"], "type": "enum"},
                "iconname": "icon-a_water",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "yg5dcbfu": {
        "schema": [
            {
                "mode": "rw",
                "code": "prm_content",
                "name": "湿度",
                "property": {
                    "unit": "% RH",
                    "min": 0,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "prm_temperature",
                "name": "温度",
                "property": {
                    "unit": "",
                    "min": -2000,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "LLoyXsJzzU6MX81L": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "nhkz9w8oardyykyl": {
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "vnya2spfopsh9lro": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "uuwajnna8zrelzh6": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "开启百分比控制",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "percent_state",
                "name": "开启百分比状态",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_warming",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "readyCal",
                "name": "已完成校准",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "如果未校准  app进度条显示灰色 不可用 已校准显示为可用",
            },
            {
                "mode": "rw",
                "code": "childLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "童锁开关",
            },
            {
                "mode": "rw",
                "code": "backLedSwitch",
                "name": "背光灯开关",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "背光灯开关",
            },
            {
                "mode": "rw",
                "code": "calControl",
                "name": "校准控制",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 104,
                "type": "obj",
                "desc": "校准控制 1 校准开始 2校准结束 3 取消校准",
            },
            {
                "mode": "rw",
                "code": "calTime",
                "name": "校准时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 1000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "校准时间即完全打开到完全关闭的时间\n用户知道时间可以直接设置  不知道时间时需要校准  ",
            },
            {
                "mode": "rw",
                "code": "clear",
                "name": "清除校准数据",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "清除校准数据",
            },
        ],
        "schemaExt": "[]",
    },
    "9ZzvEHiUp4XwJBlS": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "通断开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "mdk",
                "name": "门磁开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 7, "inputStyle": "", "inputType": ""}],
    },
    "ulv4nnue7gqp0rjk": {
        "schema": [
            {
                "mode": "rw",
                "code": "alarm_state",
                "name": "报警器状态",
                "property": {
                    "range": ["light", "voice", "light_voice", "mute"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "【必选】\n1：声音报警\n2：光亮报警\n3：声光报警\n4：报警解除",
            },
            {
                "mode": "rw",
                "code": "alarm_volume",
                "name": "报警音量",
                "property": {
                    "range": ["low", "middle", "high", "mute"],
                    "type": "enum",
                },
                "id": 5,
                "type": "obj",
                "desc": "【非必选】低量/中量/高量/静音",
            },
            {
                "mode": "rw",
                "code": "alarm_time",
                "name": "报警时长",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 7,
                "type": "obj",
                "desc": "【非必选】",
            },
            {
                "mode": "rw",
                "code": "alarm_switch",
                "name": "报警开关",
                "property": {"type": "bool"},
                "id": 13,
                "type": "obj",
                "desc": "可以手动开始报警和手动结束报警",
            },
        ],
        "schemaExt": [{"id": 7, "inputStyle": "", "inputType": ""}],
    },
    "VdDGAJHYWVj62FGM": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "GQxEe5orh45cMgA6": {
        "schema": [
            {
                "mode": "rw",
                "code": "mode",
                "name": "喷雾",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-dp_box",
                "id": 2,
                "type": "obj",
                "desc": "关闭/连续/间断/倒计时",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 4,
                "type": "obj",
                "desc": "显示小时+分钟",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "灯光",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "灯光模式",
                "property": {
                    "range": ["close", "colorful", "white", "color"],
                    "type": "enum",
                },
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "顺序从左到右是关闭/七彩渐变/白光/定色\n其中定色和白光界面可以调节亮度。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光值",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["lack_water"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-yanse",
                "id": 9,
                "type": "obj",
                "desc": "缺水故障",
            },
            {
                "mode": "rw",
                "code": "wuhua",
                "name": "雾量",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "大喷雾/小喷雾",
            },
            {
                "mode": "rw",
                "code": "daojishi",
                "name": "倒计时",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "0-6小时",
            },
        ],
        "schemaExt": [
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
            {"id": 5, "inputStyle": "", "inputType": ""},
            {"id": 6, "inputStyle": "", "inputType": ""},
            {"id": 7, "inputStyle": "", "inputType": ""},
            {"id": 101, "inputStyle": "", "inputType": ""},
            {"id": 102, "inputStyle": "", "inputType": ""},
        ],
    },
    "zblsf6lkbcx19cwf": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": "plain"},
            {"id": 21, "inputStyle": "", "inputType": "plain"},
            {"id": 22, "inputStyle": "", "inputType": "plain"},
            {"id": 23, "inputStyle": "", "inputType": "plain"},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "VEtey9k09k0A1ftr": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "power",
                "name": "power",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "插座开关",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
            {"id": 102, "inputStyle": "", "inputType": ""},
        ],
    },
    "1qhlrytqcpnqmzj7": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_control",
                "name": "开关控制",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间配置",
                "property": {
                    "unit": "s",
                    "min": 10,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "BlackLight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "背光可控",
            },
        ],
        "schemaExt": "[]",
    },
    "mzdqe6ectfdaarqr": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "用于wifi遥控器开关",
            },
        ],
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 3,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 4, "inputStyle": "temp", "inputType": "percent"},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": ""},
        ],
    },
    "vdLB09s3DgZ0s5Gk": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
    },
    "mdxN7u3QJWwifuIR": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "插座",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 11, "inputStyle": "", "inputType": ""},
            {"id": 101, "inputStyle": "", "inputType": ""},
        ],
    },
    "At6C3S6JYzp4ez1T": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "Wall Switch 1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "m3dn9ck8f6qcn4hj": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "用于wifi遥控器控制",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": "percent1"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "5zhtsrznc7nmk6pe": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ZAx1jolkKaiu8JtM": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "switch_power",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "confirm",
                "name": "确认",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "menu",
                "name": "菜单",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "up",
                "name": "上",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "left",
                "name": "左",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "right",
                "name": "右",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "volume_up",
                "name": "音量+",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "volume_down",
                "name": "音量-",
                "property": {"type": "bool"},
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "zero",
                "name": "0",
                "property": {"type": "bool"},
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "one",
                "name": "1",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "two",
                "name": "2",
                "property": {"type": "bool"},
                "id": 112,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "three",
                "name": "3",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "four",
                "name": "4",
                "property": {"type": "bool"},
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "five",
                "name": "5",
                "property": {"type": "bool"},
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "six",
                "name": "6",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "seven",
                "name": "7",
                "property": {"type": "bool"},
                "id": 117,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "eight",
                "name": "8",
                "property": {"type": "bool"},
                "id": 118,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "nine",
                "name": "9",
                "property": {"type": "bool"},
                "id": 119,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "mute",
                "name": "静音",
                "property": {"type": "bool"},
                "id": 120,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "signal",
                "name": "信号源",
                "property": {"type": "bool"},
                "id": 121,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "back",
                "name": "返回",
                "property": {"type": "bool"},
                "id": 122,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "main_page",
                "name": "主页",
                "property": {"type": "bool"},
                "id": 123,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "underline",
                "name": "-/--",
                "property": {"type": "bool"},
                "id": 124,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "volume",
                "name": "音量",
                "property": {"type": "bool"},
                "id": 125,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "h5xA1HckHwEeD1kK": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "ocz3kopwgtw1bfbg": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "namu1lshm4jrx1td": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_filter",
                "id": 39,
                "type": "obj",
                "desc": "0：断电；\n1：通电；\n2：记忆继电器上次状态",
            },
        ],
        "schemaExt": "[]",
    },
    "qge4qpgtumbnuxi6": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "xw0AjeWMmnX0LX7Z": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": "percent"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "8QMq5QyBkZDiA8ME": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "fiuqhs9hunjfciaa": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_location",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "OIQxvj501JCGs6f0": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "AqHUMdcbYzIq1Of4": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "8ckpglK8mI3k5DYP": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 10, "inputStyle": "", "inputType": ""},
        ],
    },
    "ai7xkvpibn4gqbxt": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "PgYTCERTyCGCvajE": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习按键下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习按键下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习按键下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "dmicpclxzikkrh1c": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "n9mt5pvhsis64b1r": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "Wj0vLiKhSxCZoW4w": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "4kheilyfiyazqpda": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 22, "inputStyle": "", "inputType": " "},
            {"id": 23, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "Y2RXPYYDE9L0JRR8": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "WBrr8aqLeGaXv97z": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "yAimpd7WEEwBi5wj": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "mPRaDY6QmEFXOTYm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 7, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "fKaXCEjLKZzUQNuA": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
            {"id": 4, "inputStyle": "", "inputType": "percent1"},
        ],
    },
    "dik6z7of4nailf94": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 22, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "ufX6necFyMftrpih": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 11, "inputStyle": "", "inputType": " "},
        ],
    },
    "0snqC46oHpBMHZ8c": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 3, "inputStyle": "", "inputType": ""}],
    },
    "ptvX5BkawcG0ALkB": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputStyle": "", "inputType": ""}],
    },
    "MOUdSQdkHy5EaV1l": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "guKRJOrrnLmdFqSI": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "Y57x9TGtsWrPjCC8": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "EJmr55ci0szFxP4x": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "BoAR5oJ8NASFBknO": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "plain"},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "KIId874l3357QvWO": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": "percent"},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "AUhqobAr15oIfEaL": {
        "schema": [
            {
                "mode": "ro",
                "code": "alarm",
                "name": "报警",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "0.01v",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "false",
                "name": "取消报警",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "fwmrrplqzjxunvmm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 10, "inputStyle": "", "inputType": ""},
            {"id": 11, "inputStyle": "", "inputType": ""},
        ],
    },
    "zysiizskwm4oib1o": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 15, "inputStyle": "", "inputType": ""},
            {"id": 17, "inputStyle": "", "inputType": ""},
            {"id": 18, "inputStyle": "", "inputType": ""},
            {"id": 19, "inputStyle": "", "inputType": ""},
            {"id": 20, "inputStyle": "", "inputType": ""},
        ],
    },
    "a6fmwrcqhc333lso": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关 2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "倒计时 2",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "倒计时 1",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "s6ohyhbpec9nxwam": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测-灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "基本-红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测-OSS上传",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测-总开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "EQD8hAQw543vzh6O": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关 2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "倒计时2",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "倒计时1",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 6, "inputStyle": "", "inputType": ""}],
    },
    "dYn2mDKmgV2Zz2YX": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "情景灯开关",
                "property": {"type": "bool"},
                "iconname": "icon-deng",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "情景灯模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_puzzle",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 29,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mode",
                "id": 31,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_nav_function",
                "id": 32,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 33,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 34,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 35,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 36,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 29, "inputStyle": "", "inputType": ""}],
    },
    "YydZ2mQ3N5XkChex": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "66mNaBqLdsYhX5lA": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "nlxvjzy1hoeiqsg6": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "用于wifi遥控器控制",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": "percent1"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "aiZa7igM16QciSZm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ON0fHlAaAf7Pt7ja": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "0：断电； 1：通电； 2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 101, "inputStyle": "", "inputType": " "},
            {"id": 102, "inputStyle": "", "inputType": " "},
        ],
    },
    "iapdgbaik9riugyn": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "CHLZe9HQ6QIXujVN": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 11, "inputStyle": "", "inputType": " "},
        ],
    },
    "gDYvLrWhRoqpgHMj": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 3000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "bqkefojbmb8ovvws": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "zY4uzKMEbqCjexxB": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            }
        ],
        "schemaExt": [{"id": 1, "inputStyle": "", "inputType": "plain"}],
    },
    "KhmRHEepuxV8ALfR": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "DYgId0sz6zWlmmYu": {
        "schema": [
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "电量状态",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "0：满电\n1：高\n2：中\n3：低\n4：外电",
            },
            {
                "mode": "rw",
                "code": "Alarmtype",
                "name": "声音类型",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
                "desc": "每一种代表一种声音",
            },
            {
                "mode": "rw",
                "code": "AlarmPeriod",
                "name": "报警时长",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "AlarmSwitch",
                "name": "报警开关",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "koiGhMKwLf2ZP81g": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "KFAHKrKO9XTIV1V4": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "Ks4CzAJZxASSBCGZ": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
    },
    "bh5X1lLgLopti7GD": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "上电后 开或  关 或 记忆断电前状态\n0 上电默认关\n1 上电默认开\n2 上电后执行断电前的状态",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 101, "inputStyle": "", "inputType": " "},
            {"id": 102, "inputStyle": "", "inputType": " "},
        ],
    },
    "3bRKXbBV747xjcKS": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 7, "inputStyle": "", "inputType": " "},
        ],
    },
    "isehgkqn5uqlrorl": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "2EzYjcFvB3W5mXuK": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "aajluzkxkuc7tyt8": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "6l4vhjl3gttstgxj": {
        "schema": [
            {
                "mode": "ro",
                "code": "status",
                "name": "开关状态",
                "property": {"range": ["open", "closed"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "电池电量",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "QONMSadFAkTBFBWx": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "fnxgcsysunpyxkou": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "3wqoo7xfysvsw0io": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "9kkmllwwbzyqltud": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
    },
    "rozAuCvPcosV08Ub": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputStyle": "", "inputType": ""}],
    },
    "na6bptfele0ud6vy": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测-灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测-定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测-OSS上传",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测-总开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "分贝检测-总开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "分贝检测-灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "分贝检测-消息上报",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "mS9jU62HAUqkb1hX": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 2, "inputStyle": "", "inputType": "percent1"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "a0mxFFmru5VGva7D": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "c4vOAfTrLDTEpCQZ": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sensor",
                "name": "红外感应",
                "property": {
                    "range": [
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                        "19",
                        "20",
                        "21",
                        "22",
                        "23",
                        "24",
                        "25",
                        "26",
                        "27",
                        "28",
                    ],
                    "type": "enum",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "plain"},
            {"id": 4, "inputStyle": "", "inputType": "plain"},
            {"id": 101, "inputStyle": "", "inputType": " "},
        ],
    },
    "PGEkBctAbtzKOZng": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "so7sjGbNSkfGrXpn": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "I7N6VHzXnHjWTUgC": {
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "fwxhqpwf": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {"range": ["white"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "QP2puy93gbcNET5G": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "zPvuY6QOEuemAlR6": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "pair_cmd",
                "name": "配对",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "clear_cmd",
                "name": "清除",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "pair_result",
                "name": "配对结果",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "clear_result",
                "name": "清除结果",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 105, "inputStyle": "", "inputType": ""},
        ],
    },
    "bot6weidzztn4m4e": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "FvuqtppKLqZ548sI": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "基本-状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测上报",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "xvsgeeru2i5wsd0y": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-HomeArm",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "urnj8q3elryarlan": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "开关机控制。\n下发： 发送控制指令给主机，主机依据指令状态进行开关机操作。\n上报：\n当主机使用遥控器关机或者长时间静止进入关机状态后，主机会上报一个关机数据。\n当主机处于关机状态时，通过遥控器或者触摸主机的按键，主机会进入开机状态，主机会上报一个开机数据。",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                    ],
                    "type": "bitmap",
                    "maxlen": 14,
                },
                "id": 11,
                "type": "obj",
                "desc": "0:无报警1:主动轮过载 2:前跌落触发 3:左跌落触发 4:右跌落触发 5:机器离地 6:左碰撞卡住 7:右碰撞卡住 8:边刷缠绕 9:电量低于20% 10:尘盒未安装 11:风扇异常 12:滚刷异常 13:电池故障14:水箱未安装",
            },
            {
                "mode": "ro",
                "code": "electricity_left",
                "name": "电量",
                "property": {
                    "unit": "％",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 14,
                "type": "obj",
                "desc": "机器定时上报电量百分比， 0% - 100%",
            },
            {
                "mode": "rw",
                "code": "power_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "id": 25,
                "type": "obj",
                "desc": "0:暂停 1:工作",
            },
            {
                "mode": "rw",
                "code": "direction_control",
                "name": "清扫方向",
                "property": {
                    "range": ["foward", "backward", "turn_left", "turn_right", "stop"],
                    "type": "enum",
                },
                "id": 26,
                "type": "obj",
                "desc": "前／后／左／右／停",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "standby",
                        "smart",
                        "spiral",
                        "single",
                        "wall_follow",
                        "chargego",
                    ],
                    "type": "enum",
                },
                "id": 27,
                "type": "obj",
                "desc": "空闲模式（清除选中）、自动模式、定点模式、单间模式、沿边模式、回充模式",
            },
            {
                "mode": "ro",
                "code": "status",
                "name": "工作状态",
                "property": {
                    "range": [
                        "standby",
                        "working",
                        "fault",
                        "sleep",
                        "workcompleted",
                        "charging",
                        "chargecompleted",
                        "pause",
                    ],
                    "type": "enum",
                },
                "id": 28,
                "type": "obj",
                "desc": "0: 待机 1: 工作中 2: 故障 3: 休眠 4: 工作完成 5: 充电 6: 充电完成 7:暂停",
            },
            {
                "mode": "wr",
                "code": "seek",
                "name": "定位机器人",
                "property": {"type": "bool"},
                "id": 29,
                "type": "obj",
                "desc": "App触发下发1",
            },
            {
                "mode": "rw",
                "code": "suction",
                "name": "清扫强度",
                "property": {"range": ["low", "normal", "high"], "type": "enum"},
                "id": 30,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "voice_switch",
                "name": "静音",
                "property": {"type": "bool"},
                "id": 31,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "clean_area",
                "name": "清扫面积",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 32,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "clean_time",
                "name": "清扫时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 33,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "clean_record",
                "name": "清扫记录",
                "property": {"type": "string", "maxlen": 255},
                "id": 34,
                "type": "obj",
                "desc": '清扫日期YYYYMMDDTTRR + 清扫时长XXX + 清扫面积XXX + 地图IDXXXXX 如： "20180411051102008000020" 代表2018年4月11日05点11分，清扫了20分钟，80平方米 ，id号为20 （假如MCU没有RTC，时间可不上报。记录则默认显示为数据上报时间）',
            },
        ],
        "schemaExt": "[]",
    },
    "di6v3qfv0sqo98bl": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "WindSpeed",
                "name": "风速",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_wind",
                "id": 2,
                "type": "obj",
                "desc": "1-3级风速。可根据产品实际功能进行修改。",
            },
            {
                "mode": "rw",
                "code": "Windmode",
                "name": "风类",
                "property": {"range": ["standard", "sleep", "natural"], "type": "enum"},
                "iconname": "icon-dp_shake",
                "id": 3,
                "type": "obj",
                "desc": "标准风，睡眠风，自然风  开机默认是标准风",
            },
            {
                "mode": "rw",
                "code": "Windleftright",
                "name": "水平风",
                "property": {"type": "bool"},
                "iconname": "icon-dp_loop",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Timer",
                "name": "倒计时",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "0:取消；0.5-7.5小时。可根据产品实际功能进行修改。",
            },
            {
                "mode": "ro",
                "code": "Countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 450,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "xetudvgwjpn1sgra": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "tsg3ba81Ikah9NrR": {
        "schema": [
            {
                "mode": "ro",
                "code": "PIR",
                "name": "PIR",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "pir 检测",
            },
            {
                "mode": "ro",
                "code": "energy",
                "name": "供电形式",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "两种供电形式：电池供电；USB 供电",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "mcu 上报电池电量",
            },
            {
                "mode": "ro",
                "code": "TamperedAlarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "mcu 上报拆除报警",
            },
        ],
        "schemaExt": "[]",
    },
    "XcEjMsAH7cZkAJiX": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": "percent"},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "kJzrAKNnBznojWku": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "be0dlbfuaictfdin": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": "plain"},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 22, "inputStyle": "", "inputType": "plain"},
            {"id": 23, "inputStyle": "", "inputType": "plain"},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "RGFFsVVstB8xf8Uo": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "总开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "总开关",
            },
        ],
        "schemaExt": "[]",
    },
    "0flijpvhn0bu2ojj": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fengli",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "ylxwmwwkfkwhcxsv": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "目标温度",
                "property": {
                    "unit": "",
                    "min": 50,
                    "max": 950,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "",
                    "min": 50,
                    "max": 990,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_unit_convert",
                "name": "温标切换",
                "property": {"range": ["c", "f"], "type": "enum"},
                "id": 19,
                "type": "obj",
                "desc": "需要配合目标温度F和当前温度F使用",
            },
            {
                "mode": "rw",
                "code": "a_key_home",
                "name": "一键离家",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_switch",
                "name": "编程开关",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_mode",
                "name": "编程模式",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "id": 103,
                "type": "obj",
                "desc": "1 为 1天编程 1-7; \n2 为 2天编程 1-5、6-7; \n3 为 3 天编程 1-5、6、7； \n4 为 7 天编程 1、2、3、4、5、6、7",
            },
            {
                "mode": "rw",
                "code": "prog_data_1",
                "name": "编程数据（周一）",
                "id": 104,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_2",
                "name": "编程数据（周二）",
                "id": 105,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_3",
                "name": "编程数据（周三）",
                "id": 106,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_4",
                "name": "编程数据（周四）",
                "id": 107,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_5",
                "name": "编程数据（周五）",
                "id": 108,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_6",
                "name": "编程数据（周六）\t",
                "id": 109,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_7",
                "name": "编程数据（周日）",
                "id": 110,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "restriction",
                "name": "温度设置上下限设置",
                "id": 111,
                "type": "raw",
                "desc": "四个字节：\n00 01：上限\n02 03：下限",
            },
            {
                "mode": "ro",
                "code": "historical_week_set",
                "name": "历史数据协议（周-设定温度）",
                "id": 112,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_month_set",
                "name": "历史数据协议（月-设定温度）",
                "id": 113,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_year_set",
                "name": "历史数据协议（年-设定温度）",
                "id": 114,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_day_now",
                "name": "历史数据协议（日-当前温度）",
                "id": 115,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_week_now",
                "name": "历史数据协议（周-当前温度）",
                "id": 116,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_month_now",
                "name": "历史数据协议（月-当前温度）",
                "id": 117,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_year_now",
                "name": "历史数据协议（年-当前温度）",
                "id": 118,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_day_pow",
                "name": "历史数据协议（日-电机开度）",
                "id": 119,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_week_pow",
                "name": "历史数据协议（周-电机开度）",
                "id": 120,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_month_pow",
                "name": "历史数据协议（月-电机开度）",
                "id": 121,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_year_pow",
                "name": "历史数据协议（年-电机开度）",
                "id": 122,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "historical_day_set",
                "name": "历史数据协议（日-设定温度)",
                "id": 123,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data",
                "name": "编程数据",
                "id": 124,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery_power",
                "scope": "fault",
                "name": "电池电量报警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "id": 125,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "pair_code",
                "name": "设备对码",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 126,
                "type": "obj",
                "desc": "开始对码、对码成功、对码失败、未对码",
            },
            {
                "mode": "rw",
                "code": "set_temp",
                "name": "设置温度（第三方）",
                "property": {
                    "unit": "C",
                    "min": 5,
                    "max": 95,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 127,
                "type": "obj",
                "desc": "目标温度_Alexa专用 DP点",
            },
            {
                "mode": "ro",
                "code": "current_temp",
                "name": "当前温度（第三方）",
                "property": {
                    "unit": "C",
                    "min": 5,
                    "max": 99,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 128,
                "type": "obj",
                "desc": "当前温度_Alexa专用DP点",
            },
            {
                "mode": "ro",
                "code": "program_num",
                "name": "编程段数选择",
                "property": {"range": ["4", "6"], "type": "enum"},
                "id": 129,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ALnnLGkhjB3Bdlwo": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "n731jh0thvakiqov": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": "[]",
    },
    "gQU2utatG2zSHMEu": {
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "开关机控制。\n下发： 发送控制指令给主机，主机依据指令状态进行开关机操作。\n上报：\n当主机使用遥控器关机或者长时间静止进入关机状态后，主机会上报一个关机数据。\n当主机处于关机状态时，通过遥控器或者触摸主机的按键，主机会进入开机状态，主机会上报一个开机数据。",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5", "6", "7", "8"],
                    "type": "bitmap",
                    "maxlen": 8,
                },
                "id": 11,
                "type": "obj",
                "desc": "0 正常；1边扫异常；2中扫异常；3左轮异常；4右轮异常；5垃圾盒异常；6 地检异常；7 碰撞异常；8其它问题\n当主机上报后，显示错误代码，当上报0后，清楚显示。",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": ["smart", "wallfollow", "mop", "chargego", "sprial"],
                    "type": "enum",
                },
                "id": 25,
                "type": "obj",
                "desc": "1:自动清扫\n2:沿边清扫\n3:拖地功能\n4:自动充电\n5:定点清扫（新增项）",
            },
            {
                "mode": "rw",
                "code": "directioncontrol",
                "name": "清扫方向",
                "property": {
                    "range": ["forward", "backward", "turnleft", "turnright", "stop"],
                    "type": "enum",
                },
                "id": 26,
                "type": "obj",
                "desc": "前进，后退，左转，右转，停止。\n默认逻辑：按住方向键下发 前/后/左转/右转，手指抬起下发停止",
            },
            {
                "mode": "rw",
                "code": "suck",
                "name": "吸力选择",
                "property": {"range": ["strong", "normal"], "type": "enum"},
                "id": 27,
                "type": "obj",
                "desc": "0: 强力 / 1:常规",
            },
            {
                "mode": "rw",
                "code": "power_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "id": 33,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Equipment_state",
                "name": "当前状态",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6"],
                    "type": "enum",
                },
                "id": 38,
                "type": "obj",
                "desc": "状态指示\n0：待机中\n1：自动清扫\n2：拖地\n3：沿边清扫\n4：回充中\n5：充电\n6：定点清扫",
            },
            {
                "mode": "ro",
                "code": "electricity_left",
                "name": "剩余电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 39,
                "type": "obj",
                "desc": "剩余电量显示",
            },
            {
                "mode": "ro",
                "code": "Clean_record",
                "name": "清扫记录",
                "property": {"type": "string", "maxlen": 255},
                "id": 40,
                "type": "obj",
                "desc": '清扫时长 +\nXXX\n清扫面积\nxxx\n清扫日期（如有）+\nYYYYMMDD\n清扫时间（如有）+\nhhmm\n如：\n"020080201804110800"\n代表清扫了20分钟，80平方米，清扫日期2018年4月11日，清扫时间8:00\n',
            },
            {
                "mode": "ro",
                "code": "Clean_area",
                "name": "清扫面积",
                "property": {
                    "unit": "㎡",
                    "min": 0,
                    "max": 9999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 41,
                "type": "obj",
                "desc": "MCU上报本次清扫面积，实时更新\n",
            },
            {
                "mode": "ro",
                "code": "Clean_time",
                "name": "清扫时间",
                "property": {
                    "unit": "分",
                    "min": 0,
                    "max": 9999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 42,
                "type": "obj",
                "desc": "MCU上报本次清扫时间，实时更新\n",
            },
            {
                "mode": "rw",
                "code": "volume",
                "name": "音量设置",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 43,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "song",
                "name": "声音开关",
                "property": {"type": "bool"},
                "id": 44,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 25, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": ""},
            {"id": 27, "inputStyle": "", "inputType": ""},
            {"id": 33, "inputStyle": "", "inputType": ""},
            {"id": 38, "inputStyle": "", "inputType": ""},
            {"id": 39, "inputStyle": "", "inputType": ""},
            {"id": 41, "inputStyle": "", "inputType": ""},
            {"id": 42, "inputStyle": "", "inputType": ""},
            {"id": 43, "inputStyle": "", "inputType": ""},
            {"id": 44, "inputStyle": "", "inputType": ""},
        ],
    },
    "U5UspDZNicoNCKO2": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": "[]",
    },
    "1AoxHItVqleAF6vy": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 10, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
            {"id": 18, "inputStyle": "", "inputType": ""},
            {"id": 19, "inputStyle": "", "inputType": ""},
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 24, "inputStyle": "", "inputType": ""},
            {"id": 25, "inputStyle": "", "inputType": ""},
        ],
    },
    "ufq2xwuzd4nb0qdr": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "用在控制wifi遥控器",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": "percent1"},
            {"id": 23, "inputStyle": "", "inputType": "percent"},
            {"id": 26, "inputStyle": "", "inputType": ""},
        ],
    },
    "4D47uCTGNqKBSdHm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "打开窗帘：open；停止：stop；关闭窗帘：close",
            },
            {
                "mode": "rw",
                "code": "state",
                "name": "位置百分比",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "窗帘的开启程度百分比呈现，0%——100%\n全开为：0%；\n全关为：100%",
            },
            {
                "mode": "rw",
                "code": "Reverse",
                "name": "电机反转",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Handpulled",
                "name": "手拉启动",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "00关\n01开",
            },
            {
                "mode": "ro",
                "code": "route",
                "scope": "fault",
                "name": "行程设置提醒",
                "property": {"type": "bool"},
                "id": 109,
                "type": "obj",
                "desc": "行程设置提醒，上报1的时候表示已经进行行程设置。上报0表示没设置。行程设置：需要完整开关窗帘一次。",
            },
        ],
        "schemaExt": "[]",
    },
    "kckzepzcfqvfckzt": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "i6bAFxm8xMj5WmLK": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习按键下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习按键下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习按键下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "hb4CGjpjH3hfWcEY": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "switch_power",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "confirm",
                "name": "确认",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "channel_up",
                "name": "频道+",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "channel_down",
                "name": "频道-",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "menu",
                "name": "菜单",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "up",
                "name": "上",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "left",
                "name": "左",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "right",
                "name": "右",
                "property": {"type": "bool"},
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "volume_up",
                "name": "音量+",
                "property": {"type": "bool"},
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "volume_down",
                "name": "音量-",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "zero",
                "name": "0",
                "property": {"type": "bool"},
                "id": 112,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "one",
                "name": "1",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "two",
                "name": "2",
                "property": {"type": "bool"},
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "three",
                "name": "3",
                "property": {"type": "bool"},
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "four",
                "name": "4",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "five",
                "name": "5",
                "property": {"type": "bool"},
                "id": 117,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "six",
                "name": "6",
                "property": {"type": "bool"},
                "id": 118,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "seven",
                "name": "7",
                "property": {"type": "bool"},
                "id": 119,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "eight",
                "name": "8",
                "property": {"type": "bool"},
                "id": 120,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "nine",
                "name": "9",
                "property": {"type": "bool"},
                "id": 121,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "mute",
                "name": "静音",
                "property": {"type": "bool"},
                "id": 122,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "back",
                "name": "返回",
                "property": {"type": "bool"},
                "id": 123,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "alternate",
                "name": "交替",
                "property": {"type": "bool"},
                "id": 124,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "underline",
                "name": "-/--",
                "property": {"type": "bool"},
                "id": 125,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "volume",
                "name": "音量",
                "property": {"type": "bool"},
                "id": 126,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ja9syyuzz4pbctg3": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "6ASdNwe9IdaewQEl": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "总开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Light",
                "name": "灯光",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "缺水故障",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_time2",
                "id": 13,
                "type": "obj",
                "desc": "0:ON；1：1小时；2：3小时；3：6小时。可根据产品实际功能进行设置。",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 14,
                "type": "obj",
                "desc": "mcu每分钟上报",
            },
            {
                "mode": "rw",
                "code": "dp_mist_grade",
                "name": "雾量",
                "property": {"range": ["small", "big", "off"], "type": "enum"},
                "id": 103,
                "type": "obj",
                "desc": "小喷雾，大喷雾,关闭",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "id": 108,
                "type": "obj",
                "desc": 'Value: ”00112233334455”（长度为 14 的字符串） 00: R 11: G 22: B 3333: H(色调 Hue) 44: S(饱和度 Saturation) 55: V(明度 Value) 示例： {"2700000000ff27"}',
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene1",
                        "scene2",
                        "scene3",
                        "scene4",
                    ],
                    "type": "enum",
                },
                "id": 109,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "lightmode",
                "name": "灯光模式",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 110,
                "type": "obj",
                "desc": "1：七彩循环；2：定色；3：夜灯",
            },
            {
                "mode": "rw",
                "code": "setlight",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "etvtak6npdvd0vg6": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "7PaAvp4fA5nhxIUh": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "jjwg6bVTD6wizPJb": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "4UgcieKnG0gd3jO7": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ylr9R01cMWnMRqEB": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "hgzylixd73iycsnk": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "3HJjEy5GAr6FoURb": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 10, "inputStyle": "", "inputType": ""},
        ],
    },
    "xRLBlgDAoYJP2Edx": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "单插开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": "[]",
    },
    "rsAWAQ7wV3zTzcmG": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
    },
    "zWqOK04ovOjw0Pcw": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "0：断电； 1：通电； 2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 102, "inputStyle": "", "inputType": ""}],
    },
    "x9nmfcaphvbxasgc": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测-灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测-OSS上传",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "ro",
                "code": "doorbell_active",
                "name": "门铃-呼叫",
                "property": {"type": "string", "maxlen": 255},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "wireless_electricity",
                "name": "低功耗-电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 145,
                "type": "obj",
                "desc": "设备主动上报当前电量，电量发生变化时上报。类型为数值型，上报0-100的整数。app会处理成百分比。\n",
            },
            {
                "mode": "ro",
                "code": "wireless_powermode",
                "name": "低功耗-供电方式",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 146,
                "type": "obj",
                "desc": "设备主动上报当前供电状态，供电状态发生变化时上报。0为电池供电状态，1为插电供电状态（或电池充电状态）",
            },
            {
                "mode": "rw",
                "code": "wireless_lowpower",
                "name": "低功耗-低电报警",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 50,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 147,
                "type": "obj",
                "desc": "若电量百分比低于该阈值，则触发报警；App端设置，设备本身无须关心该dp点。",
            },
            {
                "mode": "rw",
                "code": "wireless_awake",
                "name": "低功耗-唤醒状态",
                "property": {"type": "bool"},
                "id": 149,
                "type": "obj",
                "desc": "设备主动上报当前低功耗是否处于唤醒状态。类型为布尔型，True为唤醒状态，false为休眠状态。（设备休眠前上报false，设备唤醒后上报一次True）",
            },
            {
                "mode": "rw",
                "code": "pir_switch",
                "name": "PIR开关及灵敏度",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 152,
                "type": "obj",
                "desc": "0关闭，1灵敏度低，2灵敏度中，3灵敏度高",
            },
            {
                "mode": "ro",
                "code": "doorbell_pic",
                "name": "门铃-抓拍图片",
                "id": 154,
                "type": "raw",
                "desc": "用户按下门铃，抓拍图片并上传",
            },
        ],
        "schemaExt": "[]",
    },
    "lo8wdsdvhchvcbsn": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "XxN1tzvUbJ0eyYMY": {
        "schema": [
            {
                "mode": "ro",
                "code": "status",
                "name": "Smoke Alarm",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "Battery",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "hx5ztlztij4yxxvg": {
        "schema": [
            {
                "mode": "ro",
                "code": "doorcontact_state",
                "name": "门磁",
                "property": {"type": "bool"},
                "iconname": "icon-zanting",
                "id": 1,
                "type": "obj",
                "desc": "【必选】",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "id": 3,
                "type": "obj",
                "desc": "【非必选】",
            },
        ],
        "schemaExt": "[]",
    },
    "dfl0ubhyhaaq5swo": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "XN75LPulKjK0xTEs": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
        "schemaExt": "[]",
    },
    "77wjoyOTO0FzHRVm": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "eo8zo3xdaqa0z7en": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "rgccowxgmkbe22gv": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_filter",
                "id": 39,
                "type": "obj",
                "desc": "0：断电；\n1：通电；\n2：记忆继电器上次状态",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
            {"id": 39, "inputStyle": "", "inputType": " "},
        ],
    },
    "jaqpf2gLCUmF7vXw": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "uitfiejlqezmwdnj": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "EYfNTuTPZln9e4cn": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "rvt5ohucbhs87wbi": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "sMk7hhVsN5KBWbwV": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "ql60m7wvk4ucjdvi": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "5vorxbbzvavwrrqs": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "0：断电； 1：通电； 2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "NlwoInNnQAXJ0UxR": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "pv2zrvn7vsmk0qax": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "FuhWeUBUbJpBgFnT": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "4yAeyq4rvK8AyH34": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "全部开关控制",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "0:全关；1:全开",
            },
        ],
        "schemaExt": [{"id": 5, "inputStyle": "", "inputType": ""}],
    },
    "C49XTQAxAWzQZRNL": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "zmuquaytzuth4gkp": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kwh",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-baojing",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "oCveFaOsA0fyAB4C": {
        "schema": [
            {
                "mode": "ro",
                "code": "WaterLeakage",
                "name": "溢水检测器",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "True - Alarm On\nFALSE - Alarm Off",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "电池电量",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "0x00 - Battery Full\n0x01 - Battery High\n0x02 - Battery Low\n0x03 - Battery Dead",
            },
        ],
        "schemaExt": "[]",
    },
    "41w4nwd6qj85b2gw": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "x24s3v3iv4ehxzup": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "backLedControl",
                "name": "背光开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "aztncqeanw9yj8rt": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "backLedControl",
                "name": "背光开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "sjcgmr9bqubfjeis": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 10, "inputStyle": "", "inputType": " "},
        ],
    },
    "hj0a5c7ckzzexu8l": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": "plain"},
            {"id": 17, "inputStyle": "", "inputType": " "},
            {"id": 18, "inputStyle": "", "inputType": ""},
            {"id": 19, "inputStyle": "", "inputType": ""},
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 24, "inputStyle": "", "inputType": ""},
            {"id": 25, "inputStyle": "", "inputType": ""},
        ],
    },
    "pxphdeyqak8mxld4": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "aswMJsr7svx632Ra": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 10, "inputStyle": "", "inputType": ""},
            {"id": 11, "inputStyle": "", "inputType": ""},
            {"id": 12, "inputStyle": "", "inputType": ""},
            {"id": 15, "inputStyle": "", "inputType": ""},
        ],
    },
    "4nqs33emdwJxpQ8O": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "OzuEOxOGFha5cP2Z": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 11, "inputStyle": "", "inputType": " "},
        ],
    },
    "9ivirni8wemum6cw": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "7by9ERqg60JA8wxA": {
        "schema": [
            {
                "mode": "ro",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "上报门窗开关状态",
            },
            {
                "mode": "ro",
                "code": "Battery",
                "name": "电池电量",
                "property": {
                    "unit": "0.01v",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "mcu 上报电池电量信息，电压值*100，0--4.00v",
            },
        ],
        "schemaExt": "[]",
    },
    "IqSNPuPZIdL4jPz2": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputStyle": "", "inputType": ""}],
    },
    "aa8l2jbp1jmmo99g": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "i6DOIjfTcNwwQNwC": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "pL8QxbxE1AnaIzqG": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "bOimjWqpRgaUUSkY": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "WuAAxvnzt9V5HYLm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报56，实际值为0.056度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
            {"id": 5, "inputStyle": "", "inputType": ""},
            {"id": 6, "inputStyle": "", "inputType": ""},
        ],
    },
    "KAdtK5c9HAC13vvM": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "7e4azRqXX7huIDvh": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "kjbMbjg6MCr5T28o": {
        "schema": [
            {
                "mode": "rw",
                "code": "Switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Temp_set",
                "name": "温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 37,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 99,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Timer",
                "name": "倒计时",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 1440,
                    "scale": 0,
                    "step": 60,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "FAULT",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["E1"], "type": "bitmap", "maxlen": 1},
                "id": 6,
                "type": "obj",
                "desc": "E1:温度探头故障",
            },
        ],
        "schemaExt": "[]",
    },
    "juqfgowpbqcmeg6s": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "开启百分比控制",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "percent_state",
                "name": "开启百分比状态",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_warming",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "readyCal",
                "name": "已完成校准",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "如果未校准  app进度条显示灰色 不可用 已校准显示为可用",
            },
            {
                "mode": "rw",
                "code": "childLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "童锁开关",
            },
            {
                "mode": "rw",
                "code": "backLedSwitch",
                "name": "背光灯开关",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "背光灯开关",
            },
            {
                "mode": "rw",
                "code": "calControl",
                "name": "校准控制",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 104,
                "type": "obj",
                "desc": "校准控制 1 校准开始 2校准结束 3 取消校准",
            },
            {
                "mode": "rw",
                "code": "calTime",
                "name": "校准时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 1000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "校准时间即完全打开到完全关闭的时间\n用户知道时间可以直接设置  不知道时间时需要校准  ",
            },
            {
                "mode": "rw",
                "code": "clear",
                "name": "清除校准数据",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "清除校准数据",
            },
        ],
        "schemaExt": "[]",
    },
    "PBIklxk8MhM0dYND": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "4ukfkbat42snwtd8": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
    },
    "wce69x1jxCwHCepx": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测-灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "基本-红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测-定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测-OSS上传",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "云台-停止转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台-方向控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
                "desc": "direction：方向，共8个;0-上，1-右上，2-右，3-右下，4-下，5-左下，6-左，7-左上",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测-总开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "分贝检测-总开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "分贝检测-灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "分贝检测-消息上报",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "jQRc7Cgy8OVzwSRG": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
            {"id": 4, "inputStyle": "", "inputType": "percent1"},
        ],
    },
    "1yncmcjwgllxw6tm": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "声音侦测报警开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "声音侦测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "检测到声音",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "QIxyB1AOzNxfoLr7": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "inudxjowamz9mnx3": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "mhq7u6zahqfqdxx9": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": "plain"},
            {"id": 17, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "jupECyrdMrUifHd8": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关 2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "bhfhmgmlfjwv31j4": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "whkaccsqldd8vu8b": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "lucrkhabau1cc6if": {
        "schema": [
            {
                "mode": "ro",
                "code": "control",
                "name": "受控信息",
                "property": {"range": ["0x03", "0x04"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "0xBB : 0x03 测试\n0x50 : 0x04 静音\n",
            },
            {
                "mode": "ro",
                "code": "signal_quality",
                "name": "信号质量",
                "property": {
                    "range": ["0x00", "0x01", "0x02", "0x03", "0x04"],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
                "desc": "0x00 表示无信号，即离线\n0x01 表示有1格信号\n0x02 表示有2格信号\n0x03 表示有3格信号\n0x04 表示有4格信号",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "0x00-0xff\n\nelectric_quantity",
            },
            {
                "mode": "ro",
                "code": "PIR",
                "name": "工作状态",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0x00 正常(+低压报警)\n0x01 报警\n0x02 静音\n0x03 测试\n0x04 烟感故障",
            },
        ],
        "schemaExt": "[]",
    },
    "Mb0BSSK0mbO7WBBt": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "wnqaw70uBCsDqgZT": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "minbright_value",
                "name": "最小亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": "plain"},
            {"id": 101, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "A0F6MxOOAt2r3OoJ": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "eba03uybrkaoqmga": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 12,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "6UkFNWLWgioHUAAO": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "4dkZ3phqgLnFKtVy": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
        "schemaExt": "[]",
    },
    "O0YnvNLlDWbJd4KC": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "fZUjBNC3zoZQYd2g": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "ld4GRDxQZZ2NAnk6": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "3rpavvenp7rsxjsb": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_control",
                "name": "开关控制",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开关暂停",
            },
            {
                "mode": "rw",
                "code": "BlackLight",
                "name": "背光",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "背光可控",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 101, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "gvsnpmrhp1ktgawm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kwh",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "过流故障上报",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-baojing",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "9769CzA8RI1wW9AU": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "KVWnN9YQ9DqSmzBt": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "设定温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 450,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "温度设定0-45摄氏度，设置精度1℃，默认15℃。",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": -50,
                    "max": 500,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "显示温度-5-50摄氏度，精度0.1℃",
            },
            {
                "mode": "rw",
                "code": "Timer",
                "name": "倒计时",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "0:取消倒计时；1-12小时倒计时。",
            },
            {
                "mode": "rw",
                "code": "Tempchange",
                "name": "温度转换",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "℃/℉转换，由APP来完成",
            },
        ],
        "schemaExt": "[]",
    },
    "KoAUR5fdtDso34VM": {
        "schema": [
            {
                "mode": "ro",
                "code": "alarm",
                "name": "报警",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lightning",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "0.01v",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dianliang",
                "id": 102,
                "type": "obj",
                "desc": "上报电池电量信息 电压值 *100    0--4.00V",
            },
            {
                "mode": "ro",
                "code": "battery_status",
                "name": "剩余电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dianliang",
                "id": 103,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 102, "inputStyle": "", "inputType": ""},
            {"id": 103, "inputStyle": "", "inputType": ""},
        ],
    },
    "kZbvCqK7zvFiCGl1": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [{"id": 2, "inputStyle": "", "inputType": ""}],
    },
    "2EmW535HvNFa4F9W": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            }
        ],
        "schemaExt": "[]",
    },
    "in5psqrrnouof32o": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "PzxHfpklYcBQOEQo": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "喷雾开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Light",
                "name": "灯光开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "缺水故障",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 14,
                "type": "obj",
                "desc": "数值范围：0-360, 间距：1, 倍数：0, 单位：分钟",
            },
            {
                "mode": "rw",
                "code": "dp_mist_time",
                "name": "喷雾倒计时",
                "property": {"range": ["1h", "3h", "6h", "ON"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "工作1小时，工作3小时；工作6小时；ON:取消",
            },
            {
                "mode": "rw",
                "code": "dp_mist_grade",
                "name": "雾量设置",
                "property": {"range": ["small", "big"], "type": "enum"},
                "id": 103,
                "type": "obj",
                "desc": "小喷雾，大喷雾",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "id": 108,
                "type": "obj",
                "desc": 'Value: ”00112233334455”（长度为 14 的字符串） 00: R 11: G 22: B 3333: H(色调 Hue) 44: S(饱和度 Saturation) 55: V(明度 Value) 示例： {"2700000000ff27"}',
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene1",
                        "scene2",
                        "scene3",
                        "scene4",
                    ],
                    "type": "enum",
                },
                "id": 109,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "lightmode",
                "name": "灯光模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 110,
                "type": "obj",
                "desc": "1：七彩循环；2：定色",
            },
        ],
        "schemaExt": "[]",
    },
    "8UhAGZyCrYqYAcEc": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "tuh2eatk4hsq336s": {
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "窗帘状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
        "schemaExt": "[]",
    },
    "foitasaq52xwyqmt": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "目标温度",
                "property": {
                    "unit": "°C",
                    "min": 50,
                    "max": 950,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "°C",
                    "min": 0,
                    "max": 990,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fangzi",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "a_key_home",
                "name": "一键离家",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_switch",
                "name": "编程开关",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_mode",
                "name": "7 天",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7"],
                    "type": "enum",
                },
                "id": 103,
                "type": "obj",
                "desc": "1 为 1天编程 1-7; 2 为 2天编程 1-5、6-7; 3 为 3 天编程 1-5、6、7； 4 为 7 天编程 1、2、3、4、5、6、7",
            },
            {
                "mode": "rw",
                "code": "prog_data_1",
                "name": "编程数据（周一）",
                "id": 104,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_2",
                "name": "编程数据（周二）",
                "id": 105,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_3",
                "name": "编程数据（周三）",
                "id": 106,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_4",
                "name": "编程数据（周四）",
                "id": 107,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_5",
                "name": "编程数据（周五）",
                "id": 108,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_6",
                "name": "编程数据（周六）",
                "id": 109,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data_7",
                "name": "编程数据（周日）",
                "id": 110,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "restriction",
                "name": "温度设置上下限设置",
                "id": 111,
                "type": "raw",
                "desc": "四个字节： 00 01：上限 02 03：下限",
            },
            {
                "mode": "rw",
                "code": "historical_week_set",
                "name": "历史数据协议（周-设定温度）",
                "id": 112,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_month_set",
                "name": "历史数据协议（月-设定温度）",
                "id": 113,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_year_set",
                "name": "历史数据协议（年-设定温度）",
                "id": 114,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_day_now",
                "name": "历史数据协议（日-当前温度）",
                "id": 115,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_week_now",
                "name": "历史数据协议（周-当前温度）",
                "id": 116,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_month_now",
                "name": "历史数据协议（月-当前温度）",
                "id": 117,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_year_now",
                "name": "历史数据协议（年-当前温度）",
                "id": 118,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_day_pow",
                "name": "历史数据协议（日-电机开度）",
                "id": 119,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_week_pow",
                "name": "历史数据协议（周-电机开度）",
                "id": 120,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_month_pow",
                "name": "历史数据协议（月-电机开度）",
                "id": 121,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_year_pow",
                "name": "历史数据协议（年-电机开度）",
                "id": 122,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "historical_day_set",
                "name": "历史数据协议（日-设定温度)",
                "id": 123,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "prog_data",
                "name": "\t编程数据",
                "id": 124,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery_power",
                "scope": "fault",
                "name": "电池电量报警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "id": 125,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "pair_code",
                "name": "设备对码",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 126,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp",
                "name": "设置温度（第三方）",
                "property": {
                    "unit": "",
                    "min": 5,
                    "max": 95,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 127,
                "type": "obj",
                "desc": "目标温度_Alexa专用 DP点",
            },
            {
                "mode": "rw",
                "code": "current_temp",
                "name": "当前温度（第三方）",
                "property": {
                    "unit": "",
                    "min": 5,
                    "max": 95,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 128,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "program_num",
                "name": "编程段数选择",
                "property": {"range": ["4", "6"], "type": "enum"},
                "id": 129,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_unit_convert",
                "name": "温标切换",
                "property": {"range": ["c", "f"], "type": "enum"},
                "id": 130,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "time",
                "name": "时间校准",
                "id": 131,
                "type": "raw",
                "desc": "用户可以选择是否自动校准时间，如果选择了开启，则根据网关下发的时间进行显示，如果设置关闭，则用户需要选择一个时间进行保存，这个时间会下发到网关，作为整个网关系统的时间。修改时间精确到分， 显示精确到秒。\n",
            },
            {
                "mode": "rw",
                "code": "tem_alibration_c",
                "name": "温度校准功能（摄氏度）",
                "property": {
                    "unit": "℃",
                    "min": -6,
                    "max": 6,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 132,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "time_auto",
                "name": "自动校准时间",
                "property": {"type": "bool"},
                "id": 133,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "tem_alibration_f",
                "name": "温度校准功能（华氏度）",
                "property": {
                    "unit": "℉",
                    "min": -40,
                    "max": 40,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "error_",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["sensor_error"], "type": "bitmap", "maxlen": 1},
                "id": 135,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key",
                "name": "增减按键锁开启/关闭",
                "property": {"type": "bool"},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "window",
                "name": "开窗开启/关闭",
                "property": {"type": "bool"},
                "id": 137,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "antifreeze",
                "name": "防冻开启/关闭",
                "property": {"type": "bool"},
                "id": 138,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "waterproof_scale",
                "name": "防水垢开启/关闭",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "yW1oJg0y0PIgywO1": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "B0eP8qYAdpUo4yR9": {
        "schema": [
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["AH", "AL", "Er"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "高温报警/地温报警/探头异常报警",
            },
            {
                "mode": "rw",
                "code": "CF",
                "name": "温标切换",
                "property": {"range": ["C", "F"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "CA",
                "name": "温度校准",
                "property": {
                    "unit": "",
                    "min": -150,
                    "max": 150,
                    "scale": 1,
                    "step": 10,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CurrentTempC",
                "name": "当前温度C",
                "property": {
                    "unit": "℃",
                    "min": -500,
                    "max": 1200,
                    "scale": 1,
                    "step": 10,
                    "type": "value",
                },
                "id": 104,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "SetTemp",
                "name": "温度设置",
                "property": {
                    "unit": "",
                    "min": -400,
                    "max": 2120,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "PT",
                "name": "制冷延时",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "AH",
                "name": "高温报警",
                "property": {
                    "unit": "",
                    "min": -400,
                    "max": 2120,
                    "scale": 1,
                    "step": 10,
                    "type": "value",
                },
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "AL",
                "name": "低温报警",
                "property": {
                    "unit": "",
                    "min": -400,
                    "max": 2120,
                    "scale": 1,
                    "step": 10,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "hot",
                "name": "高温报警",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cold",
                "name": "低温报警",
                "property": {"type": "bool"},
                "id": 112,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp",
                "name": "温度异常",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "OutputState",
                "name": "输出状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 115,
                "type": "obj",
                "desc": "0：制冷状态，无输出\n1：制冷状态，有输出\n2：加热状态，无输出\n3：加热状态，有输出",
            },
            {
                "mode": "rw",
                "code": "CurrentTempF",
                "name": "当前温度F",
                "property": {
                    "unit": "℉",
                    "min": -500,
                    "max": 2480,
                    "scale": 1,
                    "step": 10,
                    "type": "value",
                },
                "id": 116,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "HD",
                "name": "加热回差温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 300,
                    "scale": 1,
                    "step": 10,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "CD",
                "name": "制冷回差温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 300,
                    "scale": 1,
                    "step": 10,
                    "type": "value",
                },
                "id": 118,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "pyhfiskiif5lzwax": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "op2lzjcj7fdfhid8": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_spray",
                "name": "喷雾开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["large", "interval", "small"], "type": "enum"},
                "iconname": "icon-dp_box",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {"range": ["2", "4", "cancel"], "type": "enum"},
                "iconname": "icon-dp_time2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "灯光",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "灯光模式",
                "property": {"range": ["colour", "colourful1"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光值",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["lack_water"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-yanse",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 5, "inputStyle": "", "inputType": ""},
            {"id": 6, "inputStyle": "", "inputType": ""},
        ],
    },
    "6adns63oboy4mdcp": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "jzkpltrhwqyzoc33": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "白光亮度",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "白光色温",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "vv5gy6pg8jpuqvjl": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": "plain"},
            {"id": 10, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "wKIbgibLBL7vdEA3": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "pkf6ggaaofgot9bk": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value_1",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "brightness_min_1",
                "name": "最小亮度",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "led_type_1",
                "name": "光源类型",
                "property": {
                    "range": ["LED", "incandescent", "halogen"],
                    "type": "enum",
                },
                "id": 4,
                "type": "obj",
                "desc": "1:LED \n2.白炽灯\n3.节能灯\n4.其他",
            },
        ],
        "schemaExt": "[]",
    },
    "fTNOwUWf3JxHmWpQ": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": [{"complexType": "", "id": 2, "inputStyle": "", "inputType": ""}],
    },
    "apxmk1cpaagjxvz2": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "dKJ5A2k0BhVT27Jg": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "arslxyjlf2gzlfqv": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "FtcUIyWXINfX3BL6": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "iQG3q7IECnbkHVms": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "全部开启或关闭",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "0:全关；1:全开",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 5, "inputStyle": "", "inputType": " "},
        ],
    },
    "jyqwiknzooocjhqc": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "声音侦测报警开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "声音侦测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "检测到声音",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "NRc2AbstIKafzROP": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 1220,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "目标温度设置范围=设置温度最低下限值~设置温度最高上限值",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {
                    "range": ["Manual", "Program", "Holiday", "TempProg"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "手动、编程、离家、临时手动",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 5,
                },
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "1:设备故障\n2:内置传感器报警\n3.外置传感器报警\n4.低温保护报警\n5.高温保护报警",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "华氏度摄氏度",
                "property": {"type": "bool"},
                "iconname": "icon-a_function_fahrenhei",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Heating_state",
                "name": "加热",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Ext_temperature",
                "name": "外置温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Days_Holiday",
                "name": "离家模式-天数",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-p7",
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Settemp_Holiday",
                "name": "离家模式-设置温度",
                "property": {
                    "unit": "",
                    "min": 5,
                    "max": 122,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Hightemp_Protect",
                "name": "高温保护功能",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "LowTemp_Protect",
                "name": "低温保护功能",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ext_temp_display",
                "name": "外置温度显示功能",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "外置温度是否显示",
            },
            {
                "mode": "rw",
                "code": "room_temp_compensate",
                "name": "温度补偿",
                "property": {
                    "unit": "",
                    "min": -180,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-ziyouchengxu",
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "room_temp_zone",
                "name": "室内温度回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "low_temp_limit",
                "name": "低温保护温度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp_max",
                "name": "设置温度最高上限",
                "property": {
                    "unit": "℃",
                    "min": 20,
                    "max": 158,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp_min",
                "name": "设置温度最低下限",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 59,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "power_state",
                "name": "上电开关机状态",
                "property": {"range": ["keep", "off", "on"], "type": "enum"},
                "id": 117,
                "type": "obj",
                "desc": "keep:保持前一次状态\noff:上电设备关机\non:上电设备开机",
            },
            {
                "mode": "rw",
                "code": "Prog_Type",
                "name": "编程类型",
                "property": {"range": ["2days", "1days", "0days"], "type": "enum"},
                "id": 118,
                "type": "obj",
                "desc": "2days:5+2 5个工作日2个休息日\n1days:6+1 6个工作日1个休息日\n0days:取消编程",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday1",
                "name": "编程-工作日参数1",
                "id": 119,
                "type": "raw",
                "desc": "工作日参数1:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第3时段分钟，第三字节为第3时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday2",
                "name": "编程-工作日参数2",
                "id": 120,
                "type": "raw",
                "desc": "工作日参数2:\n第一字节为第4时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第4时段分钟，第三字节为第4时段设置温度。第四字节为第5时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第5时段分钟，第六字节为第5时段设置温度。第七字节为第6时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第6时段分钟，第三字节为第6时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday1",
                "name": "编程-休息日参数1",
                "id": 121,
                "type": "raw",
                "desc": "休息日参数1:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第3时段分钟，第三字节为第3时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday2",
                "name": "编程-休息日参数2",
                "id": 122,
                "type": "raw",
                "desc": "休息日参数2:\n第一字节为第4时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第4时段分钟，第三字节为第4时段设置温度。第四字节为第5时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第5时段分钟，第六字节为第5时段设置温度。第七字节为第6时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第6时段分钟，第三字节为第6时段设置温度。",
            },
        ],
        "schemaExt": "[]",
    },
    "3i480z6ds8l9rlda": {
        "schema": [
            {
                "mode": "ro",
                "code": "pir_state",
                "name": "人体感应状态",
                "property": {"range": ["pir"], "type": "enum"},
                "iconname": "icon-yundong",
                "id": 1,
                "type": "obj",
                "desc": "【必选】1：有人触发\n",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
                "desc": "【非必选】\n低电量\n中电量\n高电量",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dianliang",
                "id": 4,
                "type": "obj",
                "desc": "【非必选】",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "iconname": "icon-a_selected",
                "id": 5,
                "type": "obj",
                "desc": "【非必选】如果硬件支持拆除检测，当发生拆除事件时，触发报警",
            },
        ],
        "schemaExt": "[]",
    },
    "mGOAAG11xWJqpQXm": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "jtCB35qnMWxHuSL8": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "RN9iPCasMEiFi3RU": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "8urvykaz4giwsbkz": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kwh",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报1000，实际值为1度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_curve",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_flower",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "bb1gl4lxrapnt4vo": {
        "schema": [
            {
                "mode": "ro",
                "code": "temp_value",
                "name": "当前温度",
                "property": {
                    "unit": "",
                    "min": -400,
                    "max": 2000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_celsius",
                "id": 1,
                "type": "obj",
                "desc": "【必选】产品为温度传感器或温湿度传感器时该功能必选",
            },
            {
                "mode": "ro",
                "code": "humidity_value",
                "name": "当前湿度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-icon-percent",
                "id": 2,
                "type": "obj",
                "desc": "【必选】产品为湿度传感器或温湿度传感器时该功能必选",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
                "desc": "【非必选】\n低电量\n中电量\n高电量",
            },
        ],
        "schemaExt": "[]",
    },
    "uyvxoqhmac1dhvlm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "bkc7r4doh4k8joso": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "shdbwbr7mjjdwu1f": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ufmpluqx4zcaiaoa": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 6, "inputStyle": "", "inputType": " "},
            {"id": 7, "inputStyle": "", "inputType": "percent"},
            {"id": 13, "inputStyle": "", "inputType": " "},
        ],
    },
    "qspawqbvse9z3hyu": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "1zhgmbekichfveta": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "zrryhdmszfg6xc6s": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "0：断电； 1：通电； 2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "iyqmKowwmGNuYqkV": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 11,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "26iRceKhfrzuQLTf": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "Switch",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "开关",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "Work_mode",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "Bright_value",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "亮度",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "Temp_value",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "冷暖",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "Colour_data",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "彩光模式数",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "Scene_data",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "情景模式数",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "Soft",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "柔光模式",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "Colours",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "缤纷模式",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "Colorful",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "炫彩模式",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "Gorgeous",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "斑斓模式",
            },
        ],
        "schemaExt": "[]",
    },
    "oylqwkwmjbwqknwv": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "情景灯开关",
                "property": {"type": "bool"},
                "iconname": "icon-deng",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "情景灯模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_puzzle",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mode",
                "id": 31,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_nav_function",
                "id": 32,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 33,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 34,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 35,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 36,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_led",
                "name": "情景灯倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 37,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 27, "inputStyle": "", "inputType": " "},
            {"id": 28, "inputStyle": "", "inputType": " "},
            {"id": 29, "inputStyle": "", "inputType": " "},
            {"id": 30, "inputStyle": "", "inputType": " "},
            {"id": 37, "inputStyle": "", "inputType": " "},
        ],
    },
    "xz0eqflm5riksgqt": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_ratio",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "色温值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "milight",
                "name": "鑫彩翼透传",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": "plain"},
            {"id": 22, "inputStyle": "", "inputType": "plain"},
            {"id": 23, "inputStyle": "", "inputType": "plain"},
            {"id": 26, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "fagmnmgohirnkxyg": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "xgahfdephq2jnhav": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "True反转，false正常",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测报警灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取SD卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "SD卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "格式化存储卡",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_record",
                "name": "移动侦测录像",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "True打开，false关闭\n摄像头本地功能：功能打开的时候，只有检测到移动才开始录像。",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "定时移动侦测时间设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
                "desc": '{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "停止云台转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
                "desc": "direction：方向，共8个;0-上，1-右上，2-右，3-右下，4-下，5-左下，6-左，7-左上",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "定时移动侦测功能开关",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "移动录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "1事件录影，2全时录影 摄像头本地保存录像到SD卡的模式 事件录影：摄像头检测到物体移动再录制录像 全时录影：不间断录制24/7录像",
            },
            {
                "mode": "rw",
                "code": "motion_tracking",
                "name": "人体移动追踪",
                "property": {"type": "bool"},
                "id": 161,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "an3xefw05o9oi2km": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yinliang",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": "plain"},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 22, "inputStyle": "", "inputType": "plain"},
            {"id": 23, "inputStyle": "", "inputType": "plain"},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "FEn1xRPbTaBjyjbb": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "5q59q6kpkuahxnmk": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ai6HtccKFIw3dxo3": {
        "schema": [
            {
                "mode": "rw",
                "code": "power_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "1：启动\n2、停止",
            },
            {
                "mode": "ro",
                "code": "cleanarea",
                "name": "清洁面积",
                "property": {
                    "unit": "m",
                    "min": 0,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_house",
                "id": 14,
                "type": "obj",
                "desc": "按实际情况输入",
            },
            {
                "mode": "rw",
                "code": "remote",
                "name": "方向控制",
                "property": {
                    "range": ["up", "down", "left", "right", "stop"],
                    "type": "enum",
                },
                "id": 101,
                "type": "obj",
                "desc": "上、下、左、右、停\n\n用户按下即发上下左右，松手就发停止",
            },
            {
                "mode": "ro",
                "code": "working_condition",
                "name": "工作状态",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
                "desc": "休眠、待机、清扫中、清扫已完成、回充、充电中、直充中、充电已完成、休眠中\n",
            },
            {
                "mode": "rw",
                "code": "mode_work",
                "name": "工作模式",
                "property": {"range": ["0", "1", "2", "3", "4", "5"], "type": "enum"},
                "id": 103,
                "type": "obj",
                "desc": "无模式、自动清扫、定点清扫、沿边清扫、自动回充、遥控清扫\n",
            },
            {
                "mode": "ro",
                "code": "Electric_quantity",
                "name": "剩余电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "0——100%，低于20%时显示红色\n",
            },
            {
                "mode": "ro",
                "code": "fault_",
                "name": "故障告警",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                    ],
                    "type": "enum",
                },
                "id": 105,
                "type": "obj",
                "desc": "ERROR_00    无故障\nERROR_01    左轮异常\nERROR_02    右轮异常\nERROR_03    左边扫异常\nERROR_04    右边扫异常\nERROR_05    中扫异常\nERROR_06    地检异常\nERROR_07    前撞异常\nERROR_08    被困\nERROR_09    电量过低\nERROR_10    尘盒缺失\nERROR_11    找不到充电座\nERROR_12    左轮抬起\nERROR_13    右轮抬起",
            },
            {
                "mode": "rw",
                "code": "Suction_regulation",
                "name": "吸力调节",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "强劲、标准、安静",
            },
            {
                "mode": "ro",
                "code": "clear_time",
                "name": "清扫时间显示",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 432000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "last_time",
                "name": "【无用】距离上一次清扫时间显示",
                "id": 108,
                "type": "raw",
                "desc": "两个字节：\n高位为天数；\n低位为小时；",
            },
            {
                "mode": "rw",
                "code": "timer",
                "name": "【无用】定时设置",
                "id": 109,
                "type": "raw",
                "desc": "一共4个字节。最高位是定时一次（0），还是循环（1），高位是定时功能的开关、中位是小时、低位是分钟",
            },
            {
                "mode": "ro",
                "code": "filter",
                "name": "滤网寿命",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "reset_filter",
                "name": "滤网重置",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "roll_brush",
                "name": "中刷寿命",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 112,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "reset_roll_brush",
                "name": "中刷重置",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "edge_brush",
                "name": "边刷寿命",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "reset_edge_brush",
                "name": "边刷重置",
                "property": {"type": "bool"},
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "seek",
                "name": "寻找机器",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "voice_switch",
                "name": "声音开关",
                "property": {"type": "bool"},
                "id": 117,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "clean_record",
                "name": "清扫记录",
                "property": {"type": "string", "maxlen": 255},
                "id": 118,
                "type": "obj",
                "desc": '清扫日期YYYYMMDDTTRR + 清扫时长XXX + 清扫面积XXX + 地图IDXXXXX\n如： "20180411051102008000020" \n代表2018年4月11日05点11分，清扫了20分钟，80平方米 ，id号为20\n（假如MCU没有RTC，时间可不上报。记录则默认显示为数据上报时间）',
            },
        ],
        "schemaExt": [
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 101, "inputStyle": "", "inputType": " "},
            {"id": 103, "inputStyle": "", "inputType": " "},
            {"id": 106, "inputStyle": "", "inputType": " "},
            {"id": 111, "inputStyle": "", "inputType": " "},
            {"id": 113, "inputStyle": "", "inputType": " "},
            {"id": 115, "inputStyle": "", "inputType": " "},
            {"id": 116, "inputStyle": "", "inputType": " "},
            {"id": 117, "inputStyle": "", "inputType": " "},
        ],
    },
    "AAi3kHZ5Tgmo64Hq": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": ""},
            {"id": 2, "inputStyle": "", "inputType": ""},
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "mxaqBsFZ9cYkACt8": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 10, "inputStyle": "", "inputType": ""},
        ],
    },
    "lxhfd50q": {
        "schema": [
            {
                "mode": "rw",
                "code": "prm_content",
                "name": "湿度",
                "property": {
                    "unit": "% RH",
                    "min": 0,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "prm_temperature",
                "name": "温度",
                "property": {
                    "unit": "",
                    "min": -2000,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "trp7wywx3yx8yild": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "GojD1boBP9O2syIi": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "4VYYy1bnOg4oYj4u": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "lXOzf4C0SnHRyOIW": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "i6qfpkwbndfavbzm": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "ICa4UR7oVhxpClcg": {
        "schema": [
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {"range": ["High", "sleep"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "高效模式；睡眠模式",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["fullwater"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "水满提示",
            },
            {
                "mode": "rw",
                "code": "Purify",
                "name": "净化",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "dehum",
                "name": "除湿",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "filterreplace",
                "name": "滤网更换",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "True:滤网更换提示",
            },
        ],
        "schemaExt": "[]",
    },
    "oAhphrO8qMU8RU7Y": {
        "schema": [
            {
                "mode": "ro",
                "code": "Mouse",
                "name": "Alarm",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "Battery",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "0：满电      1：高      2：中      3：低",
            },
        ],
        "schemaExt": "[]",
    },
    "HiqYJtATgLPqVOW7": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "单插开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 11, "inputStyle": "", "inputType": " "},
        ],
    },
    "tvbrqurv8cl3dtfx": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "iconname": "icon-yundong",
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "声音侦测报警开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "声音侦测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "检测到声音",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
            {
                "mode": "rw",
                "code": "cry_detection_switch",
                "name": "哭声侦测",
                "property": {"type": "bool"},
                "id": 167,
                "type": "obj",
                "desc": "True 开启哭声侦测，false 关闭哭声侦测",
            },
            {
                "mode": "rw",
                "code": "humanoid_filter",
                "name": "人行过滤",
                "property": {"type": "bool"},
                "id": 170,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "baby_cry_upload",
                "name": "检测到婴儿哭声",
                "property": {"type": "string", "maxlen": 255},
                "id": 231,
                "type": "obj",
                "desc": "用于哭声报警消息推送，app上会显示通知",
            },
        ],
        "schemaExt": "[]",
    },
    "z7gaxjajwswn0qki": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "aivw0u9azqc1lzni": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "jevkei7xv0r2zkwi": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "t60pdfglsht7xdgw": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "i3jwagudolr0quct": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
        ],
    },
    "1EKriEN813ucT1uW": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "TEZ6oluErOidJz6L": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "uwajjpe6u24lmjqf": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value_1",
                "name": "亮度值1",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "brightness_min_1",
                "name": "最小亮度1",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "led_type_1",
                "name": "光源类型1",
                "property": {
                    "range": ["LED", "incandescent", "halogen"],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时1",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
            {"id": 6, "inputStyle": "", "inputType": " "},
        ],
    },
    "iNibjJ46XZLtsF21": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "pjyjdwqofodz9tim": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "4j2hiriwhwhlsgmg": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
        ],
    },
    "lyjxgg2vrbutr9t7": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "r4ynuv8yanczmaot": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_location",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": "plain"},
            {"id": 21, "inputStyle": "", "inputType": "plain"},
            {"id": 22, "inputStyle": "", "inputType": "percent"},
            {"id": 23, "inputStyle": "", "inputType": "percent"},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "stramubuirz4jvsc": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
    },
    "jo66vqjwss8zs8xc": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 10, "inputStyle": "", "inputType": ""},
        ],
    },
    "fevkif60ir8c1i0x": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 12, "inputStyle": "", "inputType": " "},
        ],
    },
    "SqpweEQeCCkuXbWD": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 3000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "l3z8y8h2jw6cnj1c": {
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "电源开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cleanarea",
                "name": "清洁面积",
                "property": {
                    "unit": "㎡",
                    "min": 0,
                    "max": 10000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_house",
                "id": 14,
                "type": "obj",
                "desc": "按实际情况输入",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "FAULT_CLIFF",
                        "FAULT_IMP",
                        "FAULT_WHL",
                        "FAULT_BRUSH",
                        "FAULT_FAN",
                        "FAULT_ROLLBRUSH",
                        "FAULT_LOWPOWER",
                        "FAULT_GIVEUP",
                        "FAULT_NODUST",
                        "FAULT_NONE",
                    ],
                    "type": "bitmap",
                    "maxlen": 10,
                },
                "iconname": "icon-dp_warming",
                "id": 17,
                "type": "obj",
                "desc": "下视异常, 前撞异常，边轮异常，边刷异常，风机异常，滚刷异常，电池电量低，找回充失败，尘盒/水箱未安装FAULT_NODUST 无故障",
            },
            {
                "mode": "ro",
                "code": "workstatus",
                "name": "工作状态",
                "property": {
                    "range": [
                        "SLEEP",
                        "HALTING",
                        "CLEANING",
                        "CLEAN_COMP",
                        "FIND_STA",
                        "CHARGING_STA",
                        "CHARGING_DC",
                        "CHARG_COMP",
                    ],
                    "type": "enum",
                },
                "id": 101,
                "type": "obj",
                "desc": "SLEEP,HALTING,CLEANING,CLEAN_COMP,FIND_STA,CHARGING_STA,CHARGING_DC,CHARG_COMP,FAULT",
            },
            {
                "mode": "rw",
                "code": "cleanmode",
                "name": "清扫模式",
                "property": {
                    "range": [
                        "clean_auto",
                        "clean_random",
                        "clean_wall",
                        "clean_spot",
                        "clean_sroom",
                        "find_sta",
                        "null",
                    ],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
                "desc": "clean_auto,clean_random,clean_wall,clean_spot,clean_sroom,find_sta，null",
            },
            {
                "mode": "rw",
                "code": "fanstatus",
                "name": "风力调节",
                "property": {
                    "range": ["FANHALTING", "FANNORAM", "FANMAX"],
                    "type": "enum",
                },
                "id": 104,
                "type": "obj",
                "desc": "停止、正常、强力",
            },
            {
                "mode": "rw",
                "code": "movedirect",
                "name": "方向控制",
                "property": {
                    "range": [
                        "MoveForward",
                        "MoveBackward",
                        "MoveLeft",
                        "MoveRight",
                        "stop",
                    ],
                    "type": "enum",
                },
                "id": 105,
                "type": "obj",
                "desc": "MoveForward,MoveBackward,MoveLeft,MoveRight,MoveHalt",
            },
            {
                "mode": "ro",
                "code": "cleantime",
                "name": "时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity",
                "name": "剩余电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "MaterialLife_Brush",
                "name": "耗材计时(边刷)",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "MaterialLife_Rollbru",
                "name": "耗材计时(滚刷)",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "MaterialLife_HEPA",
                "name": "耗材计时(滤网)",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "CleanSwtich",
                "name": "启动/暂停",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 112,
                "type": "obj",
                "desc": "CleanOFF,CleanON",
            },
            {
                "mode": "wr",
                "code": "ResetBrush",
                "name": "复位耗材（边刷）剩余时间？",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "ResetRollbrush",
                "name": "复位耗材（滚刷）剩余时间？",
                "property": {"type": "bool"},
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "ResetHepa",
                "name": "复位耗材（滤网）剩余时间？",
                "property": {"type": "bool"},
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "FindRobot",
                "name": "寻回扫地机",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "time",
                "name": "清扫模式",
                "property": {
                    "range": [
                        "clean_auto",
                        "clean_random",
                        "clean_wall",
                        "clean_spot",
                        "find_sta",
                    ],
                    "type": "enum",
                },
                "id": 117,
                "type": "obj",
                "desc": "clean_auto,clean_random,clean_wall,clean_spot,clean_sroom,find_sta，null",
            },
            {
                "mode": "ro",
                "code": "RobotModel",
                "name": "设备型号",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 118,
                "type": "obj",
                "desc": "设备型号",
            },
            {
                "mode": "ro",
                "code": "DataSample",
                "name": "数据采集",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 999999999,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 119,
                "type": "obj",
                "desc": "1、用于采集设备的一些信息至云端\n2、用于告知云端设备的一些致命故障等",
            },
            {
                "mode": "rw",
                "code": "g_waterlevel",
                "name": "水量调节",
                "property": {
                    "range": ["water_small", "water_auto", "water_big"],
                    "type": "enum",
                },
                "id": 120,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "2zzciaiapf0eri06": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
    },
    "ahwernlcacvtwe3c": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_5",
                "name": "开关5",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_5",
                "name": "开关5倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "asojbyn4krxn5cix": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fengli",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "dijodvatrsuoo5aq": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "0：断电； 1：通电； 2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 101, "inputStyle": "", "inputType": " "},
            {"id": 102, "inputStyle": "", "inputType": " "},
        ],
    },
    "dyp8emvjvnfyj3kd": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "0：断电； 1：通电； 2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "a6a0y97ikplxbiee": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "zp3yf95sc5z1v4ty": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": ""},
        ],
    },
    "daq19tsrzm8eyia6": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music", "smooth", "flash"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "白光，彩色，情景，识音，渐变，跳变",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mic_sense",
                "name": "麦克风灵敏度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "灵敏度 1-100，用户可设置",
            },
            {
                "mode": "rw",
                "code": "change_speed",
                "name": "变化速度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "music_type",
                "name": "音乐风格",
                "property": {"range": ["soft", "classic", "rock"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "5iac1zdktfolsh1s": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "eISESdwVoVIV3axj": {
        "schema": [
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "电量状态",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": " 0：满电\n1：高\n2：中\n3：低\n4：外电",
            },
            {
                "mode": "rw",
                "code": "Alarmtype",
                "name": "声音类型",
                "property": {
                    "range": [
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                    ],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
                "desc": "每一种代表一种声音",
            },
            {
                "mode": "rw",
                "code": "AlarmPeriod",
                "name": "报警时长",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 1800,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "时间间隔设置",
            },
            {
                "mode": "rw",
                "code": "AlarmSwitch",
                "name": "报警开关",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "声音报警开关",
            },
            {
                "mode": "ro",
                "code": "temperature",
                "name": "温度",
                "property": {
                    "unit": "℃",
                    "min": -20,
                    "max": 80,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "humidity",
                "name": "当前湿度",
                "property": {
                    "unit": "%RH",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temperature_min_set",
                "name": "温度最小值设置",
                "property": {
                    "unit": "℃",
                    "min": -20,
                    "max": 80,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "设置温度阀值的最小值",
            },
            {
                "mode": "rw",
                "code": "temperature_max_set",
                "name": "温度最大值设置",
                "property": {
                    "unit": "",
                    "min": -20,
                    "max": 80,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "设置温度阀值的最大值",
            },
            {
                "mode": "rw",
                "code": "humidity_min_set",
                "name": "湿度最小值设置",
                "property": {
                    "unit": "%RH",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 109,
                "type": "obj",
                "desc": "设置湿度最小值",
            },
            {
                "mode": "rw",
                "code": "humidity_max_set",
                "name": "湿度最大值设置",
                "property": {
                    "unit": "%RH",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "湿度最大值设置",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "温标",
                "property": {"type": "bool"},
                "id": 112,
                "type": "obj",
                "desc": "摄氏度和华氏度切换",
            },
            {
                "mode": "rw",
                "code": "temperatureswitch",
                "name": "温度报警开关",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "可设置温度报警开或者关",
            },
            {
                "mode": "rw",
                "code": "humidityswitch",
                "name": "湿度报警器开关",
                "property": {"type": "bool"},
                "id": 114,
                "type": "obj",
                "desc": "可设置湿度报警开或者关",
            },
            {
                "mode": "ro",
                "code": "Alarm_Status",
                "name": "报警类型",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "6", "8", "9", "12"],
                    "type": "enum",
                },
                "id": 115,
                "type": "obj",
                "desc": "0 解除报警\n1 高温报警 \n2 高湿报警\n3 高温高湿报警\n4 低温报警\n6 低温高湿报警\n8 低湿报警\n9 高温低湿报警\n12 低温低湿报警",
            },
        ],
        "schemaExt": "[]",
    },
    "cuhokdii7ojyw8k2": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "plain", "inputType": "countdown"},
        ],
    },
    "ex8g3j6vabgvk8km": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "4sj7KDNMLbn0oPXO": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
            {"id": 4, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "iqhidxhhmgxk5eja": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "zg6iKOoSnbkYk3YF": {
        "schema": [
            {
                "mode": "ro",
                "code": "PIR",
                "name": "PIR",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "pir 检测",
            },
            {
                "mode": "ro",
                "code": "energy",
                "name": "供电形式",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "两种供电形式：电池供电；USB 供电",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "mcu 上报电池电量",
            },
            {
                "mode": "ro",
                "code": "TamperedAlarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "mcu 上报拆除报警",
            },
        ],
        "schemaExt": "[]",
    },
    "bm37x1lrv6v7lfja": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-dp_lightning",
                "id": 3,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dianliang",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_filter",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_function",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gongneng",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-tongji",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_battery",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "9ulslienhntojx5z": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "声音侦测报警开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "声音侦测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "检测到声音",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "aguvua6tjgfdxpsb": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "backLedControl",
                "name": "背光开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "MW3oVwRZMFA5KCnZ": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报56，实际值为0.056度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "s7jR1xqQPL5F44FJ": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fengli",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": "percent"},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "y13aipj2RedHJ56s": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "agnk8qcx": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "SmFKLTOcGHbPQvmh": {
        "schema": [
            {
                "mode": "ro",
                "code": "WaterLeakage",
                "name": "Alarm",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "True - Alarm On\nFALSE - Alarm Off",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "Battery",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "0x00 - Battery Full\n0x01 - Battery High\n0x02 - Battery Low\n0x03 - Battery Dead",
            },
        ],
        "schemaExt": "[]",
    },
    "zzj2h0nl2mjlpr0g": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "5adbusgachewfheh": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {"range": ["white", "colour", "scene"], "type": "enum"},
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 22, "inputStyle": "", "inputType": " "},
            {"id": 23, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "1GaXUA5v7MqM0A1k": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "b1uk4ftduaqopxv1": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "mdk",
                "name": "门磁开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "uk21by86": {
        "schema": [
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "温度设置",
                "property": {
                    "unit": "°C",
                    "min": 1,
                    "max": 59,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 2,
                "type": "obj",
                "desc": "范围0.5-29.5℃，步进0.5，下发值乘以0.5",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "°C",
                    "min": -50,
                    "max": 350,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-fangzi",
                "id": 3,
                "type": "obj",
                "desc": "显示当前设置温度，步进0.1",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "模式",
                "property": {"range": ["auto", "manual", "holiday"], "type": "enum"},
                "iconname": "icon-fangzi1",
                "id": 4,
                "type": "obj",
                "desc": "自动，手动，假日",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-guanjia",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["fault1", "fault2", "fault3"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "id": 13,
                "type": "obj",
                "desc": "F1.阀门驱动缓慢，检查阀门是否卡死；\nF2.动作范围太宽，检查阀门是否没有安装到位,螺丝是否柠到底；\nF3.调整范围太小，检查暖气阀门是否运行受阻,阀门阻力是否过大",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 1000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-chongnai",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "comfort_temp",
                "name": "舒适温度",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 59,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "范围0.5-29.5℃，步进0.5℃，下发值乘以0.5",
            },
            {
                "mode": "rw",
                "code": "eco_temp",
                "name": "节能温度",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 59,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "范围0.5-29.5℃，步进0.5℃，下发值乘以0.5",
            },
            {
                "mode": "rw",
                "code": "holiday_set",
                "name": "假日模式设置",
                "id": 103,
                "type": "raw",
                "desc": "设定年月日起始时间，结束时间以及温度",
            },
            {
                "mode": "rw",
                "code": "temp_drift",
                "name": "漂移温度（校准）",
                "property": {
                    "unit": "℃",
                    "min": -55,
                    "max": 55,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "范围-5.5~5.5℃，步进0.1℃",
            },
            {
                "mode": "rw",
                "code": "auto_temp",
                "name": "自动温度设置",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 59,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "仅在自动模式下设置，范围0.5-29.5℃，步进0.5，下发值乘以0.5，0用于节能舒适的时候取消",
            },
            {
                "mode": "rw",
                "code": "rapid",
                "name": "快速升温",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "快速升温快关；仅在自动和手动下有效",
            },
            {
                "mode": "ro",
                "code": "window",
                "name": "窗户状态",
                "property": {"type": "bool"},
                "id": 110,
                "type": "obj",
                "desc": "窗户状态显示",
            },
            {
                "mode": "rw",
                "code": "dormancy",
                "name": "休眠",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "monday",
                "name": "周一编程",
                "id": 114,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "thursday",
                "name": "周二编程",
                "id": 115,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "wednesday",
                "name": "周三编程",
                "id": 116,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "tuesday",
                "name": "周四编程",
                "id": 117,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "friday",
                "name": "周五编程",
                "id": 118,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "saturday",
                "name": "周六编程",
                "id": 119,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sunday",
                "name": "周日编程",
                "id": 120,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "window_temp",
                "name": "开窗温度",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 59,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 121,
                "type": "obj",
                "desc": "范围0.5-29.5，步进0.5，下发值乘以0.5",
            },
            {
                "mode": "rw",
                "code": "windows_time",
                "name": "开窗时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 122,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "rapid_time",
                "name": "快速升温倒计时",
                "property": {
                    "unit": "S",
                    "min": 0,
                    "max": 900,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 123,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "state",
                "name": "面板状态",
                "property": {"type": "bool"},
                "id": 124,
                "trigger": "direct",
                "type": "obj",
                "desc": "用于判断面板当前所处的状态",
            },
        ],
        "schemaExt": "[]",
    },
    "LrAKK3uaL6UoKGN1": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "2d7enxgwcxrtjs8g": {
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "n56t7yiklmjd0h4p": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "wymmohgz6fe7o1lm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_filter",
                "id": 39,
                "type": "obj",
                "desc": "0：断电；\n1：通电；\n2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯模式",
                "property": {"range": ["relay", "pos", "none"], "type": "enum"},
                "iconname": "icon-dp_light",
                "id": 40,
                "type": "obj",
                "desc": "relay:状态指示,断开时关闭，接通时点亮；\npos:位置指示，断开时点亮，接通时关闭；\nnone:无指示，指示灯关闭",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 41,
                "type": "obj",
                "desc": "童锁打开发True,关闭发false",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 42,
                "type": "obj",
                "desc": "最大10个定时功能: 每10个字节代表 #1通道号（bit7--开关，bit6-bit0---通道号）/#2星期/#3#4起始时间(min)/#5#6结束时间(min)/#7#8开启时间(min)/#9#10关闭时间(min) \n星期：00(单次)01(周日)02(周一)04(周二)08(周三)10(周四)20(周五)40(周六)",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 43,
                "type": "obj",
                "desc": "最大16个定时功能：每6个字节代表 #1通道号（bit7--开关，bit6-bit0---通道号----排插位数0-6）/#2星期/#3#4起始时间(min)/#5#6结束时间(min)，最大42组\n字符型：6*2字节",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-power",
                "id": 44,
                "type": "obj",
                "desc": "每3个字节代表 #1通道号（bit7--开关，bit0-bit6---通道号）#2表示点动时间:1-60min\n",
            },
        ],
        "schemaExt": "[]",
    },
    "AELWhEbcrw01MAcj": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "tuuggHgAqF6jj8mj": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "qzqoru6yp8rb4umc": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "ukp6s1xx6bh0szam": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "v86uW5IC1RYLFN6q": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "True反转，false正常",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测报警灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取SD卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "SD卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "格式化存储卡",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_record",
                "name": "移动侦测录像",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "True打开，false关闭\n摄像头本地功能：功能打开的时候，只有检测到移动才开始录像。",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "定时移动侦测时间设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测图片/视频上传",
                "id": 115,
                "type": "raw",
                "desc": '{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "停止云台转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
                "desc": "direction：方向，共8个;0-上，1-右上，2-右，3-右下，4-下，5-左下，6-左，7-左上",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测报警功能开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "移动录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "1事件录影，2全时录影 摄像头本地保存录像到SD卡的模式 事件录影：摄像头检测到物体移动再录制录像 全时录影：不间断录制24/7录像",
            },
            {
                "mode": "rw",
                "code": "motion_tracking",
                "name": "人体移动追踪",
                "property": {"type": "bool"},
                "id": 161,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "gVziphwzr6TMD8Qt": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 1220,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "目标温度设置范围=设置温度最低下限值~设置温度最高上限值",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "室内温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {
                    "range": ["Manual", "Program", "Holiday", "TempProg"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "手动、编程、离家、临时手动",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 5,
                },
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "1:设备故障\n2:内置传感器报警\n3.外置传感器报警\n4.低温保护报警\n5.高温保护报警",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "华氏度摄氏度切换",
                "property": {"type": "bool"},
                "iconname": "icon-a_function_fahrenhei",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Heating_state",
                "name": "加热状态",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Ext_temperature",
                "name": "外置温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Days_Holiday",
                "name": "离家模式-天数",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-p7",
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Settemp_Holiday",
                "name": "离家模式-设置温度",
                "property": {
                    "unit": "",
                    "min": 5,
                    "max": 122,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Hightemp_Protect",
                "name": "高温保护功能",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "LowTemp_Protect",
                "name": "低温保护功能",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ext_temp_display",
                "name": "外置温度显示功能",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "外置温度是否显示",
            },
            {
                "mode": "rw",
                "code": "room_temp_compensate",
                "name": "室内温度补偿",
                "property": {
                    "unit": "",
                    "min": -180,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-ziyouchengxu",
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "room_temp_zone",
                "name": "室内温度控制回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ext_temp_zone",
                "name": "外置温度控制回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 18,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "high_temp_limit",
                "name": "高温保护温度",
                "property": {
                    "unit": "",
                    "min": 35,
                    "max": 158,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 112,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "low_temp_limit",
                "name": "低温保护温度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp_max",
                "name": "设置温度最高上限",
                "property": {
                    "unit": "℃",
                    "min": 20,
                    "max": 158,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp_min",
                "name": "设置温度最低下限",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 59,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_sensor_type",
                "name": "传感器类型",
                "property": {"range": ["in", "ext", "all"], "type": "enum"},
                "id": 116,
                "type": "obj",
                "desc": "in:单内置传感器\next:单外置传感器\nall:内外置传感器",
            },
            {
                "mode": "rw",
                "code": "power_state",
                "name": "上电开关机状态",
                "property": {"range": ["keep", "off", "on"], "type": "enum"},
                "id": 117,
                "type": "obj",
                "desc": "keep:保持前一次状态\noff:上电设备关机\non:上电设备开机",
            },
            {
                "mode": "rw",
                "code": "Prog_Type",
                "name": "编程类型",
                "property": {"range": ["2days", "1days", "0days"], "type": "enum"},
                "id": 118,
                "type": "obj",
                "desc": "2days:5+2 5个工作日2个休息日\n1days:6+1 6个工作日1个休息日\n0days:取消编程",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday1",
                "name": "编程-工作日参数1",
                "id": 119,
                "type": "raw",
                "desc": "工作日参数1:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第3时段分钟，第三字节为第3时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday2",
                "name": "编程-工作日参数2",
                "id": 120,
                "type": "raw",
                "desc": "工作日参数2:\n第一字节为第4时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第4时段分钟，第三字节为第4时段设置温度。第四字节为第5时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第5时段分钟，第六字节为第5时段设置温度。第七字节为第6时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第6时段分钟，第三字节为第6时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday1",
                "name": "编程-休息日参数1",
                "id": 121,
                "type": "raw",
                "desc": "休息日参数1:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第3时段分钟，第三字节为第3时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday2",
                "name": "编程-休息日参数2",
                "id": 122,
                "type": "raw",
                "desc": "休息日参数2:\n第一字节为第4时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第4时段分钟，第三字节为第4时段设置温度。第四字节为第5时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第5时段分钟，第六字节为第5时段设置温度。第七字节为第6时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第6时段分钟，第三字节为第6时段设置温度。",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": " "},
            {"id": 6, "inputStyle": "", "inputType": " "},
            {"id": 101, "inputStyle": "", "inputType": "plain"},
            {"id": 103, "inputStyle": "", "inputType": ""},
            {"id": 104, "inputStyle": "", "inputType": "plain"},
            {"id": 105, "inputStyle": "", "inputType": "plain"},
            {"id": 106, "inputStyle": "", "inputType": " "},
            {"id": 107, "inputStyle": "", "inputType": " "},
            {"id": 108, "inputStyle": "", "inputType": " "},
            {"id": 109, "inputStyle": "", "inputType": "plain"},
            {"id": 110, "inputStyle": "", "inputType": " "},
            {"id": 111, "inputStyle": "", "inputType": " "},
            {"id": 112, "inputStyle": "", "inputType": " "},
            {"id": 113, "inputStyle": "", "inputType": " "},
            {"id": 114, "inputStyle": "", "inputType": " "},
            {"id": 115, "inputStyle": "", "inputType": " "},
            {"id": 116, "inputStyle": "", "inputType": " "},
            {"id": 117, "inputStyle": "", "inputType": " "},
        ],
    },
    "1SBmfVPvx2ZsO4B7": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 10, "inputStyle": "", "inputType": ""},
            {"id": 11, "inputStyle": "", "inputType": ""},
        ],
    },
    "kiz4vjrgur3v1cq5": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-HomeArm",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "turAAs6wYyKbH2BH": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "uva98axd2gu1hpzv": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fengli",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "rslytpneaou5rwkg": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fengli",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "5qkmo8rawimwnxgw": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_filter",
                "id": 39,
                "type": "obj",
                "desc": "0：断电；\n1：通电；\n2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 41,
                "type": "obj",
                "desc": "童锁打开发True,关闭发false",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 42,
                "type": "obj",
                "desc": "最大10个定时功能: 每10个字节代表 #1通道号（bit7--开关，bit6-bit0---通道号）/#2星期/#3#4起始时间(min)/#5#6结束时间(min)/#7#8开启时间(min)/#9#10关闭时间(min) \n星期：00(单次)01(周日)02(周一)04(周二)08(周三)10(周四)20(周五)40(周六)",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 43,
                "type": "obj",
                "desc": "最大16个定时功能：每6个字节代表 #1通道号（bit7--开关，bit6-bit0---通道号----排插位数0-6）/#2星期/#3#4起始时间(min)/#5#6结束时间(min)，最大42组\n字符型：6*2字节",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 39, "inputStyle": "", "inputType": " "},
            {"id": 41, "inputStyle": "", "inputType": " "},
        ],
    },
    "9VcZ0dI8xgop7Kyq": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
    },
    "Yhtig6DeVgGXKT2W": {
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "电源开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "power_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "direction",
                "name": "清扫方向",
                "property": {
                    "range": ["forward", "back", "left", "right"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "清扫模式",
                "property": {
                    "range": ["auto", "SmallRoom", "Spot", "Edge", "Nosweep"],
                    "type": "enum",
                },
                "iconname": "icon-dp_dust",
                "id": 5,
                "type": "obj",
                "desc": "自动模式；小房间模式；定点模式；延边模式……可按产品实际功能进行修改",
            },
            {
                "mode": "ro",
                "code": "status",
                "name": "工作状态",
                "property": {
                    "range": [
                        "Running",
                        "standby",
                        "Sleeping",
                        "Charging",
                        "completed",
                        "Recharge",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_direction",
                "id": 15,
                "type": "obj",
                "desc": "0x00:运行中\n0x01:待机中\n0x02:休眠中\n0x03:充电中\n0x04:充电完成\n0x05:回充中",
            },
            {
                "mode": "rw",
                "code": "FMR",
                "name": "自动回充",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Cleaning_intensity",
                "name": "清扫强度",
                "property": {
                    "range": ["Standard", "Boost_IQ", "Max", "No_suction"],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
                "desc": "Standard、Boost IQ、Max",
            },
            {
                "mode": "rw",
                "code": "Looking_weeper",
                "name": "寻找扫地机",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_left1",
                "name": "剩余电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Fault_report",
                "name": "故障上报",
                "property": {
                    "range": [
                        "no_error",
                        "Stuck_5_min",
                        "Crash_bar_stuck",
                        "sensor_dirty",
                        "N_enough_pow",
                        "Wheel_stuck",
                        "S_brush_stuck",
                        "Fan_stuck",
                        "R_brush_stuck",
                    ],
                    "type": "enum",
                },
                "id": 106,
                "type": "obj",
                "desc": "无故障\n卡住5分钟无碰撞 \n防撞栏卡住\n防跌落感应器变脏\n电量不足\n轮子卡住\n侧刷卡住\n风机卡住\n滚刷卡住",
            },
        ],
        "schemaExt": "[]",
    },
    "vl4fdo6mf8aaukqh": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "czmaazl4ezcwbvi4": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "fy7gw8jajnlbhyvy": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 10, "inputStyle": "", "inputType": " "},
        ],
    },
    "kgyvjxko5xbvlesx": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": "plain"},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "yvczn2lhjubluzdl": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kwh",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报1000，实际值为1度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_curve",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_flower",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "vnrlxgzz8hsbjp0o": {
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "galccfa3sw3w4eet": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "zkybmnlmrnagwjvm": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fengli",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "xykp6opg4atevkm1": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kwh",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "过流故障上报",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-baojing",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
    },
    "vnccxpwvdrykudpb": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "True反转，false正常",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测报警灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取SD卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "SD卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "格式化存储卡",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_record",
                "name": "移动侦测录像",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "True打开，false关闭\n摄像头本地功能：功能打开的时候，只有检测到移动才开始录像。",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "定时移动侦测时间设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
                "desc": '{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "停止云台转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
                "desc": "direction：方向，共8个;0-上，1-右上，2-右，3-右下，4-下，5-左下，6-左，7-左上",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "移动录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "1事件录影，2全时录影 摄像头本地保存录像到SD卡的模式 事件录影：摄像头检测到物体移动再录制录像 全时录影：不间断录制24/7录像",
            },
            {
                "mode": "rw",
                "code": "motion_tracking",
                "name": "人体移动追踪",
                "property": {"type": "bool"},
                "id": 161,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "of0VDuFcWsBTfzWt": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_s1",
                "name": "开关s1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_s2",
                "name": "开关s2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_s3",
                "name": "开关s3",
                "property": {"type": "bool"},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_s4",
                "name": "开关s4",
                "property": {"type": "bool"},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb",
                "name": "开关usb",
                "property": {"type": "bool"},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "全部开关控制",
                "property": {
                    "unit": "m",
                    "min": 0,
                    "max": 1,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 7,
                "type": "obj",
                "desc": "0断电  1通电  2记忆继电器上次状态",
            },
        ],
        "schemaExt": [{"complexType": "", "id": 6, "inputStyle": "", "inputType": ""}],
    },
    "b9mcasugykzgefgs": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "bUh0SuudvL9Fs3kg": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
    },
    "FCyk1qyCdMuOu7tW": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
    },
    "Mi2j4AwtJN1mtker": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": " "},
        ],
    },
    "aAeibSsHEuFyPi7A": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "8rzwkffqldxl4idm": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "ljecrv5b1glkw8da": {
        "schema": [
            {
                "mode": "ro",
                "code": "smoke_sensor_state",
                "name": "烟雾检测状态",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "【必选】\n1：烟雾报警\n2:烟雾报警解除\n\n",
            },
            {
                "mode": "ro",
                "code": "checking_result",
                "name": "设备自检结果",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 9,
                "type": "obj",
                "desc": "【非必选】\n0:自检中\n1:自检成功\n2:设备正常\n3:自检超时；\n自检时，建议面板强制等待自检结果，自检拿不到新的结果返回，显示超时。如果面板新进入时，拿到的自检状态值为“自检中”并且是x 秒内上报的，面板显示为自检中状态\n",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "id": 11,
                "type": "obj",
                "desc": "【非必选】",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "id": 14,
                "type": "obj",
                "desc": "低、中、高 三种状态，低电定义为电量值少于30%，将触发低电报警",
            },
        ],
        "schemaExt": "[]",
    },
    "m4E63PZlGWp743wM": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "多路开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "多路开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "多路开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "qpbczz4wwv6q0mxu": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 1220,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "目标温度设置范围=设置温度最低下限值~设置温度最高上限值",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {
                    "range": ["Manual", "Program", "Holiday", "TempProg"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "手动、编程、离家、临时手动",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 5,
                },
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "1:设备故障\n2:内置传感器报警\n3.外置传感器报警\n4.低温保护报警\n5.高温保护报警",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "华氏度摄氏度",
                "property": {"type": "bool"},
                "iconname": "icon-a_function_fahrenhei",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Heating_state",
                "name": "加热",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Ext_temperature",
                "name": "外置温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Days_Holiday",
                "name": "离家模式-天数",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-p7",
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Settemp_Holiday",
                "name": "离家模式-设置温度",
                "property": {
                    "unit": "",
                    "min": 5,
                    "max": 122,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Hightemp_Protect",
                "name": "高温保护功能",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "LowTemp_Protect",
                "name": "低温保护功能",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ext_temp_display",
                "name": "外置温度显示功能",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "外置温度是否显示",
            },
            {
                "mode": "rw",
                "code": "room_temp_compensate",
                "name": "温度补偿",
                "property": {
                    "unit": "",
                    "min": -180,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-ziyouchengxu",
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "room_temp_zone",
                "name": "室内温度回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ext_temp_zone",
                "name": "外置温度回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 18,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "high_temp_limit",
                "name": "高温保护温度",
                "property": {
                    "unit": "",
                    "min": 35,
                    "max": 158,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 112,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "low_temp_limit",
                "name": "低温保护温度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp_max",
                "name": "设置温度最高上限",
                "property": {
                    "unit": "℃",
                    "min": 20,
                    "max": 158,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp_min",
                "name": "设置温度最低下限",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 59,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_sensor_type",
                "name": "传感器类型",
                "property": {"range": ["in", "ext", "all"], "type": "enum"},
                "id": 116,
                "type": "obj",
                "desc": "in:单内置传感器\next:单外置传感器\nall:内外置传感器",
            },
            {
                "mode": "rw",
                "code": "power_state",
                "name": "上电开关机状态",
                "property": {"range": ["keep", "off", "on"], "type": "enum"},
                "id": 117,
                "type": "obj",
                "desc": "keep:保持前一次状态\noff:上电设备关机\non:上电设备开机",
            },
            {
                "mode": "rw",
                "code": "Prog_Type",
                "name": "编程类型",
                "property": {"range": ["2days", "1days", "0days"], "type": "enum"},
                "id": 118,
                "type": "obj",
                "desc": "2days:5+2 5个工作日2个休息日\n1days:6+1 6个工作日1个休息日\n0days:取消编程",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday1",
                "name": "编程-工作日参数1",
                "id": 119,
                "type": "raw",
                "desc": "工作日参数1:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第3时段分钟，第三字节为第3时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday2",
                "name": "编程-工作日参数2",
                "id": 120,
                "type": "raw",
                "desc": "工作日参数2:\n第一字节为第4时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第4时段分钟，第三字节为第4时段设置温度。第四字节为第5时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第5时段分钟，第六字节为第5时段设置温度。第七字节为第6时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第6时段分钟，第三字节为第6时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday1",
                "name": "编程-休息日参数1",
                "id": 121,
                "type": "raw",
                "desc": "休息日参数1:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第3时段分钟，第三字节为第3时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday2",
                "name": "编程-休息日参数2",
                "id": 122,
                "type": "raw",
                "desc": "休息日参数2:\n第一字节为第4时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第4时段分钟，第三字节为第4时段设置温度。第四字节为第5时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第5时段分钟，第六字节为第5时段设置温度。第七字节为第6时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第6时段分钟，第三字节为第6时段设置温度。",
            },
        ],
        "schemaExt": "[]",
    },
    "00L5DHLUfSQh5xbS": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 11,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "hjsgdkfl": {
        "schema": [
            {
                "mode": "rw",
                "code": "prm_content",
                "name": "湿度",
                "property": {
                    "unit": "% RH",
                    "min": 0,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "prm_temperature",
                "name": "温度",
                "property": {
                    "unit": "",
                    "min": -2000,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "vAIsoFGvJNaq7v0W": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
    },
    "ojh1chfj842dgz3y": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "uwP5ueRSh5k5Ccuw": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "喷雾开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Light",
                "name": "灯光开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "缺水故障",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_time2",
                "id": 13,
                "type": "obj",
                "desc": "0:ON；1：1小时；2：3小时。可根据产品实际功能进行设置。",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 14,
                "type": "obj",
                "desc": "mcu每分钟上报",
            },
            {
                "mode": "rw",
                "code": "dp_mist_grade",
                "name": "雾量",
                "property": {"range": ["small", "big"], "type": "enum"},
                "id": 103,
                "type": "obj",
                "desc": "小喷雾，大喷雾",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "id": 108,
                "type": "obj",
                "desc": 'Value: ”00112233334455”（长度为 14 的字符串） 00: R 11: G 22: B 3333: H(色调 Hue) 44: S(饱和度 Saturation) 55: V(明度 Value) 示例： {"2700000000ff27"}',
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene1",
                        "scene2",
                        "scene3",
                        "scene4",
                    ],
                    "type": "enum",
                },
                "id": 109,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "lightmode",
                "name": "灯光模式",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 110,
                "type": "obj",
                "desc": "1：七彩循环；2：定色；3：夜灯",
            },
            {
                "mode": "rw",
                "code": "setlight",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
                "desc": "只用于夜灯亮度调节",
            },
        ],
        "schemaExt": [
            {"id": 14, "inputStyle": "", "inputType": ""},
            {"id": 111, "inputStyle": "", "inputType": ""},
        ],
    },
    "mrdtuiyqesno0475": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fengli",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "3EUETAhBnjdGBE5K": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "speed",
                "name": "风速",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_wind",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "filter_reset",
                "name": "滤芯复位",
                "property": {"type": "bool"},
                "iconname": "icon-dp_filter",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {"range": ["cancle", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_time2",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 240,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "lightmode",
                "name": "灯光",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "灯光",
            },
        ],
    },
    "ch8z9cpfhfn108wa": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
    },
    "m6hWILNKUL8ALT95": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "percent1"},
        ],
    },
    "ymf4oruxqx0xlogp": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "电池电量",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": " 0：满电\n1：高\n2：中\n3：低\n4：外电",
            },
            {
                "mode": "rw",
                "code": "Alarmtype",
                "name": "报警声类型",
                "property": {
                    "range": [
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                    ],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
                "desc": "每一种代表一种声音",
            },
            {
                "mode": "rw",
                "code": "AlarmPeriod",
                "name": "报警时长",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 1800,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "时间间隔设置",
            },
            {
                "mode": "rw",
                "code": "AlarmSwitch",
                "name": "报警开关",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "声音报警开关",
            },
            {
                "mode": "ro",
                "code": "temperature",
                "name": "温度",
                "property": {
                    "unit": "℃",
                    "min": -200,
                    "max": 500,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "humidity",
                "name": "湿度",
                "property": {
                    "unit": "%RH",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temperature_min_set",
                "name": "温度最小值",
                "property": {
                    "unit": "℃",
                    "min": -20,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "设置温度阀值的最小值",
            },
            {
                "mode": "rw",
                "code": "temperature_max_set",
                "name": "温度最大值",
                "property": {
                    "unit": "℃",
                    "min": -20,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "设置温度阀值的最大值",
            },
            {
                "mode": "rw",
                "code": "humidity_min_set",
                "name": "湿度最小值",
                "property": {
                    "unit": "%RH",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 109,
                "type": "obj",
                "desc": "设置湿度最小值",
            },
            {
                "mode": "rw",
                "code": "humidity_max_set",
                "name": "湿度最大值",
                "property": {
                    "unit": "%RH",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "湿度最大值设置",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "温标",
                "property": {"type": "bool"},
                "id": 112,
                "type": "obj",
                "desc": "摄氏度和华氏度切换",
            },
            {
                "mode": "rw",
                "code": "temperatureswitch",
                "name": "温度报警开关",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
                "desc": "可设置温度报警开或者关",
            },
            {
                "mode": "rw",
                "code": "humidityswitch",
                "name": "湿度报警器开关",
                "property": {"type": "bool"},
                "id": 114,
                "type": "obj",
                "desc": "可设置湿度报警开或者关",
            },
            {
                "mode": "ro",
                "code": "Alarm_Status",
                "name": "报警类型",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 115,
                "type": "obj",
                "desc": "0 高温报警 \n1 高湿报警\n2 低温报警\n3 低湿报警\n4 解除报警",
            },
            {
                "mode": "rw",
                "code": "AlarmdB",
                "name": "报警分贝",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 116,
                "type": "obj",
                "desc": "0 高分贝\n1 中分贝\n2 低分贝\n",
            },
        ],
    },
    "XS76BY5Q1uKO6gjC": {
        "schema": [
            {
                "mode": "rw",
                "code": "position",
                "name": "窗帘位置",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_loop",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mach_operate",
                "name": "电机操作",
                "property": {"range": ["ZZ", "FZ", "STOP"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "正转、反转、停",
            },
            {
                "mode": "rw",
                "code": "opposite",
                "name": "反向设置",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "0:不反向 1:反向",
            },
        ],
        "schemaExt": [
            {"id": 101, "inputStyle": "", "inputType": "percent"},
            {"id": 102, "inputStyle": "", "inputType": " "},
            {"id": 103, "inputStyle": "", "inputType": " "},
        ],
    },
    "h8rhaescdxmdtnvh": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
    },
    "YTXzou69j7G8gajX": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": "plain"},
            {"id": 4, "inputStyle": "", "inputType": "plain"},
        ],
    },
    "ixwmhw1karzonjnc": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
        "schemaExt": "[]",
    },
    "aVaUQA0i5xrHGrcR": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": [
            {"id": 9, "inputStyle": "", "inputType": ""},
            {"id": 10, "inputStyle": "", "inputType": ""},
            {"id": 17, "inputStyle": "", "inputType": ""},
            {"id": 18, "inputStyle": "", "inputType": ""},
            {"id": 19, "inputStyle": "", "inputType": ""},
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 24, "inputStyle": "", "inputType": ""},
            {"id": 25, "inputStyle": "", "inputType": ""},
        ],
    },
    "5god9xhp5w3cebzm": {
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-dp_puzzle",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_puzzle",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "码库按键参数4",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "学习参数下发4",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_puzzle",
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "abnl2bar22ij804p": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "TfMQK6wdMphwJBcL": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "具体功能：继电器1（IO15，高电平-开）；WIFI清除按键（IO0，低电平有效，长按配对，短按继电器通断）；继电器通断指示灯（IO13，低电平点亮）；WIFI指示灯（IO12，高电平点亮，上电高电平，可单独APP（语音）控制亮、灭,可调光，与小夜灯共用指示）",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
            {
                "mode": "rw",
                "code": "switch",
                "name": "夜灯开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "light",
                "name": "小夜灯亮度调节",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-deng",
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch03",
                "name": "总控开关",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "总控制夜灯和插座的通断开关",
            },
        ],
        "schemaExt": [
            {"id": 11, "inputStyle": "", "inputType": ""},
            {"id": 103, "inputStyle": "", "inputType": "percent"},
        ],
    },
    "oBUpA2V0CCuQ43Cd": {
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
    },
    "n3xgr5pdmpinictg": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "窗帘状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
    },
    "G7mU2Ae7O2wNtrwJ": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "zwhr5xpa98wkftaw": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
        "schemaExt": "[]",
    },
    "jsf9spFEoWRFozCC": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "timer_func",
                "scope": "fault",
                "name": "定时功能",
                "property": {"label": ["1", "2"], "type": "bitmap", "maxlen": 2},
                "id": 4,
                "type": "obj",
                "desc": "第一位普通定时关机；第二位普通定时开机；",
            },
            {
                "mode": "rw",
                "code": "set_mode",
                "name": "设定模式",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 5,
                "type": "obj",
                "desc": "0智能；1制热；2除湿；3制冷；4送风",
            },
            {
                "mode": "rw",
                "code": "set_temper",
                "name": "设定温度",
                "property": {
                    "unit": "℃",
                    "min": 13,
                    "max": 32,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "wind_speed",
                "name": "风速",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 8,
                "type": "obj",
                "desc": "0自动，1低速，2中速，3高速，",
            },
            {
                "mode": "rw",
                "code": "c_f_change",
                "name": "温度转换",
                "property": {"type": "bool"},
                "id": 10,
                "type": "obj",
                "desc": "1:华氏 0:摄氏",
            },
            {
                "mode": "rw",
                "code": "off_timer_min",
                "name": "定时关机时间",
                "property": {
                    "unit": "h",
                    "min": 0,
                    "max": 1440,
                    "scale": 0,
                    "step": 60,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "on_timer_min",
                "name": "定时开机时间",
                "property": {
                    "unit": "h",
                    "min": 0,
                    "max": 1440,
                    "scale": 0,
                    "step": 60,
                    "type": "value",
                },
                "id": 14,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障提示",
                "property": {
                    "label": ["Lt", "PF", "Ft"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "id": 15,
                "type": "obj",
                "desc": "低温除霜保护；感温系统故障；安全水箱水满；",
            },
            {
                "mode": "rw",
                "code": "wind",
                "name": "摆风",
                "property": {"type": "bool"},
                "id": 16,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sleep_func",
                "name": "睡眠",
                "property": {"type": "bool"},
                "id": 17,
                "type": "obj",
                "desc": "0:关 1:开",
            },
            {
                "mode": "rw",
                "code": "f_temper",
                "name": "华氏度温度",
                "property": {
                    "unit": "℉",
                    "min": 55,
                    "max": 90,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "force",
                "name": "强力",
                "property": {"type": "bool"},
                "id": 19,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "A97tpqWB2DyjUnd5": {
        "schemaExt": [{"id": 11, "inputStyle": "", "inputType": ""}],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
    },
    "gfadjwam": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch1_value",
                "name": "无线开关1",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-power",
                "id": 1,
                "trigger": "direct",
                "type": "obj",
                "desc": "0：单击 1：双击 2：长按",
            },
            {
                "mode": "rw",
                "code": "switch2_value",
                "name": "无线开关2",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-power",
                "id": 2,
                "trigger": "direct",
                "type": "obj",
                "desc": "0：单击 1：双击 2：长按",
            },
            {
                "mode": "rw",
                "code": "switch3_value",
                "name": "无线开关3",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-power",
                "id": 3,
                "trigger": "direct",
                "type": "obj",
                "desc": "0：单击 1：双击 2：长按",
            },
        ],
    },
    "Uw3wfqKPcQGrTlaC": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": "plain"},
            {"id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "80qAxMh5FekucSKw": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "xplsif5wa1s9rtoe": {
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": " "},
            {"id": 21, "inputStyle": "", "inputType": " "},
            {"id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {"range": ["colour", "scene", "music"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "JvihcnJiXk1grl60": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ehzaytjzwy4etre9": {
        "schema": [
            {
                "mode": "ro",
                "code": "hcho_sensor_state",
                "name": "甲烷检测状态",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "【必选】\n1：甲烷报警\n2:甲烷报警解除\n\n",
            },
            {
                "mode": "ro",
                "code": "hcho_sensor_value",
                "name": "甲烷检测值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "【非必选】",
            },
            {
                "mode": "rw",
                "code": "self_checking",
                "name": "设备自检",
                "property": {"type": "bool"},
                "id": 8,
                "type": "obj",
                "desc": "【非必选】app触发后，硬件进入自检状态，处于自检中状态时app不能重新触发自检\n",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "id": 16,
                "type": "obj",
                "desc": "硬件开始发出报警声后，上报该dp点。app可以通过指令下发，停止设备在本周期内的报警",
            },
            {
                "mode": "rw",
                "code": "DCF",
                "name": "远程关阀",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "1== 关阀； 0==不关阀",
            },
            {
                "mode": "rw",
                "code": "MOTOR",
                "name": "机械手关闭",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "1== 机械手关； 0==机械手开。",
            },
        ],
        "schemaExt": "[]",
    },
    "yn6cbjf3awcpmmij": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
    },
    "aagyuMeViZwSXXsD": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "3ovuf2vazfsz2hfd": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 3, "inputStyle": "", "inputType": " "},
            {"id": 101, "inputStyle": "", "inputType": "plain"},
            {"id": 102, "inputStyle": "", "inputType": " "},
            {"id": 103, "inputStyle": "", "inputType": " "},
            {"id": 104, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度1",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "led_switch2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-a_power",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value2",
                "name": "亮度2",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 103,
                "type": "obj",
                "desc": "0：断电 \n1：通电\n2：记忆设备上次状态",
            },
            {
                "mode": "rw",
                "code": "min_bright",
                "name": "亮度最小值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "gmjdt6mvy1mntvqn": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "yVANJtHqYAPeA7pJ": {
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测-定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "声音侦测报警开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "声音侦测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
                "desc": "0代表低灵敏度；1代表高灵敏度",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "检测到声音",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
                "desc": "用于报警消息推送，app上会显示通知",
            },
            {
                "mode": "ro",
                "code": "sensor_temperature",
                "name": "传感器-温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 142,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "sensor_humidity",
                "name": "传感器-湿度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 143,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
        "schemaExt": "[]",
    },
    "iPiqkMPG2lOUtpqB": {
        "schema": [
            {
                "mode": "rw",
                "code": "PowerOnOff",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "启动和停止",
            },
            {
                "mode": "ro",
                "code": "WorkStatus",
                "name": "工作状态",
                "property": {"range": ["stop", "working", "complete"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "已暂停，准备中，正在烹调，已完成",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "设定温度",
                "property": {
                    "unit": "℃",
                    "min": 200,
                    "max": 960,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "温度设置范围要求在20摄氏度-95摄氏度",
            },
            {
                "mode": "ro",
                "code": "TempShow",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "SetTime",
                "name": "设定时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 5999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "时间设置范围0-99小时59分钟",
            },
            {
                "mode": "ro",
                "code": "RemainingTime",
                "name": "剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 5999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障",
                "property": {"label": ["0", "1", "2"], "type": "bitmap", "maxlen": 3},
                "id": 107,
                "type": "obj",
                "desc": "0为无报警，1为水位异常报警，2，NTC故障",
            },
            {
                "mode": "rw",
                "code": "TempChanger",
                "name": "温度切换",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "0：℃\n1：℉",
            },
            {
                "mode": "rw",
                "code": "Recipe",
                "name": "本地菜谱",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 109,
                "type": "obj",
                "desc": "本地菜谱编号",
            },
            {
                "mode": "rw",
                "code": "TempSc",
                "name": "温度修正",
                "property": {
                    "unit": "°C",
                    "min": -180,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "25OALPSupXhFUTD8": {
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
        "schemaExt": "[]",
    },
    "khw6nzpbjilca1ex": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "Brightness",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "tcahxua1g4cbowbo": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 7, "inputStyle": "", "inputType": "plain"},
            {"id": 9, "inputStyle": "", "inputType": "countdown"},
            {"id": 15, "inputStyle": "", "inputType": "countdown"},
            {"id": 17, "inputStyle": "", "inputType": " "},
            {"id": 18, "inputStyle": "", "inputType": ""},
            {"id": 19, "inputStyle": "", "inputType": ""},
            {"id": 20, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "Switch1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "Socket switch",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "SwitchUSB1",
                "property": {"type": "bool"},
                "iconname": "icon-battery",
                "id": 7,
                "type": "obj",
                "desc": "USB output switch",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "SocketTimer",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USBTimer",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "AccumPower",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-dianliang",
                "id": 17,
                "type": "obj",
                "desc": "Accumulated power",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "CurrCurrent",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "CurrPower",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "CurrVoltage",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "Overload",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "故障告警\nov_cr：过流保护",
            },
        ],
    },
    "nT5naTaAoraAuOrM": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
    },
    "f9owcdgqqdwubknn": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "窗帘状态",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
    },
    "SxH4TApHnxj4ElMW": {
        "schemaExt": [{"id": 2, "inputStyle": "", "inputType": ""}],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
        ],
    },
    "rdopirknpltovvth": {
        "schemaExt": [
            {"id": 103, "inputStyle": "", "inputType": " "},
            {"id": 104, "inputStyle": "", "inputType": " "},
            {"id": 106, "inputStyle": "", "inputType": " "},
            {"id": 111, "inputStyle": "", "inputType": " "},
            {"id": 147, "inputStyle": "", "inputType": " "},
            {"id": 149, "inputStyle": "", "inputType": " "},
            {"id": 152, "inputStyle": "", "inputType": " "},
            {"id": 188, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测告警",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "ro",
                "code": "doorbell_active",
                "name": "门铃呼叫",
                "property": {"type": "string", "maxlen": 255},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "wireless_electricity",
                "name": "低功耗-电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 145,
                "type": "obj",
                "desc": "设备主动上报当前电量，电量发生变化时上报。类型为数值型，上报0-100的整数。app会处理成百分比。\n",
            },
            {
                "mode": "ro",
                "code": "wireless_powermode",
                "name": "低功耗-供电方式",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 146,
                "type": "obj",
                "desc": "设备主动上报当前供电状态，供电状态发生变化时上报。0为电池供电状态，1为插电供电状态（或电池充电状态）",
            },
            {
                "mode": "rw",
                "code": "wireless_lowpower",
                "name": "低功耗-低电报警",
                "property": {
                    "unit": "",
                    "min": 20,
                    "max": 50,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 147,
                "type": "obj",
                "desc": "若电量百分比低于该阈值，则触发报警；App端设置，设备本身无须关心该dp点。",
            },
            {
                "mode": "rw",
                "code": "wireless_awake",
                "name": "低功耗-唤醒状态",
                "property": {"type": "bool"},
                "id": 149,
                "type": "obj",
                "desc": "设备主动上报当前低功耗是否处于唤醒状态。类型为布尔型，True为唤醒状态，false为休眠状态。（设备休眠前上报false，设备唤醒后上报一次True）",
            },
            {
                "mode": "rw",
                "code": "pir_switch",
                "name": "PIR开关及灵敏度",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-renxingyidong",
                "id": 152,
                "type": "obj",
                "desc": "0关闭，1灵敏度低，2灵敏度中，3灵敏度高",
            },
            {
                "mode": "ro",
                "code": "doorbell_pic",
                "name": "门铃-抓拍图片 ",
                "id": 154,
                "type": "raw",
                "desc": "用户按下门铃，抓拍图片并上传",
            },
            {
                "mode": "rw",
                "code": "alarm_message",
                "name": "告警消息-上报",
                "id": 185,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "basic_anti_flicker",
                "name": "抗闪烁",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 188,
                "type": "obj",
                "desc": "0：关闭功能 \n1：50Hz\n2：60Hz",
            },
            {
                "mode": "ro",
                "code": "cus_alarm",
                "name": "自定义告警",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 231,
                "type": "obj",
                "desc": "0.关闭 ， 1-设备已被拆除，2-安装异常",
            },
        ],
    },
    "Vd5BdeaOTJQy2TBf": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": " "},
            {"id": 3, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "hjlrvnrnjwdohget": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "KeyCode",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
                "desc": "码库按键参数",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "KeyCode2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
                "desc": "码库按键参数2\n仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "KeyCode3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
                "desc": "码库按键参数3\n仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "KeyStudy",
                "id": 7,
                "type": "raw",
                "desc": "来自学习参数下发",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "KeyStudy2",
                "id": 8,
                "type": "raw",
                "desc": "来自学习参数下发2\n仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "KeyStudy3",
                "id": 9,
                "type": "raw",
                "desc": "来自学习参数下发3\n仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "IRSendDelay",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "红外码发送延时",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "NewKey_KeyCode4",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "新按键参数",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "LearnedKeyParameters",
                "id": 12,
                "type": "raw",
                "desc": "新学习参数",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "CodeID",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "码库标识",
            },
        ],
    },
    "LOeuvI6KCxzuZe0k": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 2, "inputStyle": "", "inputType": "plain"},
            {"id": 5, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "全部开关控制",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "0:全关；1:全开",
            },
        ],
    },
    "tg43aAXlWMBBqL3T": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "上报门窗开关状态",
            },
            {
                "mode": "ro",
                "code": "TamperedAlarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "mcu 上报拆除信息",
            },
            {
                "mode": "ro",
                "code": "Battery",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "mcu 上报电池电量信息",
            },
            {
                "mode": "ro",
                "code": "state",
                "name": "状态",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "上报产品是“休眠”还是“离线”",
            },
        ],
    },
    "zfbj19qm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_play-copy",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "QecRBM8OwQJEIVpb": {
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "xwoekxbr6nzdqlj0": {
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "tff0sh8vl2pnljye": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "dzdmfbh14gxcsujg": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 7, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "延时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "my2JIQN4R8jADr0D": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "6sbfhav7hipqeru0": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "e4xB7UAeNn237W2B": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "91XARjHUMs1UGRmu": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": "plain"},
            {"id": 11, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
    },
    "p5pd3bukjlgny5z7": {
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 23, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ycRIimfUpZAhopVm": {
        "schemaExt": [
            {"id": 3, "inputStyle": "", "inputType": ""},
            {"id": 4, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "D9T0hGIV7jGBC3xA": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "6qwk8atz3sbzmuda": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "status",
                "name": "开关状态",
                "property": {"range": ["open", "closed"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "电池电量",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "dr3bqhjubfp2suon": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "WaterLeakage",
                "name": "溢水检测器",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "True - Alarm On\nFALSE - Alarm Off",
            },
            {
                "mode": "ro",
                "code": "BatteryStatus",
                "name": "电池电量",
                "property": {"range": ["0x00", "0x01", "0x02", "0x03"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "0x00 - Battery Full\n0x01 - Battery High\n0x02 - Battery Low\n0x03 - Battery Dead",
            },
        ],
    },
    "bbyar9arpehpvh7i": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "go7x6hwgllkukhck": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "2nuwDqbTZIAV7JW6": {
        "schemaExt": [{"id": 3, "inputStyle": "", "inputType": ""}],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "WTfN2BwyMbEQsAdC": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "qeny8iwwe9wtm4zw": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "master_mode",
                "name": "主机模式",
                "property": {
                    "range": ["disarmed", "arm", "home", "sos"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "delay_set",
                "name": "布防延时时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 256,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "alarm_time",
                "name": "报警延时时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 256,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_sound",
                "name": "布撤防推送开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "alarm_volume",
                "name": "音量",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-dp_voice",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "alarm_ringtone",
                "name": "铃声",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                        "19",
                        "20",
                        "21",
                        "22",
                        "23",
                        "24",
                        "25",
                        "26",
                        "27",
                        "28",
                        "29",
                        "30",
                        "31",
                        "32",
                        "33",
                        "34",
                        "35",
                        "36",
                        "37",
                        "38",
                        "39",
                        "40",
                        "41",
                        "42",
                        "43",
                        "44",
                        "45",
                        "46",
                        "47",
                        "48",
                        "49",
                        "50",
                        "51",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_voice",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "zone_attribute",
                "name": "防区属性设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-air_quality",
                "id": 24,
                "type": "obj",
                "desc": "0普通1紧急",
            },
            {
                "mode": "ro",
                "code": "alarm_msg",
                "name": "告警信息",
                "iconname": "icon-baojing",
                "id": 26,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "master_information",
                "name": "主机信息",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_doc",
                "id": 33,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sub_class",
                "name": "子设备品类",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 36,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sub_type",
                "name": "子设备类别",
                "property": {
                    "range": [
                        "motion_sensor",
                        "contact_sensor",
                        "smoke_alarm",
                        "gas_alarm",
                        "co_alarm",
                        "vibration_detector",
                        "water_leak_sensor",
                        "infrared_emission_detector",
                        "glass_break_detector",
                        "sos_button",
                        "remote_controller",
                        "keypad",
                        "doorbell",
                        "door_lock",
                        "rfid",
                        "alarm",
                        "environment_detector",
                        "others",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 37,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sub_admin",
                "name": "子设备管理",
                "iconname": "icon-dp_mode",
                "id": 38,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "sub_state",
                "name": "子设备状态",
                "property": {
                    "range": ["normal", "alarm", "fault", "others"],
                    "type": "enum",
                },
                "iconname": "icon-zhuangtai",
                "id": 39,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "master_language",
                "name": "主机语言",
                "property": {"range": ["0", "1"], "type": "enum"},
                "iconname": "icon-a_function_filter",
                "id": 40,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "arm_mode_push",
                "name": "布撤防推送",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7"],
                    "type": "enum",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "AXnFs1bJQITWAPA4": {
        "schemaExt": [{"id": 1, "inputStyle": "", "inputType": "plain"}],
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "Status",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
    },
    "mxux6odsvwvjvmos": {
        "schemaExt": [
            {"id": 1, "inputStyle": "", "inputType": " "},
            {"id": 9, "inputStyle": "", "inputType": " "},
            {"id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
    },
    "wwfztjkr3kqxrfya": {
        "schemaExt": [
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 104, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 105, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 106, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 109, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 116, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 117, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 121, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 122, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 123, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 124, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 125, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 126, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 129, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 130, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led",
                "name": "灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "1-打开\n0-关闭",
            },
            {
                "mode": "rw",
                "code": "led_light",
                "name": "灯亮度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 20,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "1-最暗 20-最亮",
            },
            {
                "mode": "rw",
                "code": "time_set",
                "name": "时间",
                "property": {"type": "string", "maxlen": 255},
                "id": 103,
                "type": "obj",
                "desc": "ASCII (12:34:56)   0X31 0X32 0X33 0X34 0X35 0X36",
            },
            {
                "mode": "rw",
                "code": "panel_light",
                "name": "时间面板亮度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 2,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "0-关闭 1-白天 2-黑夜",
            },
            {
                "mode": "rw",
                "code": "Radio",
                "name": "收音机",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "0-关闭\n1-打开",
            },
            {
                "mode": "rw",
                "code": "volume",
                "name": "收音机音量",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 16,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "1-最低音量 16--最响",
            },
            {
                "mode": "rw",
                "code": "Radiolist",
                "name": "Radio总台数及当前播放台号",
                "id": 107,
                "type": "raw",
                "desc": "#1总台数 范围（1-60），如MCU返回未搜台（此处为0），APP显示-\n#2当前播放台号 范围（1-60），如未获得总台数，播放台号0，APP显示-",
            },
            {
                "mode": "rw",
                "code": "clock1",
                "name": "闹钟1",
                "property": {"type": "bool"},
                "id": 109,
                "type": "obj",
                "desc": "0--闹钟禁止--APP下发/MCU上传\n1--闹钟使能--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "Delay_time",
                "name": "贪睡时长",
                "property": {
                    "unit": "分钟",
                    "min": 8,
                    "max": 15,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 116,
                "type": "obj",
                "desc": "默认9分钟",
            },
            {
                "mode": "rw",
                "code": "close_mode_set",
                "name": "贪睡模式",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "id": 117,
                "type": "obj",
                "desc": "0x00-音效+Radio；0X01-灯光；0X02-Radio，0X03-Radio+音效+灯光\n（默认值为0x03）",
            },
            {
                "mode": "rw",
                "code": "sleep",
                "name": "入睡",
                "property": {"type": "bool"},
                "id": 121,
                "type": "obj",
                "desc": "0--伴睡关闭--APP下发/MCU上传\n1--伴睡打开--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "clock2",
                "name": "闹钟2",
                "property": {"type": "bool"},
                "id": 122,
                "type": "obj",
                "desc": "0--闹钟禁止--APP下发/MCU上传\n1--闹钟使能--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "clock3",
                "name": "闹钟3",
                "property": {"type": "bool"},
                "id": 123,
                "type": "obj",
                "desc": "0--闹钟禁止--APP下发/MCU上传\n1--闹钟使能--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "clock4",
                "name": "闹钟4",
                "property": {"type": "bool"},
                "id": 124,
                "type": "obj",
                "desc": "0--闹钟禁止--APP下发/MCU上传\n1--闹钟使能--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "Internet_time",
                "name": "网络校时",
                "property": {"type": "bool"},
                "id": 125,
                "type": "obj",
                "desc": "0--禁止--APP下发/MCU上传\n1--允许--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "Radio_search",
                "name": "收音机搜台",
                "property": {"type": "bool"},
                "id": 126,
                "type": "obj",
                "desc": "0-搜台结束\n1-搜台开始",
            },
            {
                "mode": "rw",
                "code": "clock_set",
                "name": "闹钟设置",
                "id": 127,
                "type": "raw",
                "desc": "闹钟设置参数设置好后，按照一条dp点进行下发。\nDp点采用RAW格式，每12个字节代表1个闹钟，最多四个闹钟，按顺序累加处理，每次修改设置下发所有闹钟设置\n#1响闹（0-响闹，1-未响闹，未启用）\n#2#3时间（高低位分钟-24小时计算，例如：13：08=13*60+8）\n#4重复（0-一次，0b00000001-周一 0b01111111 周一-周日 16进制传输 0x7F）\n#5响闹持续时间（10-20范围，默认15）\n#6响闹方式（0-音效，1-音效+灯光，2-Radio，3-radio+灯光）\n#7响闹音效（1-7范围）\n#8音效音量（1-16范围）\n#9 Radio台表（1-60范围）\n#13 Radio音量 （1-16范围）\n#10唤醒灯日出时间（10-60范围）\n#11日出完成后亮度（1-20范围）\n#12支持snooze（0-支持，1-不支持 默认支持）",
            },
            {
                "mode": "rw",
                "code": "sleep_set",
                "name": "入睡设置",
                "id": 128,
                "type": "raw",
                "desc": "1，入睡设置参数设置好后，需同时下发所���参数，mcu设计时也需注意接收全部参数。App端仅进行下发，后续由mcu自行处理；\n2，入睡持续时间结束后，mcu上报入睡开关状态。 Dp点采用RAW格式，总共10个字节，\n#1开关（此位无效，统一置1）\n#2入睡方式（音效-0x0，音效+灯-0x1，收音机-0x2，灯光+收音机-0x3）\n#3入睡音效（1-3范围）/\n#4音效音量（1-16范围）/\n#5音效持续时长（范围10-120）/\n#6radio台号（1-60范围）/\n#7radio持续时长（范围10-120）/\n#8日落起始亮度（1-20范围）/\n#9日落持续时间（范围10-120）/\n#10支持snooze（0-支持 1-不支持 默认不支持）\n（#5，#7和#9设置为同一个数值，且APP各种菜单选项保证只有一个位置可以设置，范围10-120）",
            },
            {
                "mode": "rw",
                "code": "colorLight",
                "name": "氛围灯",
                "property": {"type": "bool"},
                "id": 129,
                "type": "obj",
                "desc": "0-关闭彩灯\n1-打开彩灯，自动模式\n",
            },
            {
                "mode": "rw",
                "code": "Delay",
                "name": "贪睡",
                "property": {"type": "bool"},
                "id": 130,
                "type": "obj",
                "desc": "1-推迟打开\n//0-推迟关闭",
            },
        ],
    },
    "tsjkezzoj9eir6xw": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ORL6E2BCxSYVpfs4": {
        "schemaExt": [
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 104, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 106, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 107, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 116, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led",
                "name": "日常灯开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "1-打开\n0-关闭",
            },
            {
                "mode": "rw",
                "code": "led_light",
                "name": "日常灯亮度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 20,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "1-最暗 20-最亮",
            },
            {
                "mode": "rw",
                "code": "time_set",
                "name": "设备时间",
                "property": {"type": "string", "maxlen": 255},
                "id": 103,
                "type": "obj",
                "desc": "ASCII (12:34:56)   0X31 0X32 0X33 0X34 0X35 0X36",
            },
            {
                "mode": "rw",
                "code": "panel_light",
                "name": "面板亮度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 2,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "0-关闭 1-白天 2-黑夜",
            },
            {
                "mode": "rw",
                "code": "Radio",
                "name": "Radio开关",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "0-关闭\n1-打开",
            },
            {
                "mode": "rw",
                "code": "volume",
                "name": "Radio音量",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 16,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "1-最低音量 16--最响",
            },
            {
                "mode": "rw",
                "code": "Radiolist",
                "name": "Radio总台数及当前播放台号",
                "id": 107,
                "type": "raw",
                "desc": "#1总台数 范围（1-60），如MCU返回未搜台（此处为0），APP显示-\n#2当前播放台号 范围（1-60），如未获得总台数，播放台号0，APP显示-",
            },
            {
                "mode": "rw",
                "code": "clock1",
                "name": "闹钟1开关",
                "property": {"type": "bool"},
                "id": 109,
                "type": "obj",
                "desc": "0--闹钟禁止--APP下发/MCU上传\n1--闹钟使能--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "Delay_time",
                "name": "推迟启动时间",
                "property": {
                    "unit": "分钟",
                    "min": 8,
                    "max": 15,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 116,
                "type": "obj",
                "desc": "默认9分钟",
            },
            {
                "mode": "rw",
                "code": "close_mode_set",
                "name": "推迟关闭模式",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "id": 117,
                "type": "obj",
                "desc": "0x00-音效+Radio；0X01-灯光；0X02-Radio，0X03-Radio+音效+灯光\n（默认值为0x03）",
            },
            {
                "mode": "rw",
                "code": "sleep",
                "name": "伴睡开关",
                "property": {"type": "bool"},
                "id": 121,
                "type": "obj",
                "desc": "0--伴睡关闭--APP下发/MCU上传\n1--伴睡打开--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "clock2",
                "name": "闹钟2开关",
                "property": {"type": "bool"},
                "id": 122,
                "type": "obj",
                "desc": "0--闹钟禁止--APP下发/MCU上传\n1--闹钟使能--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "clock3",
                "name": "闹钟3开关",
                "property": {"type": "bool"},
                "id": 123,
                "type": "obj",
                "desc": "0--闹钟禁止--APP下发/MCU上传\n1--闹钟使能--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "clock4",
                "name": "闹钟4开关",
                "property": {"type": "bool"},
                "id": 124,
                "type": "obj",
                "desc": "0--闹钟禁止--APP下发/MCU上传\n1--闹钟使能--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "Internet_time",
                "name": "网络校时",
                "property": {"type": "bool"},
                "id": 125,
                "type": "obj",
                "desc": "0--禁止--APP下发/MCU上传\n1--允许--APP下发/MCU上传",
            },
            {
                "mode": "rw",
                "code": "Radio_search",
                "name": "Radio搜台开关",
                "property": {"type": "bool"},
                "id": 126,
                "type": "obj",
                "desc": "0-搜台结束\n1-搜台开始",
            },
            {
                "mode": "rw",
                "code": "clock_set",
                "name": "闹钟设置",
                "id": 127,
                "type": "raw",
                "desc": "闹钟设置参数设置好后，按照一条dp点进行下发。\nDp点采用RAW格式，每12个字节代表1个闹钟，最多四个闹钟，按顺序累加处理，每次修改设置下发所有闹钟设置\n#1响闹（0-响闹，1-未响闹，未启用）\n#2#3时间（高低位分钟-24小时计算，例如：13：08=13*60+8）\n#4重复（0-一次，0b00000001-周一 0b01111111 周一-周日 16进制传输 0x7F）\n#5响闹持续时间（10-20范围，默认15）\n#6响闹方式（0-音效，1-音效+灯光，2-Radio，3-radio+灯光）\n#7响闹音效（1-7范围）\n#8音效音量（1-16范围）\n#9 Radio台表（1-60范围）\n#13 Radio音量 （1-16范围）\n#10唤醒灯日出时间（10-60范围）\n#11日出完成后亮度（1-20范围）\n#12支持snooze（0-支持，1-不支持 默认支持）",
            },
            {
                "mode": "rw",
                "code": "sleep_set",
                "name": "伴睡设置",
                "id": 128,
                "type": "raw",
                "desc": "1，入睡设置参数设置好后，需同时下发所有参数，mcu设计时也需注意接收全部参数。App端仅进行下发，后续由mcu自行处理；\n2，入睡持续时间结束后，mcu上报入睡开关状态。 Dp点采用RAW格式，总共10个字节，\n#1开关（此位无效，统一置1）\n#2入睡方式（音效-0x0，音效+灯-0x1，收音机-0x2，灯光+收音机-0x3）\n#3入睡音效（1-3范围）/\n#4音效音量（1-16范围）/\n#5音效持续时长（范围10-120）/\n#6radio台号（1-60范围）/\n#7radio持续时长（范围10-120）/\n#8日落起始亮度（1-20范围）/\n#9日落持续时间（范围10-120）/\n#10支持snooze（0-支持 1-不支持 默认不支持）\n（#5，#7和#9设置为同一个数值，且APP各种菜单选项保证只有一个位置可以设置，范围10-120）",
            },
            {
                "mode": "rw",
                "code": "colorLight",
                "name": "彩灯开关",
                "property": {"type": "bool"},
                "id": 129,
                "type": "obj",
                "desc": "0-关闭彩灯\n1-打开彩灯，自动模式\n",
            },
            {
                "mode": "rw",
                "code": "Delay",
                "name": "推迟开关",
                "property": {"type": "bool"},
                "id": 130,
                "type": "obj",
                "desc": "1-推迟打开\n//0-推迟关闭",
            },
        ],
    },
    "wslixzv8upponyuo": {
        "schemaExt": [
            {"id": 20, "inputStyle": "", "inputType": ""},
            {"id": 21, "inputStyle": "", "inputType": ""},
            {"id": 22, "inputStyle": "", "inputType": ""},
            {"id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "gogb05wrtredz3bs": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["auto", "manual"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "frost",
                "name": "防霜冻功能",
                "property": {"type": "bool"},
                "iconname": "icon-chushuang",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 90,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 16,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "upper_temp",
                "name": "设置温度上限",
                "property": {
                    "unit": "℃",
                    "min": 30,
                    "max": 90,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_f",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 900,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-wendu",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "lower_temp",
                "name": "设置温度下限",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 20,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_c",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_correction",
                "name": "温度校准",
                "property": {
                    "unit": "摄氏度",
                    "min": -9,
                    "max": 9,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-wendu1",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "valve_state",
                "name": "阀门状态",
                "property": {"range": ["open", "close"], "type": "enum"},
                "iconname": "icon-tcl_function_vs2",
                "id": 36,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "week_program1",
                "name": "周编程（自由式）",
                "iconname": "icon-icon-test7",
                "id": 38,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "iconname": "icon-icon-test12",
                "id": 39,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 40,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sensor_choose",
                "name": "传感器选择",
                "property": {"range": ["in", "out", "all"], "type": "enum"},
                "iconname": "icon-gongneng",
                "id": 43,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["e1", "e2", "e3"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "iconname": "icon-dp_notice",
                "id": 45,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Temp_dif",
                "name": "温差启动",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "program_mode",
                "name": "编程模式",
                "property": {"range": ["00", "52", "61", "70"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "3US5ommGBBdunoQf": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-dp_lightning",
                "id": 3,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 60000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dianliang",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 500000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_filter",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_function",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gongneng",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-tongji",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_battery",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ausyxafxj8q2evhf": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "koAASpds906awojG": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "WInTemp",
                "name": "进水温度(AIN1)",
                "property": {
                    "unit": "摄氏度或华氏度",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "change_tem",
                "name": "温度切换",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "摄氏度和华氏度切换，0为摄氏，1为华氏",
            },
            {
                "mode": "ro",
                "code": "SpeedPercentage",
                "name": "速度百分比",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "SetMode",
                "name": "设定模式",
                "property": {"range": ["smart", "warm", "cool"], "type": "enum"},
                "id": 105,
                "type": "obj",
                "desc": "0为智能模式，1为制热模式，2制冷模式",
            },
            {
                "mode": "rw",
                "code": "SetTemp",
                "name": "温度设定",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SetDnLimit",
                "name": "设定值下限",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SetUpLimit",
                "name": "设定值上限",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault1",
                "scope": "fault",
                "name": "故障1",
                "property": {
                    "label": [
                        "E1",
                        "E2",
                        "E3",
                        "E4",
                        "E5",
                        "E6",
                        "E7",
                        "E8",
                        "E9",
                        "EA",
                        "EB",
                        "ED",
                        "P0",
                        "P1",
                        "P2",
                        "P3",
                        "P4",
                        "P5",
                        "P6",
                        "P7",
                        "P8",
                        "P9",
                        "PA",
                        "F1",
                        "F2",
                        "F3",
                        "F4",
                        "F5",
                        "F6",
                        "F7",
                    ],
                    "type": "bitmap",
                    "maxlen": 30,
                },
                "id": 115,
                "type": "obj",
                "desc": "E1,E2,E3,E4,E5,E6,E7,E8,E9,EA,EB,ED,P0,P1,P2,P3,P4,P5,P6,P7,P8,P9,PA,F1,F2,F3,F4,F5,F6,F7",
            },
            {
                "mode": "ro",
                "code": "fault2",
                "scope": "fault",
                "name": "故障2",
                "property": {
                    "label": ["F8", "F9", "Fb", "Fa"],
                    "type": "bitmap",
                    "maxlen": 4,
                },
                "id": 116,
                "type": "obj",
                "desc": "F8,F9,Fb,Fa",
            },
            {
                "mode": "rw",
                "code": "SilentMdoe",
                "name": "静音模式",
                "property": {"type": "bool"},
                "id": 117,
                "type": "obj",
                "desc": "0为智能模式，1为静音模式。",
            },
            {
                "mode": "ro",
                "code": "WarmOrCool",
                "name": "制热或制冷运行",
                "property": {"type": "bool"},
                "id": 118,
                "type": "obj",
                "desc": "0为制热运行，0为制冷运行",
            },
            {
                "mode": "ro",
                "code": "OutPipeTemp",
                "name": "外盘管温度（AIN3）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 120,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ExhaustTemp",
                "name": "排气温度（AIN5）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 122,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "AmbTemp",
                "name": "外环境温度（AIN7）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 124,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompFreAct",
                "name": "压缩机运行频率",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 150,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 125,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompressorCurrent",
                "name": "压缩机电流",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 126,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "RadTemp",
                "name": "散热器温度",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 127,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "EXVPosition",
                "name": "电子膨胀阀开度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 128,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "DCFanSpeed",
                "name": "直流风机转速",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 129,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Defrost",
                "name": "除霜",
                "property": {"type": "bool"},
                "id": 130,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompRly",
                "name": "压缩机交流接触器（OUT1）",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CyclePump",
                "name": "循环水泵（OUT2）",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ReserveValve",
                "name": "四通阀(6)",
                "property": {"type": "bool"},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ChargeRly",
                "name": "限流充电继电器(9)",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ACFanSpeed",
                "name": "交流风机转速",
                "property": {
                    "range": ["LowSpeed", "MidSpeed", "HighSpeed"],
                    "type": "enum",
                },
                "id": 140,
                "type": "obj",
                "desc": "STOP，HighSpeed（OUT3），MidSpeed（OUT4），LowSpeed（OUT5），",
            },
        ],
    },
    "vnaasjg41lghvt1q": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "Gsnuuk4rq6IAt7N2": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "m3epcmf5scntddmo": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ha1dpj4b7rvglwmx": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "上报门窗开关状态",
            },
            {
                "mode": "ro",
                "code": "TamperedAlarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "mcu 上报拆除信息",
            },
            {
                "mode": "ro",
                "code": "Battery",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "mcu 上报电池电量信息",
            },
            {
                "mode": "ro",
                "code": "state",
                "name": "状态",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "上报产品是“休眠”还是“离线”",
            },
        ],
    },
    "blu5wtzapabqghjw": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "vrzgldxtfdspm1di": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ixfcioorukhda2a1": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "Rn9LxHN1NABJFXIW": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "saMa30bbTOq0nxUz": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "PIR",
                "name": "PIR",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "pir 检测",
            },
            {
                "mode": "ro",
                "code": "energy",
                "name": "供电形式",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "两种供电形式：电池供电；USB 供电",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "mcu 上报电池电量",
            },
            {
                "mode": "ro",
                "code": "TamperedAlarm",
                "name": "Tamper",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "mcu 上报拆除报警",
            },
        ],
    },
    "ljmfjahi9bbv2huq": {
        "schemaExt": [
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 13, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 16, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "ro",
                "code": "smoke_sensor_state",
                "name": "烟雾检测状态",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "【必选】\n1：烟雾报警\n2:烟雾报警解除\n\n",
            },
            {
                "mode": "ro",
                "code": "smoke_sensor_value",
                "name": "烟雾检测值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "【非必选】",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "低电故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "id": 11,
                "type": "obj",
                "desc": "【非必选】",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "id": 14,
                "type": "obj",
                "desc": "低、中、高 三种状态，低电定义为电量值少于30%，将触发低电报警",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 15,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "iconname": "icon-dp_voice",
                "id": 16,
                "type": "obj",
                "desc": "0：无消音\n1：消音",
            },
            {
                "mode": "ro",
                "code": "test",
                "name": "手动测试报警",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "1=手动报警\n0=无手动报警",
            },
        ],
    },
    "hj9rkim47obg79wr": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 12,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "x7zjh2yj6qpkqcsz": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "vzavdi0syogwmkl3": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {
                    "range": ["auto", "baby", "humidity", "manual"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "自动模式，婴儿模式，恒温模式，手动模式",
            },
            {
                "mode": "ro",
                "code": "envhumid",
                "name": "环境湿度",
                "property": {
                    "unit": "％",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_wash",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "fog",
                "name": "雾量",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7"],
                    "type": "enum",
                },
                "iconname": "icon-dp_dust",
                "id": 6,
                "type": "obj",
                "desc": "1--1格, 2--2格, 3--3格，4-4格，5-5格，6-6格，7-7格",
            },
            {
                "mode": "rw",
                "code": "anion",
                "name": "等离子",
                "property": {"type": "bool"},
                "iconname": "icon-dp_fresh",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "缺水告警",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_time2",
                "id": 13,
                "type": "obj",
                "desc": "0:取消；1-12小时。可根据产品实际功能进行设置。",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 720,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 14,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "heat",
                "name": "加热",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "nightlight",
                "name": "夜灯",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "constant_humidity",
                "name": "恒湿",
                "property": {
                    "range": [
                        "35",
                        "40",
                        "45",
                        "50",
                        "55",
                        "60",
                        "65",
                        "70",
                        "75",
                        "Co",
                        "30",
                    ],
                    "type": "enum",
                },
                "id": 103,
                "type": "obj",
                "desc": "分别对应百分比，Co为取消",
            },
            {
                "mode": "ro",
                "code": "Temp",
                "name": "室内温度",
                "property": {
                    "unit": "˚C",
                    "min": -9,
                    "max": 199,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "tem_change",
                "name": "温度切换",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
                "desc": "摄氏度和华氏度切换，0：摄氏度，1华氏度",
            },
            {
                "mode": "rw",
                "code": "screen",
                "name": "熄屏",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "不是工作模式，仅处理主机面板上的灯光控制",
            },
        ],
    },
    "qqhaaapldm2gkmcu": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "gv7d4xyhaecyriim": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2 编辑",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "jfdpqesxn6xtxpoj": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "enaacraxpq4jxcc1": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "yxejnuxiaebrqfxb": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "J4b9HONUUjrBxJXK": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ql5UbGTXqUPCmLS8": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "7cralcrcrm7yffqx": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box",
                "id": 29,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ybjo8bp4iu8sz98m": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "6n3pcwisahllpqdu": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "D8W4QZLNU3qWSvBp": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "z5xpdisimues9xzt": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "v7kc6pvepjtnmkmc": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "absc9d5b71amgowm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_filter",
                "id": 39,
                "type": "obj",
                "desc": "0：断电；\n1：通电；\n2：记忆继电器上次状态",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯模式",
                "property": {"range": ["relay", "pos", "none"], "type": "enum"},
                "iconname": "icon-dp_light",
                "id": 40,
                "type": "obj",
                "desc": "relay:状态指示,断开时关闭，接通时点亮；\npos:位置指示，断开时点亮，接通时关闭；\nnone:无指示，指示灯关闭",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 41,
                "type": "obj",
                "desc": "童锁打开发True,关闭发false",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 42,
                "type": "obj",
                "desc": "最大10个定时功能: 每10个字节代表 #1通道号（bit7--开关，bit6-bit0---通道号）/#2星期/#3#4起始时间(min)/#5#6结束时间(min)/#7#8开启时间(min)/#9#10关闭时间(min) \n星期：00(单次)01(周日)02(周一)04(周二)08(周三)10(周四)20(周五)40(周六)",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 43,
                "type": "obj",
                "desc": "最大16个定时功能：每6个字节代表 #1通道号（bit7--开关，bit6-bit0---通道号----排插位数0-6）/#2星期/#3#4起始时间(min)/#5#6结束时间(min)，最大42组\n字符型：6*2字节",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-power",
                "id": 44,
                "type": "obj",
                "desc": "每3个字节代表 #1通道号（bit7--开关，bit0-bit6---通道号）#2表示点动时间:1-60min\n",
            },
        ],
    },
    "mrcaxh3mx6pdg4bh": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "master_mode",
                "name": "主机模式",
                "property": {
                    "range": ["disarmed", "arm", "home", "sos"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 1,
                "trigger": "direct",
                "type": "obj",
                "desc": "disarmed撤防 arm布防 home在家 sos紧急",
            },
            {
                "mode": "rw",
                "code": "delay_set",
                "name": "延时设置",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "alarm_time",
                "name": "报警时长",
                "property": {
                    "unit": "s",
                    "min": 1,
                    "max": 600,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "alarm_ringtone",
                "name": "报警铃音",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7"],
                    "type": "enum",
                },
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "charge_state",
                "name": "充电状态",
                "property": {"type": "bool"},
                "id": 15,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 16,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "alarm_msg",
                "name": "告警信息",
                "property": {"type": "raw", "maxlen": 128},
                "id": 26,
                "trigger": "direct",
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_propel",
                "name": "告警推送",
                "property": {"type": "bool"},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "alarm_delay_time",
                "name": "告警后延时报警",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "master_state",
                "name": "主机状态",
                "property": {"range": ["normal", "alarm"], "type": "enum"},
                "id": 32,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "master_information",
                "name": "主机设备信息",
                "property": {"type": "raw", "maxlen": 128},
                "id": 33,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "id": 34,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sub_add",
                "name": "添加子设备",
                "property": {"type": "bool"},
                "id": 35,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sub_class",
                "name": "子设备品类",
                "property": {
                    "range": ["detector", "remote_controller"],
                    "type": "enum",
                },
                "id": 36,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sub_type",
                "name": "子设备类型",
                "property": {
                    "range": [
                        "motion_sensor",
                        "contact_sensor",
                        "smoke_alarm",
                        "gas_alarm",
                        "co_alarm",
                        "vibration_detector",
                        "water_leak_sensor",
                        "infrared_emission_detector",
                        "glass_break_detector",
                        "sos_button",
                        "remote_controller",
                        "keypad",
                        "doorbell",
                        "door_lock",
                        "rfid",
                        "alarm",
                        "environment_detector",
                        "others",
                    ],
                    "type": "enum",
                },
                "id": 37,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sub_admin",
                "name": "子设备管理",
                "property": {"type": "raw", "maxlen": 128},
                "id": 38,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "sub_state",
                "name": "子设备状态",
                "property": {
                    "range": ["normal", "alarm", "fault", "others"],
                    "type": "enum",
                },
                "id": 39,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "doorbell_ringtone",
                "name": "门铃铃声",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7"],
                    "type": "enum",
                },
                "id": 42,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "z09KPPo1BEvJTua4": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "设置温度-摄氏度",
                "property": {
                    "unit": "℃",
                    "min": 16,
                    "max": 31,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度-摄氏度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 35,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["cold", "wet", "wind", "hot"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "cold：制冷模式；wet：除湿模式；wind：送风模式；hot：制热模式；可根据产品实际功能修改功能属性。",
            },
            {
                "mode": "rw",
                "code": "windspeed",
                "name": "风速",
                "property": {"range": ["low", "med", "high"], "type": "enum"},
                "iconname": "icon-dp_wind",
                "id": 5,
                "type": "obj",
                "desc": "低风\n中风\n高风",
            },
            {
                "mode": "rw",
                "code": "anion",
                "name": "负离子",
                "property": {"type": "bool"},
                "iconname": "icon-dp_fresh",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "windshake",
                "name": "风摆1",
                "property": {"range": ["off", "on"], "type": "enum"},
                "iconname": "icon-dp_shake",
                "id": 15,
                "type": "obj",
                "desc": "开关",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["E1", "E2", "warter_full"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "iconname": "icon-dp_warming",
                "id": 20,
                "type": "obj",
                "desc": "1:室温传感器故障；2:盘管传感器故障；3：水满报警；\n",
            },
            {
                "mode": "rw",
                "code": "Sleeping_mode",
                "name": "睡眠模式",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TimerOn",
                "name": "定时开启",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 1440,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TimerOff",
                "name": "定时关闭",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 1440,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_set_f",
                "name": "设置温度-华氏度",
                "property": {
                    "unit": "℉",
                    "min": 61,
                    "max": 88,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_current_f",
                "name": "当前温度-华氏度",
                "property": {
                    "unit": "℉",
                    "min": 32,
                    "max": 95,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "funcTag",
                "scope": "fault",
                "name": "功能标记",
                "property": {
                    "label": ["0", "1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 6,
                },
                "id": 109,
                "type": "obj",
                "desc": "第一位：竖摆风 0：无竖摆风 1：竖摆风；\n第二位：横摆风 0：无横摆风 1：横摆风；\n第三位：无负离子0、负离子1；\n第四位：单冷0、冷暖1；\n第五位：风速二档0、三挡1；\n第六位：摄氏度0，华氏度1；",
            },
            {
                "mode": "rw",
                "code": "windshakeH",
                "name": "风摆2",
                "property": {"type": "bool"},
                "id": 110,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "4Db4JtAOnxbng8Fw": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "jhScexmS2WhfeOnt": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_spray",
                "name": "喷雾开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["large", "middle", "small"], "type": "enum"},
                "iconname": "icon-dp_box",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {"range": ["cancel", "1", "3", "6"], "type": "enum"},
                "iconname": "icon-dp_time2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "灯光",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "灯光模式",
                "property": {"range": ["colour", "colourful1"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光值",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch",
                "name": "总开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "okiuzzuwarvjos4a": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_5",
                "name": "开关5",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_5",
                "name": "开关5倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "pgk4kxabbmmjxxcx": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_control",
                "name": "开关控制",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "BlackLight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "AMHpt4ZBxVYlBL9w": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 18, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 19, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 24, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 25, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 27, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "情景灯开关",
                "property": {"type": "bool"},
                "iconname": "icon-deng",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "jigsujrv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "prm_content",
                "name": "湿度",
                "property": {
                    "unit": "% RH",
                    "min": 0,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "prm_temperature",
                "name": "温度",
                "property": {
                    "unit": "",
                    "min": -2000,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "b5g40alm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "PIR",
                "name": "检测状态",
                "property": {"type": "bool"},
                "id": 101,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "VCTZuoQ9Y7UjPU3s": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "n4qd0btb": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "prm_switch",
                "name": "门窗开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ceBCvy4V2acJ6UsV": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "WInTemp",
                "name": "进水温度(AIN1)",
                "property": {
                    "unit": "摄氏度或华氏度",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "change_tem",
                "name": "温度切换",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "摄氏度和华氏度切换，0为摄氏，1为华氏",
            },
            {
                "mode": "ro",
                "code": "SpeedPercentage",
                "name": "速度百分比",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "SetMode",
                "name": "设定模式",
                "property": {"range": ["smart", "warm", "cool"], "type": "enum"},
                "id": 105,
                "type": "obj",
                "desc": "0为智能模式，1为制热模式，2制冷模式",
            },
            {
                "mode": "rw",
                "code": "SetTemp",
                "name": "温度设定",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SetDnLimit",
                "name": "设定值下限",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SetUpLimit",
                "name": "设定值上限",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault1",
                "scope": "fault",
                "name": "故障1",
                "property": {
                    "label": [
                        "E1",
                        "E2",
                        "E3",
                        "E4",
                        "E5",
                        "E6",
                        "E7",
                        "E8",
                        "E9",
                        "EA",
                        "EB",
                        "ED",
                        "P0",
                        "P1",
                        "P2",
                        "P3",
                        "P4",
                        "P5",
                        "P6",
                        "P7",
                        "P8",
                        "P9",
                        "PA",
                        "F1",
                        "F2",
                        "F3",
                        "F4",
                        "F5",
                        "F6",
                        "F7",
                    ],
                    "type": "bitmap",
                    "maxlen": 30,
                },
                "id": 115,
                "type": "obj",
                "desc": "E1,E2,E3,E4,E5,E6,E7,E8,E9,EA,EB,ED,P0,P1,P2,P3,P4,P5,P6,P7,P8,P9,PA,F1,F2,F3,F4,F5,F6,F7",
            },
            {
                "mode": "ro",
                "code": "fault2",
                "scope": "fault",
                "name": "故障2",
                "property": {
                    "label": ["F8", "F9", "Fb", "Fa"],
                    "type": "bitmap",
                    "maxlen": 4,
                },
                "id": 116,
                "type": "obj",
                "desc": "F8,F9,Fb,Fa",
            },
            {
                "mode": "rw",
                "code": "SilentMdoe",
                "name": "静音模式",
                "property": {"type": "bool"},
                "id": 117,
                "type": "obj",
                "desc": "0为智能模式，1为静音模式。",
            },
            {
                "mode": "ro",
                "code": "WarmOrCool",
                "name": "制热或制冷运行",
                "property": {"type": "bool"},
                "id": 118,
                "type": "obj",
                "desc": "0为制热运行，0为制冷运行",
            },
            {
                "mode": "ro",
                "code": "OutPipeTemp",
                "name": "外盘管温度（AIN3）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 120,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ExhaustTemp",
                "name": "排气温度（AIN5）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 122,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "AmbTemp",
                "name": "外环境温度（AIN7）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 124,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompFreAct",
                "name": "压缩机运行频率",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 150,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 125,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompressorCurrent",
                "name": "压缩机电流",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 126,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "RadTemp",
                "name": "散热器温度",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 127,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "EXVPosition",
                "name": "电子膨胀阀开度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 128,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "DCFanSpeed",
                "name": "直流风机转速",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 129,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Defrost",
                "name": "除霜",
                "property": {"type": "bool"},
                "id": 130,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompRly",
                "name": "压缩机交流接触器（OUT1）",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CyclePump",
                "name": "循环水泵（OUT2）",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ReserveValve",
                "name": "四通阀(6)",
                "property": {"type": "bool"},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ChargeRly",
                "name": "限流充电继电器(9)",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ACFanSpeed",
                "name": "交流风机转速",
                "property": {
                    "range": ["LowSpeed", "MidSpeed", "HighSpeed"],
                    "type": "enum",
                },
                "id": 140,
                "type": "obj",
                "desc": "STOP，HighSpeed（OUT3），MidSpeed（OUT4），LowSpeed（OUT5），",
            },
        ],
    },
    "oncvngyc4rcmk8fh": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 38, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 38,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "fiqzdu3uua95cant": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
    },
    "tefahiby9c10n9zp": {"schemaExt": "[]", "schema": "[]"},
    "nzbkgncdndc4bcgo": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "3slpirlnlqp0bqo1": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "doorcontact_state",
                "name": "门磁",
                "property": {"type": "bool"},
                "iconname": "icon-menci",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dp_battery",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "YwZ0rfm1qN7UFdnM": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "基本-状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测-灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "基本-红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测-OSS上传",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测-总开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
    },
    "yvwaagc5u4nxz27k": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ab4kwxlrok0yvxuo": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "over_current_alarm",
                "name": "过流预警",
                "property": {"type": "bool"},
                "id": 7,
                "type": "obj",
                "desc": "当电流处于16.3A和18A之间时，预警，20秒后关闭电源",
            },
        ],
    },
    "ItNHCYOFJfD3ZzI5": {
        "schemaExt": [
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "percent"}
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "dtqeuj3iadh3jkwo": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "c0nh3LmEk0NDebrq": {
        "schemaExt": [
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_spray",
                "name": "喷雾开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["large", "small"], "type": "enum"},
                "iconname": "icon-dp_box",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {"range": ["cancel", "1", "3", "6"], "type": "enum"},
                "iconname": "icon-dp_time2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "灯光",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "灯光模式",
                "property": {"range": ["colour", "colourful1"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光值",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "fi2xhhvyod93vrnu": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "S_AlertTime",
                "name": "报警警铃时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 180,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "S_Led",
                "name": "灯光开关",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "T_Learn",
                "name": "学习模式",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "通知设备进入学习配件模式或退出学习模式",
            },
            {
                "mode": "rw",
                "code": "T_Remote",
                "name": "遥控器",
                "id": 112,
                "type": "raw",
                "desc": "遥控器名称修改及显示",
            },
            {
                "mode": "rw",
                "code": "T_Sensor",
                "name": "探测器",
                "id": 113,
                "type": "raw",
                "desc": "探测器名称、类型及状态修改和显示",
            },
            {
                "mode": "ro",
                "code": "M_Push_Short",
                "name": "报警显示推送",
                "id": 114,
                "trigger": "direct",
                "type": "raw",
                "desc": "各种探测器、遥控器推送，显示于主页面左上角",
            },
            {
                "mode": "rw",
                "code": "S_Mode",
                "name": "工作模式",
                "property": {"range": ["Arm_", "HomeArm_", "Disarm_"], "type": "enum"},
                "id": 116,
                "type": "obj",
                "desc": "设备工作模式，布防/撤防/家防",
            },
            {
                "mode": "rw",
                "code": "temperalarm",
                "name": "防拆状态",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 117,
                "type": "obj",
                "desc": "MCU会上报：被拆卸",
            },
            {
                "mode": "rw",
                "code": "POWER_DOWN",
                "name": "掉电状态",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 118,
                "type": "obj",
                "desc": "MCU会上报警笛:已掉电",
            },
            {
                "mode": "rw",
                "code": "factoryreset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "id": 119,
                "type": "obj",
                "desc": "开启/关闭",
            },
            {
                "mode": "rw",
                "code": "volume",
                "name": "警号音量",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 120,
                "type": "obj",
                "desc": "低/中/高",
            },
            {
                "mode": "rw",
                "code": "S_sound",
                "name": "声音开关",
                "property": {"type": "bool"},
                "id": 121,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Alarm_Message",
                "name": "报警消息推送",
                "id": 122,
                "type": "raw",
                "desc": "推送这个信息到手机通知栏",
            },
            {
                "mode": "ro",
                "code": "Arm_Message",
                "name": "布防消息推送",
                "id": 123,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Home_Message",
                "name": "在家布防消息推送",
                "id": 124,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Disarm_Message",
                "name": "撤防消息推送",
                "id": 125,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Detector_Power_Low",
                "name": "配件低电推送",
                "id": 126,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ALARM",
                "name": "报警",
                "property": {"type": "bool"},
                "id": 127,
                "type": "obj",
                "desc": "涂鸦其他设备联动本设备报警",
            },
            {
                "mode": "ro",
                "code": "Door_Message",
                "name": "门铃推送",
                "id": 128,
                "type": "raw",
                "desc": "门铃推送",
            },
        ],
    },
    "seqwasot": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ckud7u2l": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "目标温度",
                "property": {
                    "unit": "°C",
                    "min": 10,
                    "max": 700,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 2,
                "type": "obj",
                "desc": "实际范围为：设置温度下限-设置温度上限",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "°C",
                    "min": 0,
                    "max": 700,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-fangzi",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "holiday",
                        "auto",
                        "manual",
                        "comfort",
                        "eco",
                        "BOOST",
                        "temp_auto",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-fangzi1",
                "id": 4,
                "type": "obj",
                "desc": "假日，自动，手动，舒适，节能，BOOST，临时手动（此数据仅上报显示，不作为模式选择）",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-guanjia",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 5,
                },
                "id": 13,
                "type": "obj",
                "desc": "E1传感器故障、E2电机故障、E3电机故障、HI、LO",
            },
            {
                "mode": "rw",
                "code": "roomtemp_calibrat",
                "name": "温度校准",
                "property": {
                    "unit": "℃",
                    "min": -90,
                    "max": 90,
                    "scale": 1,
                    "step": 10,
                    "type": "value",
                },
                "id": 44,
                "type": "obj",
                "desc": "温度校准值±9℃",
            },
            {
                "mode": "rw",
                "code": "lowtemp",
                "name": "温度最低下限",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 15,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "hightemp",
                "name": "温度最高上限",
                "property": {
                    "unit": "℃",
                    "min": 16,
                    "max": 70,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "wind",
                "name": "通风条件",
                "id": 104,
                "type": "raw",
                "desc": "第一字节为通风功能开关：0表示关闭此功能，1表示开启此功能，默认值为0；第二字节为设置温度，范围为5-25℃，默认值为5℃；第三字节为阀门关闭时间，范围为5-60分钟，默认值为15分钟",
            },
            {
                "mode": "rw",
                "code": "boost",
                "name": "BOOST阀门开启时间",
                "property": {
                    "unit": "",
                    "min": 100,
                    "max": 900,
                    "scale": 0,
                    "step": 100,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "100-900秒，默认300秒",
            },
            {
                "mode": "rw",
                "code": "valve_set",
                "name": "阀门设置",
                "property": {
                    "range": ["normal", "ForceOpen", "ForceClose"],
                    "type": "enum",
                },
                "id": 106,
                "type": "obj",
                "desc": "0=阀门正常工作  1=强制全开阀门 2=强制全关阀门；此状态需显示在主界面阀门开度处.",
            },
            {
                "mode": "rw",
                "code": "comfort_temp",
                "name": "舒适温度设置",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 70,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "实际范围为：设置温度下限-设置温度上限",
            },
            {
                "mode": "rw",
                "code": "eco_temp",
                "name": "节能温度设置",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 70,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "实际范围为：设置温度下限-设置温度上限",
            },
            {
                "mode": "ro",
                "code": "valve",
                "name": "阀门状态",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_state",
                "name": "电压状态",
                "property": {"type": "bool"},
                "id": 110,
                "type": "obj",
                "desc": "0正常 1低电量",
            },
            {
                "mode": "rw",
                "code": "week_state",
                "name": "周编程类型",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 111,
                "type": "obj",
                "desc": "5+2,6+1,7",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday",
                "name": "编程-工作日参数",
                "id": 112,
                "type": "raw",
                "desc": "工作日参数:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第七个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第八字节为第3时段分钟，第九字节为第3时段设置温度...以此类推，第十六字节为第6时段开始小时，第十六个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第十七字节为第6时段分钟，第十八字节为第6时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday",
                "name": "编程-休息日参数",
                "id": 113,
                "type": "raw",
                "desc": "休息日参数:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第七个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第八字节为第3时段分钟，第九字节为第3时段设置温度...以此类推，第十六字节为第6时段开始小时，第十六个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第十七字节为第6时段分钟，第十八字节为第6时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Temp_holiday",
                "name": "假日模式-设置温度",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 70,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
                "desc": "实际范围为：设置温度下限-设置温度上限",
            },
            {
                "mode": "ro",
                "code": "windows_state",
                "name": "窗户状态",
                "property": {"type": "bool"},
                "id": 115,
                "type": "obj",
                "desc": "0=窗户正常（关闭） 1=窗户状态异常（开窗）",
            },
            {
                "mode": "rw",
                "code": "Auto_Lock",
                "name": "童锁自动锁定",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "0关闭童锁自动锁定 1开启童锁自动锁定 默认为1",
            },
            {
                "mode": "rw",
                "code": "Days_Holiday",
                "name": "假日模式-天数",
                "property": {
                    "unit": "天",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "qrlLaHWwIsZsV31f": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "WInTemp",
                "name": "进水温度(AIN1)",
                "property": {
                    "unit": "摄氏度或华氏度",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "change_tem",
                "name": "温度切换",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "摄氏度和华氏度切换，0为摄氏，1为华氏",
            },
            {
                "mode": "ro",
                "code": "SpeedPercentage",
                "name": "速度百分比",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "SetMode",
                "name": "设定模式",
                "property": {"range": ["smart", "warm", "cool"], "type": "enum"},
                "id": 105,
                "type": "obj",
                "desc": "0为智能模式，1为制热模式，2制冷模式",
            },
            {
                "mode": "rw",
                "code": "SetTemp",
                "name": "温度设定",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SetDnLimit",
                "name": "设定值下限",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SetUpLimit",
                "name": "设定值上限",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault1",
                "scope": "fault",
                "name": "故障1",
                "property": {
                    "label": [
                        "E1",
                        "E2",
                        "E3",
                        "E4",
                        "E5",
                        "E6",
                        "E7",
                        "E8",
                        "E9",
                        "EA",
                        "EB",
                        "ED",
                        "P0",
                        "P1",
                        "P2",
                        "P3",
                        "P4",
                        "P5",
                        "P6",
                        "P7",
                        "P8",
                        "P9",
                        "PA",
                        "F1",
                        "F2",
                        "F3",
                        "F4",
                        "F5",
                        "F6",
                        "F7",
                    ],
                    "type": "bitmap",
                    "maxlen": 30,
                },
                "id": 115,
                "type": "obj",
                "desc": "E1,E2,E3,E4,E5,E6,E7,E8,E9,EA,EB,ED,P0,P1,P2,P3,P4,P5,P6,P7,P8,P9,PA,F1,F2,F3,F4,F5,F6,F7",
            },
            {
                "mode": "ro",
                "code": "fault2",
                "scope": "fault",
                "name": "故障2",
                "property": {
                    "label": ["F8", "F9", "Fb", "Fa"],
                    "type": "bitmap",
                    "maxlen": 4,
                },
                "id": 116,
                "type": "obj",
                "desc": "F8,F9,Fb,Fa",
            },
            {
                "mode": "rw",
                "code": "SilentMdoe",
                "name": "静音模式",
                "property": {"type": "bool"},
                "id": 117,
                "type": "obj",
                "desc": "0为智能模式，1为静音模式。",
            },
            {
                "mode": "ro",
                "code": "WarmOrCool",
                "name": "制热或制冷运行",
                "property": {"type": "bool"},
                "id": 118,
                "type": "obj",
                "desc": "0为制热运行，0为制冷运行",
            },
            {
                "mode": "ro",
                "code": "OutPipeTemp",
                "name": "外盘管温度（AIN3）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 120,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ExhaustTemp",
                "name": "排气温度（AIN5）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 122,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "AmbTemp",
                "name": "外环境温度（AIN7）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 124,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompFreAct",
                "name": "压缩机运行频率",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 150,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 125,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompressorCurrent",
                "name": "压缩机电流",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 126,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "RadTemp",
                "name": "散热器温度",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 127,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "EXVPosition",
                "name": "电子膨胀阀开度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 128,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "DCFanSpeed",
                "name": "直流风机转速",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 129,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Defrost",
                "name": "除霜",
                "property": {"type": "bool"},
                "id": 130,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompRly",
                "name": "压缩机交流接触器（OUT1）",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CyclePump",
                "name": "循环水泵（OUT2）",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ReserveValve",
                "name": "四通阀(6)",
                "property": {"type": "bool"},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ChargeRly",
                "name": "限流充电继电器(9)",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ACFanSpeed",
                "name": "交流风机转速",
                "property": {
                    "range": ["LowSpeed", "MidSpeed", "HighSpeed"],
                    "type": "enum",
                },
                "id": 140,
                "type": "obj",
                "desc": "STOP，HighSpeed（OUT3），MidSpeed（OUT4），LowSpeed（OUT5），",
            },
        ],
    },
    "fisdfvcxqj6dr8av": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 1220,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "目标温度设置范围=设置温度最低下限值~设置温度最高上限值",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {
                    "range": ["Manual", "Program", "Holiday", "TempProg"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "手动、编程、离家、临时手动",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 5,
                },
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
                "desc": "1:设备故障\n2:内置传感器报警\n3.外置传感器报警\n4.低温保护报警\n5.高温保护报警",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "华氏度摄氏度",
                "property": {"type": "bool"},
                "iconname": "icon-a_function_fahrenhei",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Heating_state",
                "name": "加热",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Ext_temperature",
                "name": "外置温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Days_Holiday",
                "name": "离家模式-天数",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-p7",
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Settemp_Holiday",
                "name": "离家模式-设置温度",
                "property": {
                    "unit": "",
                    "min": 5,
                    "max": 122,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Hightemp_Protect",
                "name": "高温保护功能",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "LowTemp_Protect",
                "name": "低温保护功能",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ext_temp_display",
                "name": "外置温度显示功能",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "外置温度是否显示",
            },
            {
                "mode": "rw",
                "code": "room_temp_compensate",
                "name": "温度补偿",
                "property": {
                    "unit": "",
                    "min": -180,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-ziyouchengxu",
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "room_temp_zone",
                "name": "室内温度回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "low_temp_limit",
                "name": "低温保护温度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp_max",
                "name": "设置温度最高上限",
                "property": {
                    "unit": "℃",
                    "min": 20,
                    "max": 158,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "set_temp_min",
                "name": "设置温度最低下限",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 59,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "power_state",
                "name": "上电开关机状态",
                "property": {"range": ["keep", "off", "on"], "type": "enum"},
                "id": 117,
                "type": "obj",
                "desc": "keep:保持前一次状态\noff:上电设备关机\non:上电设备开机",
            },
            {
                "mode": "rw",
                "code": "Prog_Type",
                "name": "编程类型",
                "property": {"range": ["2days", "1days", "0days"], "type": "enum"},
                "id": 118,
                "type": "obj",
                "desc": "2days:5+2 5个工作日2个休息日\n1days:6+1 6个工作日1个休息日\n0days:取消编程",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday1",
                "name": "编程-工作日参数1",
                "id": 119,
                "type": "raw",
                "desc": "工作日参数1:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第3时段分钟，第三字节为第3时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday2",
                "name": "编程-工作日参数2",
                "id": 120,
                "type": "raw",
                "desc": "工作日参数2:\n第一字节为第4时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第4时段分钟，第三字节为第4时段设置温度。第四字节为第5时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第5时段分钟，第六字节为第5时段设置温度。第七字节为第6时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第6时段分钟，第三字节为第6时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday1",
                "name": "编程-休息日参数1",
                "id": 121,
                "type": "raw",
                "desc": "休息日参数1:\n第一字节为第1时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第1时段分钟，第三字节为第1时段设置温度。第四字节为第2时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第2时段分钟，第六字节为第2时段设置温度。第七字节为第3时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第3时段分钟，第三字节为第3时段设置温度。",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday2",
                "name": "编程-休息日参数2",
                "id": 122,
                "type": "raw",
                "desc": "休息日参数2:\n第一字节为第4时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第4时段分钟，第三字节为第4时段设置温度。第四字节为第5时段开始小时，第四个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第五字节为第5时段分钟，第六字节为第5时段设置温度。第七字节为第6时段开始小时，第一个字节最高位是标识位，若为1，标识设备处于该时间段的设置，若为0，则不是。第二字节为第6时段分钟，第三字节为第6时段设置温度。",
            },
        ],
    },
    "mgnfaehwo2ha3ate": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "water",
                "name": "水浸",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "上报是否漏水",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "电池剩余电量",
            },
        ],
    },
    "felfmjjaayxh0dvj": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "gbcuv4jd8sduaico": {
        "schemaExt": [
            {"complexType": "plain", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 22,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "okjnzwrgozaiuplj": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "tjOgTA5p135osloO": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "percent1"},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "W9CTnBZFjMnEatA4": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "CGJ08iaKlWqKmVuX": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "WInTemp",
                "name": "进水温度(AIN1)",
                "property": {
                    "unit": "摄氏度或华氏度",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "change_tem",
                "name": "温度切换",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "摄氏度和华氏度切换，0为摄氏，1为华氏",
            },
            {
                "mode": "ro",
                "code": "SpeedPercentage",
                "name": "速度百分比",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "SetMode",
                "name": "设定模式",
                "property": {"range": ["smart", "warm", "cool"], "type": "enum"},
                "id": 105,
                "type": "obj",
                "desc": "0为智能模式，1为制热模式，2制冷模式",
            },
            {
                "mode": "rw",
                "code": "SetTemp",
                "name": "温度设定",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SetDnLimit",
                "name": "设定值下限",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SetUpLimit",
                "name": "设定值上限",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 104,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault1",
                "scope": "fault",
                "name": "故障1",
                "property": {
                    "label": [
                        "E1",
                        "E2",
                        "E3",
                        "E4",
                        "E5",
                        "E6",
                        "E7",
                        "E8",
                        "E9",
                        "EA",
                        "EB",
                        "ED",
                        "P0",
                        "P1",
                        "P2",
                        "P3",
                        "P4",
                        "P5",
                        "P6",
                        "P7",
                        "P8",
                        "P9",
                        "PA",
                        "F1",
                        "F2",
                        "F3",
                        "F4",
                        "F5",
                        "F6",
                        "F7",
                    ],
                    "type": "bitmap",
                    "maxlen": 30,
                },
                "id": 115,
                "type": "obj",
                "desc": "E1,E2,E3,E4,E5,E6,E7,E8,E9,EA,EB,ED,P0,P1,P2,P3,P4,P5,P6,P7,P8,P9,PA,F1,F2,F3,F4,F5,F6,F7",
            },
            {
                "mode": "ro",
                "code": "fault2",
                "scope": "fault",
                "name": "故障2",
                "property": {
                    "label": ["F8", "F9", "Fb", "Fa"],
                    "type": "bitmap",
                    "maxlen": 4,
                },
                "id": 116,
                "type": "obj",
                "desc": "F8,F9,Fb,Fa",
            },
            {
                "mode": "rw",
                "code": "SilentMdoe",
                "name": "静音模式",
                "property": {"type": "bool"},
                "id": 117,
                "type": "obj",
                "desc": "0为智能模式，1为静音模式。",
            },
            {
                "mode": "ro",
                "code": "WarmOrCool",
                "name": "制热或制冷运行",
                "property": {"type": "bool"},
                "id": 118,
                "type": "obj",
                "desc": "0为制热运行，0为制冷运行",
            },
            {
                "mode": "ro",
                "code": "OutPipeTemp",
                "name": "外盘管温度（AIN3）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 120,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ExhaustTemp",
                "name": "排气温度（AIN5）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 122,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "AmbTemp",
                "name": "外环境温度（AIN7）",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 124,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompFreAct",
                "name": "压缩机运行频率",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 150,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 125,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompressorCurrent",
                "name": "压缩机电流",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 126,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "RadTemp",
                "name": "散热器温度",
                "property": {
                    "unit": "",
                    "min": -22,
                    "max": 250,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 127,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "EXVPosition",
                "name": "电子膨胀阀开度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 128,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "DCFanSpeed",
                "name": "直流风机转速",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 129,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Defrost",
                "name": "除霜",
                "property": {"type": "bool"},
                "id": 130,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CompRly",
                "name": "压缩机交流接触器（OUT1）",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "CyclePump",
                "name": "循环水泵（OUT2）",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ReserveValve",
                "name": "四通阀(6)",
                "property": {"type": "bool"},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ChargeRly",
                "name": "限流充电继电器(9)",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ACFanSpeed",
                "name": "交流风机转速",
                "property": {
                    "range": ["LowSpeed", "MidSpeed", "HighSpeed"],
                    "type": "enum",
                },
                "id": 140,
                "type": "obj",
                "desc": "STOP，HighSpeed（OUT3），MidSpeed（OUT4），LowSpeed（OUT5），",
            },
        ],
    },
    "zfz2zkwhapkb4jlo": {
        "schemaExt": [
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "2pZd6V3NJG0JWrQ3": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 3000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "E6duVoI7FfqKVcYQ": {
        "schemaExt": [
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 12, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ybewzarmqc8w2hpe": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "BHAAZ4PLhJMCZyGy": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "WindSpeed",
                "name": "风速",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-dp_wind",
                "id": 2,
                "type": "obj",
                "desc": "微风、低速、中速、高速",
            },
            {
                "mode": "rw",
                "code": "WindDirection",
                "name": "风向",
                "property": {"range": ["1", "2"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 4,
                "type": "obj",
                "desc": "摇头；静止",
            },
            {
                "mode": "rw",
                "code": "Timer",
                "name": "定时",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "定时关闭功能，最大7.5H，0.5一级",
            },
        ],
    },
    "3idmhygtjqlxcglf": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "vaojp2ky2zv8tyow": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "窗帘状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "开 关 暂停",
            }
        ],
    },
    "fwOYfIPjtUJ8kjFM": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "passive": True,
                "desc": "倒计时功能",
            },
        ],
    },
    "LORg9swzXbc1LVyN": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "oalw3cyjm7hzpc1j": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "jwpxkqvsz6c9ubrj": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
    },
    "vfkcdtdsoijt05vc": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value_1",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "brightness_min_1",
                "name": "最小亮度",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ac7ekyznhaqaipmw": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "soy18v1bwdidkell": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent1"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "wXW1mTmvFW8VCLXA": {
        "schemaExt": [{"complexType": "", "id": 2, "inputStyle": "", "inputType": ""}],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "oe0cpnjg": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {"range": ["white", "colour", "music"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ddy7a81zb1a9otk1": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "bbbslpkfnjkjgdwg": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "机器开关功能",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": ["auto", "cool", "fan", "dry", "heat"],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "工作模式分为：自动、制冷、送风、除湿、制热",
            },
            {
                "mode": "rw",
                "code": "speed",
                "name": "档位",
                "property": {"range": ["low", "mid", "high"], "type": "enum"},
                "id": 3,
                "type": "obj",
                "desc": "风速档位：低档、中档、高档",
            },
            {
                "mode": "rw",
                "code": "timer",
                "name": "定时",
                "property": {
                    "unit": "h",
                    "min": 0,
                    "max": 24,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "定时功能：可设定1-24小时开/关机及不定时",
            },
            {
                "mode": "rw",
                "code": "temp_c_set",
                "name": "温度",
                "property": {
                    "unit": "℃",
                    "min": 18,
                    "max": 32,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "sleep",
                "name": "睡眠",
                "property": {"type": "bool"},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ion",
                "name": "负离子/光触媒功能",
                "property": {"type": "bool"},
                "id": 7,
                "type": "obj",
                "desc": "负离子（光触媒）：开/关功能",
            },
            {
                "mode": "ro",
                "code": "temp_c_disp",
                "name": "室内温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["full_water", "E1", "E2"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "id": 9,
                "type": "obj",
                "desc": "full_water：满水报警；E1：室内温度传感器故障；E2：室内盘管传感器故障",
            },
            {
                "mode": "rw",
                "code": "temp_f_set",
                "name": "华氏温度设置",
                "property": {
                    "unit": "℉",
                    "min": 64,
                    "max": 90,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_f_disp",
                "name": "华氏温度显示",
                "property": {
                    "unit": "℉",
                    "min": 32,
                    "max": 122,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "ion_show",
                "name": "是否显示负离子／光触媒",
                "property": {"type": "bool"},
                "id": 12,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "mode_hot_show",
                "name": "是否显示制热模式",
                "property": {"type": "bool"},
                "id": 13,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "c_f_change",
                "name": "华氏度摄氏度切换",
                "property": {"type": "bool"},
                "id": 14,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "count_down",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1440,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 15,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "4aeadm1xijnxjsu6": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 5, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 19, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关机",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "设置温度",
                "property": {
                    "unit": "℃",
                    "min": 16,
                    "max": 32,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 99,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["Cool", "Dry", "Fan", "Heat"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "Cool, Dry, Fan, Heat",
            },
            {
                "mode": "rw",
                "code": "fan_speed_enum",
                "name": "风速",
                "property": {"range": ["Low", "Hig"], "type": "enum"},
                "iconname": "icon-a_mode_fan",
                "id": 5,
                "type": "obj",
                "desc": "Low,  Hig",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["Rtemp_fault", "IPtemp_fault", "Water_FULL"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "iconname": "icon-Panic",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Sleep",
                "name": "Sleep",
                "property": {"type": "bool"},
                "iconname": "icon-a_function_sleep",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "scxpkwfm73rokiap": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "zav1pa32pyxray78": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "遥控器开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "3lwccpx99blsjxmy": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_ratio",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "色温值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "milight",
                "name": "鑫彩翼透传",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "c4erxjcanbauavzn": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "doorcontact_state",
                "name": "门磁",
                "property": {"type": "bool"},
                "iconname": "icon-zanting",
                "id": 1,
                "type": "obj",
                "desc": "【必选】\nTrue：关\nfalse：开",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 2,
                "type": "obj",
                "desc": "【必选】",
            },
        ],
    },
    "oer8r2g6rpehj6h4": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "白光亮度",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "白光色温",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "iayz2jmtlipjnxj7": {
        "schemaExt": [
            {"complexType": "plain", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {
                "complexType": "",
                "id": 22,
                "inputStyle": "bright",
                "inputType": "percent",
            },
            {"complexType": "", "id": 23, "inputStyle": "temp", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "wifi控制器",
            },
        ],
    },
    "xaaowb3xa0ijd9dh": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
    },
    "wqhaj7e0ctvqlhg5": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ibev5hhq1icdblau": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["Breathe", "nature", "read", "night"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "breathe-呼吸灯，nature-自然光，read-阅读模式，night-夜光模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "SOS",
                "name": "SOS",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "紧急情况",
            },
        ],
    },
    "Gb0Y1YlEoDyDSqXh": {
        "schemaExt": [
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 5, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 6, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报56，实际值为0.056度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "vej1jbtsrgakumwk": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
    },
    "aqzqbhs2f5yw9fu0": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "jrlfbtvfebypwvd9": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "xs6oozaecllo3gbk": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "temp_value",
                "name": "当前温度",
                "property": {
                    "unit": "",
                    "min": -400,
                    "max": 2000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-wendu1",
                "id": 1,
                "type": "obj",
                "desc": "【必选】产品为温度传感器或温湿度传感器时该功能必选",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "iconname": "icon-a_selected",
                "id": 5,
                "type": "obj",
                "desc": "【非必选】如果硬件支持拆除检测，当发生拆除事件时，触发报警",
            },
            {
                "mode": "rw",
                "code": "temp_unit_convert",
                "name": "温标切换",
                "property": {"type": "bool"},
                "id": 9,
                "type": "obj",
                "desc": "【非必选】仅支持硬件上传℃数据",
            },
            {
                "mode": "rw",
                "code": "maxtemp_set",
                "name": "温度上限设置",
                "property": {
                    "unit": "℃",
                    "min": -400,
                    "max": 2000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "【非必选】",
            },
            {
                "mode": "rw",
                "code": "minitemp_set",
                "name": "温度下限设置",
                "property": {
                    "unit": "",
                    "min": -400,
                    "max": 2000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 11,
                "type": "obj",
                "desc": "【非必选】",
            },
            {
                "mode": "ro",
                "code": "temp_alarm",
                "name": "温度报警",
                "property": {
                    "range": ["loweralarm", "upperalarm", "lowercancel", "uppercancel"],
                    "type": "enum",
                },
                "id": 14,
                "type": "obj",
                "desc": "loweralarm：下限报警\nupperalarm：上限报警\nlowercancel：低温报警解除\nuppercancel:  高温报警解除",
            },
        ],
    },
    "75zgxageqaovbtgg": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_control",
                "name": "开关控制",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_back",
                "name": "电机转向",
                "property": {"range": ["forward", "back"], "type": "enum"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间设置",
                "property": {
                    "unit": "s",
                    "min": 10,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "a84wcpfcqo4to7e8": {
        "schemaExt": [
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"}
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "music_scane_data",
                "name": "音乐模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐界面下的音乐模式选择",
            },
        ],
    },
    "3vqszkotwygqdgu2": {
        "schemaExt": [{"complexType": "", "id": 9, "inputStyle": "", "inputType": ""}],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "27fz2sx87hf3y6nh": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "trigger": "direct",
                "type": "obj",
                "desc": "上报的为放大1000倍之后的值，即上报1000，实际值为1度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 3000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "u1zakbe32jydgwti": {
        "schemaExt": [{"complexType": "", "id": 1, "inputStyle": "", "inputType": " "}],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            }
        ],
    },
    "yaxprtktsfxnndyw": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "watersensor_state",
                "name": "水浸检测状态",
                "property": {"range": ["alarm", "normal"], "type": "enum"},
                "iconname": "icon-a_water",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "4rjtwsnrxbxxhiev": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box",
                "id": 29,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "iftitpxeagazktbn": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 29,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "5scjzkgxqhlnnlmb": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "mdk",
                "name": "门磁开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "rhwmcibq5i9qnqeq": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "Temp",
                "name": "土壤温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "湿度范围-127~128℃,上报只为0-255的值，上报值大于128的值都也负湿度值，负湿度值=255-上报值。",
            },
            {
                "mode": "ro",
                "code": "Moisure",
                "name": "土壤湿度",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Flow",
                "name": "流量传感器数据",
                "property": {
                    "unit": "L",
                    "min": 0,
                    "max": 65536,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Rain",
                "name": "降雨传感器数据显示",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "BatteryCapacity",
                "name": "主控器电量",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "WorkStatus",
                "name": "工作状态",
                "property": {"range": ["0", "1", "2", "3", "4", "5"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ManualTimer",
                "name": "灌溉时间倒计时设置",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ManualSwitch",
                "name": "灌溉控制",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "LeftTime",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Timer1",
                "name": "灌溉周定时1",
                "id": 110,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Timer2",
                "name": "灌溉周定时2",
                "id": 111,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Timer3",
                "name": "灌溉周定时3",
                "id": 112,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TimerDelay",
                "name": "灌溉延时",
                "property": {"range": ["0", "24", "48", "72"], "type": "enum"},
                "id": 113,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TimeFormat",
                "name": "周定时24/12H切换",
                "property": {"range": ["12", "24"], "type": "enum"},
                "id": 114,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "AddMoisureSensor",
                "name": "温湿度传感器添加",
                "property": {"type": "bool"},
                "id": 115,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "AddRainSensor",
                "name": "降雨传感器添加",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "MoisurePowerStatus",
                "name": "土壤温湿度传感器电量",
                "property": {"type": "bool"},
                "id": 117,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "RainPowerStatus",
                "name": "雨量传感器电量",
                "property": {"type": "bool"},
                "id": 118,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempFormat",
                "name": "温标转换",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 119,
                "type": "obj",
                "desc": "1：℃  2：℉",
            },
            {
                "mode": "ro",
                "code": "AlarmStatus",
                "scope": "fault",
                "name": "故障报警",
                "property": {
                    "label": ["0", "1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 6,
                },
                "id": 120,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "FlowCount",
                "name": "每天累计用水量统计",
                "id": 121,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "TempCount",
                "name": "温度统计数据",
                "id": 122,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "MoisureCount",
                "name": "湿度统计数据",
                "id": 123,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "RainCount",
                "name": "降雨传感器数据",
                "id": 124,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Stopirrigation",
                "name": "自动灌溉",
                "property": {"type": "bool"},
                "id": 125,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "SYS_TIME",
                "name": "系统时间",
                "id": 126,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "MCU_Version",
                "name": "系统版本",
                "property": {"type": "string", "maxlen": 255},
                "id": 127,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "next_time",
                "name": "下次灌溉时间",
                "id": 128,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "2avrf904bqtlga6a": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            }
        ],
    },
    "DUjcp4C86dglMzAr": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "jzQA5vi0nxwAK1Hd": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "dqs8oqdeccnqjfkx": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {
                "complexType": "",
                "id": 22,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 23, "inputStyle": "temp", "inputType": "percent"},
            {
                "complexType": "",
                "id": 26,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shezhi",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "wifi控制器",
            },
        ],
    },
    "kmyk8p13hiirggtv": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_control",
                "name": "开关控制",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "BlackLight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "jmj7mcderhdweyy4": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "basic_private",
                "name": "隐私模式",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 105,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\nTrue休眠，false不休眠",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 109,
                "type": "obj",
                "desc": "单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "min": 1,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-setting",
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "iconname": "icon-setting",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "min": -20000,
                    "max": 200000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-setting",
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
            {
                "mode": "rw",
                "code": "device_restart",
                "name": "设备重启",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 162,
                "type": "obj",
                "desc": "无参数，页面操作为按钮类型，用户点击远程重启，直接发送ture的命令。",
            },
            {
                "mode": "rw",
                "code": "motion_area_switch",
                "name": "报警区域开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 168,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_area",
                "name": "报警区域",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 169,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "humanoid_filter",
                "name": "人形过滤",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 170,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "alarm_message",
                "name": "告警消息上报",
                "iconname": "icon-setting",
                "id": 185,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ai_fr_switch",
                "name": "AI人脸识别",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 186,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "qfabwisay0snvehe": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "upward",
                "name": "上行通道",
                "id": 101,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "down",
                "name": "下行通道",
                "id": 102,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "znfxaaxc89zz6m5a": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {
                "complexType": "",
                "id": 22,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 23, "inputStyle": "temp", "inputType": "percent"},
            {
                "complexType": "",
                "id": 26,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shezhi",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "wifi控制器",
            },
        ],
    },
    "fcldsaadc3hzf9ey": {
        "schemaExt": [{"complexType": "", "id": 7, "inputStyle": "", "inputType": ""}],
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "fan_speed",
                "name": "风速",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 3,
                "type": "obj",
                "desc": "可根据实际档位需求扩展",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                    ],
                    "type": "enum",
                },
                "id": 6,
                "type": "obj",
                "desc": "0：取消\n1：1小时\n2：2小时\n.....",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 960,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "light",
                "name": "灯光",
                "property": {"type": "bool"},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "fan_beep",
                "name": "声音",
                "property": {"type": "bool"},
                "id": 17,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "cfgbqdd9upyrhtez": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "情景灯开关",
                "property": {"type": "bool"},
                "iconname": "icon-deng",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "情景灯模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_puzzle",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mode",
                "id": 31,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_nav_function",
                "id": 32,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 33,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 34,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 35,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 36,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_led",
                "name": "情景灯倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 37,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "vyi7ct3rfr8xv4iu": {
        "schemaExt": [
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 104, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 105, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 106, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 107, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 108, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 111, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "Switch",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "Mode",
                "property": {"range": ["Normal", "Sleep"], "type": "enum"},
                "iconname": "icon-fengli",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "fan_speed",
                "name": "Speed",
                "property": {"range": ["1", "2", "3", "4", "5", "6"], "type": "enum"},
                "iconname": "icon-a_fan_low",
                "id": 3,
                "type": "obj",
                "desc": "\nCan be expanded according to actual gear demand",
            },
            {
                "mode": "rw",
                "code": "light",
                "name": "Fan LED",
                "property": {"type": "bool"},
                "iconname": "icon-tcl_function_light",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "fan_beep",
                "name": "Beep",
                "property": {"type": "bool"},
                "iconname": "icon-dp_voice",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power",
                "name": "Power",
                "property": {
                    "unit": "Watt",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Timer_Set",
                "name": "Timer",
                "property": {
                    "unit": "minutes",
                    "min": 0,
                    "max": 600,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "Timer can maximum be set for 6 hours.",
            },
            {
                "mode": "ro",
                "code": "Speed_1_time",
                "name": "Speed_1_Runtime",
                "property": {
                    "unit": "minutes",
                    "min": 0,
                    "max": 1000000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Speed_2_time",
                "name": "Speed_2_Runtime",
                "property": {
                    "unit": "minutes",
                    "min": 0,
                    "max": 1000000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Speed_3_time",
                "name": "Speed_3_Runtime",
                "property": {
                    "unit": "minutes",
                    "min": 0,
                    "max": 1000000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Speed_4_time",
                "name": "Speed_4_Runtime",
                "property": {
                    "unit": "minutes",
                    "min": 0,
                    "max": 1000000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Speed_5_time",
                "name": "Speed_5_Runtime",
                "property": {
                    "unit": "minutes",
                    "min": 0,
                    "max": 1000000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Speed_Boost_time",
                "name": "Speed_Boost_Runtime",
                "property": {
                    "unit": "minutes",
                    "min": -10,
                    "max": 1000000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Setial_Numberr",
                "name": "Serial_Number",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Fan_SKU",
                "name": "Fan_SKU",
                "property": {"type": "string", "maxlen": 255},
                "id": 110,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "Fault_code",
                "name": "Fault_code",
                "property": {
                    "unit": "Number",
                    "min": 0,
                    "max": 1000000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "Read_Fan_timer",
                "name": "Read_Fan_timer",
                "property": {"type": "bool"},
                "id": 112,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "wka3btln8htuy8h9": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "894vueeesscugsdu": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yinliang",
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "h6qp8pnvl0xa5tnc": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
    },
    "a4vhzrfgo2rzsi2s": {
        "schemaExt": [
            {"complexType": "plain", "id": 101, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 105,
                "inputStyle": "plain",
                "inputType": "countdown1",
            },
            {
                "complexType": "",
                "id": 110,
                "inputStyle": "plain",
                "inputType": "countdown1",
            },
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "开关到底控制",
                "property": {"range": ["off", "max"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "off：关到底；\nmax：开到底；",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "开启百分比控制",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 5,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "percent_state",
                "name": "开启百分比状态",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "max_state",
                "name": "开到底状态",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "off_state",
                "name": "关到底状态",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "failure_warning",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["motor_fault"], "type": "bitmap", "maxlen": 1},
                "id": 108,
                "type": "obj",
                "desc": "电机故障",
            },
            {
                "mode": "rw",
                "code": "countdown_on",
                "name": "默认倒计时开启",
                "property": {"type": "bool"},
                "id": 109,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_set",
                "name": "默认倒计时设置",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "显示xx小时xx分钟xx秒",
            },
            {
                "mode": "ro",
                "code": "water_month",
                "name": "月浇水量",
                "property": {
                    "unit": "L",
                    "min": 0,
                    "max": 10000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "time_month",
                "name": "月使用时长",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 2592000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 112,
                "trigger": "direct",
                "type": "obj",
                "desc": "显示使用XX小时XX分钟",
            },
        ],
    },
    "d8naw2l1edqwhvuu": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "scene_type",
                "name": "scene_type",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "91aksdftymyl3bol": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_send",
                "name": "红外控制下发",
                "property": {"type": "string", "maxlen": 3072},
                "id": 201,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "ir_study_code",
                "name": "红外学习值上报",
                "id": 202,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "J2BHg3CbAibO902n": {
        "schemaExt": [
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "237mvcniwsrjgqhl": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_control",
                "name": "switch control",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间设置",
                "property": {
                    "unit": "s",
                    "min": 10,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "BlackLight",
                "name": "BackLight",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "背光可控",
            },
        ],
    },
    "xc6djbkdcenxt2vs": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "hzS2YW9iT4NbpyKA": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_s1",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_s2",
                "name": "开关 2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_s3",
                "name": "开关 3",
                "property": {"type": "bool"},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "id": 4,
                "type": "obj",
                "desc": "switch_s4修改为switch_usb1",
            },
        ],
    },
    "dtxprloz8g3zkgzw": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {
                "complexType": "",
                "id": 22,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 23, "inputStyle": "temp", "inputType": "percent"},
            {
                "complexType": "",
                "id": 26,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shezhi",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "wifi控制器",
            },
        ],
    },
    "g3fkaqusj90iay1g": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "imk0pcrtmyx9cbfg": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "开关机控制。\n下发： 发送控制指令给主机，主机依据指令状态进行开关机操作。\n上报：\n当主机使用遥控器关机或者长时间静止进入关机状态后，主机会上报一个关机数据。\n当主机处于关机状态时，通过遥控器或者触摸主机的按键，主机会进入开机状态，主机会上报一个开机数据。",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                    ],
                    "type": "bitmap",
                    "maxlen": 16,
                },
                "id": 11,
                "type": "obj",
                "desc": "0:无报警1:主动轮过载 2:前跌落触发 3:左跌落触发 4:右跌落触发 5:机器离地 6:左碰撞卡住 7:右碰撞卡住 8:边刷缠绕 9:电量低于20% 10:尘盒未安装 11:风扇异常 12:滚刷异常 13:电池故障14:水箱未安装 15:地磁异常 16:机器人打滑",
            },
            {
                "mode": "ro",
                "code": "electricity_left",
                "name": "电量",
                "property": {
                    "unit": "％",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 14,
                "type": "obj",
                "desc": "机器定时上报电量百分比， 0% - 100%",
            },
            {
                "mode": "rw",
                "code": "power_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "id": 25,
                "type": "obj",
                "desc": "0:暂停 1:工作",
            },
            {
                "mode": "rw",
                "code": "direction_control",
                "name": "清扫方向",
                "property": {
                    "range": ["foward", "backward", "turn_left", "turn_right", "stop"],
                    "type": "enum",
                },
                "id": 26,
                "type": "obj",
                "desc": "前／后／左／右／停",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "standby",
                        "smart",
                        "spiral",
                        "single",
                        "wall_follow",
                        "chargego",
                    ],
                    "type": "enum",
                },
                "id": 27,
                "type": "obj",
                "desc": "空闲模式（清除选中）、自动模式、定点模式、单间模式、沿边模式、回充模式",
            },
            {
                "mode": "ro",
                "code": "status",
                "name": "工作状态",
                "property": {
                    "range": [
                        "standby",
                        "working",
                        "fault",
                        "sleep",
                        "workcompleted",
                        "charging",
                        "chargecompleted",
                        "pause",
                        "cleanning",
                        "mopping",
                        "docking",
                    ],
                    "type": "enum",
                },
                "id": 28,
                "type": "obj",
                "desc": "0: 待机 1: 工作中 2: 故障 3: 休眠 4: 工作完成 5: 充电 6: 充电完成 7:暂停  8:清扫中 9:拖地中 10:回充中",
            },
            {
                "mode": "wr",
                "code": "seek",
                "name": "定位机器人",
                "property": {"type": "bool"},
                "id": 29,
                "type": "obj",
                "desc": "App触发下发1",
            },
            {
                "mode": "rw",
                "code": "suction",
                "name": "清扫强度",
                "property": {"range": ["low", "normal", "high"], "type": "enum"},
                "id": 30,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "voice_switch",
                "name": "静音",
                "property": {"type": "bool"},
                "id": 31,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "clean_area",
                "name": "清扫面积",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 32,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "clean_time",
                "name": "清扫时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 33,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "clean_record",
                "name": "清扫记录",
                "property": {"type": "string", "maxlen": 255},
                "id": 34,
                "type": "obj",
                "desc": '清扫日期YYYYMMDDTTRR + 清扫时长XXX + 清扫面积XXX + 地图IDXXXXX 如： "20180411051102008000020" 代表2018年4月11日05点11分，清扫了20分钟，80平方米 ，id号为20 （假如MCU没有RTC，时间可不上报。记录则默认显示为数据上报时间）',
            },
        ],
    },
    "wqz93nrdomectyoz": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "pir_state",
                "name": "人体感应状态",
                "property": {"range": ["pir"], "type": "enum"},
                "iconname": "icon-yundong",
                "id": 1,
                "type": "obj",
                "desc": "【必选】1：有人触发\n",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
                "desc": "【非必选】\n0:低电量\n1:中电量\n2:高电量",
            },
        ],
    },
    "ajlhq0rixh0nythp": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
                "desc": "send_ir:码库红外码发送\nstudy:进入学习状态\nstudy_exit:退出学习状态\nstudy_key:学习获取到的红外码发送",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习上报参数",
                "id": 2,
                "type": "raw",
                "desc": "用于学习功能数据上报",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "遥控器解码参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
                "desc": "用于搭配按键参数解码使用",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键同时下发",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
                "desc": "仅用于机顶盒多个按键下发",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "ju6wwggaa5xqvsae": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_alarm",
                "name": "温度预警",
                "property": {"type": "bool"},
                "id": 7,
                "type": "obj",
                "desc": "当设备温度高于某限定值时，设备上报此DP点，触发温度预警消息推送",
            },
        ],
    },
    "v68uqkgvibcx1yge": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关机",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "开关",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "设置温度",
                "property": {
                    "unit": "℃",
                    "min": 16,
                    "max": 32,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 99,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["Cool", "Dry", "Heat", "Auto"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "fan_speed_enum",
                "name": "风速",
                "property": {"range": ["Low", "Hig"], "type": "enum"},
                "iconname": "icon-a_mode_fan",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "windshake",
                "name": "摆风",
                "property": {"range": ["OFF", "ON"], "type": "enum"},
                "iconname": "icon-dp_shake",
                "id": 15,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["Rtemp_fault", "IPtemp_fault", "Water_FULL"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "iconname": "icon-Panic",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Sleep",
                "name": "睡眠",
                "property": {"type": "bool"},
                "iconname": "icon-a_function_sleep",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "seaalzavunjqan2f": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_control",
                "name": "开关控制",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_back",
                "name": "电机转向",
                "property": {"range": ["forward", "back"], "type": "enum"},
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间设置",
                "property": {
                    "unit": "s",
                    "min": 10,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "fqSYZSABYZyqjjZE": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "基本-状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n设备指示灯是否打开，True打开，false关闭",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测-灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_wdr",
                "name": "基本-宽动态范围模式（WDR）",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
                "desc": "True则打开宽动态范围模式，false则关闭宽动态范围",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "基本-红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测-OSS上传",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测-总开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "doorbell_active",
                "name": "门铃-呼叫",
                "property": {"type": "string", "maxlen": 255},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "wireless_electricity",
                "name": "低功耗-电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 145,
                "type": "obj",
                "desc": "设备主动上报当前电量，电量发生变化时上报。类型为数值型，上报0-100的整数。app会处理成百分比。\n",
            },
            {
                "mode": "ro",
                "code": "wireless_powermode",
                "name": "低功耗-供电方式",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 146,
                "type": "obj",
                "desc": "设备主动上报当前供电状态，供电状态发生变化时上报。0为电池供电状态，1为插电供电状态（或电池充电状态）",
            },
            {
                "mode": "rw",
                "code": "wireless_lowpower",
                "name": "低功耗-低电报警",
                "property": {
                    "unit": "",
                    "min": 20,
                    "max": 50,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 147,
                "type": "obj",
                "desc": "若电量百分比低于该阈值，则触发报警；App端设置，设备本身无须关心该dp点。",
            },
            {
                "mode": "rw",
                "code": "wireless_awake",
                "name": "低功耗-唤醒状态",
                "property": {"type": "bool"},
                "id": 149,
                "type": "obj",
                "desc": "设备主动上报当前低功耗是否处于唤醒状态。类型为布尔型，True为唤醒状态，false为休眠状态。（设备休眠前上报false，设备唤醒后上报一次True）",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "ro",
                "code": "doorbell_pic",
                "name": "门铃-抓拍图片",
                "id": 154,
                "type": "raw",
                "desc": "用户按下门铃，抓拍图片并上传",
            },
            {
                "mode": "rw",
                "code": "talk_volume",
                "name": "对讲音量控制",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 10,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 160,
                "type": "obj",
                "desc": "控制设备端播放对讲声音的音量",
            },
        ],
    },
    "ly3zo7mlczeq8vkg": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "qCtDRErfUiSCsExB": {
        "schemaExt": [
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 105, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB 1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "342sd0qc12eci4sd": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "WindSpeed",
                "name": "风速",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "8", "9"],
                    "type": "enum",
                },
                "iconname": "icon-dp_wind",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Windmode",
                "name": "风类",
                "property": {
                    "range": ["sleep", "heavy", "fresh", "close"],
                    "type": "enum",
                },
                "iconname": "icon-dp_shake",
                "id": 3,
                "type": "obj",
                "desc": "睡眠风，强劲风,自然风",
            },
            {
                "mode": "rw",
                "code": "Windleftright",
                "name": "水平风",
                "property": {"type": "bool"},
                "iconname": "icon-dp_loop",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Timer",
                "name": "倒计时",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
                    "type": "enum",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "1-8",
            },
            {
                "mode": "ro",
                "code": "Countdown",
                "name": "倒计时",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 480,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5", "6", "7"],
                    "type": "bitmap",
                    "maxlen": 7,
                },
                "iconname": "icon-dp_warming",
                "id": 13,
                "type": "obj",
                "desc": "E1：母线欠压  E2:母线过压  E3:电机堵转  E4：硬件过流  E5：软件过流   E7：缺相故障  E8:通讯故障",
            },
            {
                "mode": "rw",
                "code": "voice",
                "name": "声音",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "0bdu4wzpy2ahqdwk": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 5, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 6, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "Timer",
                "property": {
                    "unit": "sec",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 2,
                "type": "obj",
                "passive": True,
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "Electricity",
                "property": {
                    "unit": "kW*h",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-dp_calendar",
                "id": 3,
                "type": "obj",
                "desc": "上报的为放大100倍之后的值，即上报56，实际值为0.56度",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "Current ",
                "property": {
                    "unit": "A",
                    "min": 0,
                    "max": 10000,
                    "scale": 0,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-dp_lightning",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "Power",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 34000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "Voltage",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 25000,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "sOGcriojabRHDvFH": {
        "schemaExt": [
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "fan_switch",
                "name": "风扇开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "speed_value",
                "name": "风速",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "灯开关",
                "property": {"type": "bool"},
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Countdown",
                "name": "倒计时",
                "property": {
                    "unit": "分钟",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "lqo71fvxmaugesup": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "themes： Focused, Natural, Active, Calm, Romantic, Cheerful, Playful, Floating, Mellow, 支持可编辑，最多十个场景",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "white_color",
                "name": "白光常用",
                "property": {"range": ["White1", "White2", "White3"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "full_color",
                "name": "彩光常用",
                "property": {"range": ["Color1", "Color2", "Color3"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "wakeup_mode",
                "name": "唤醒模式/淡入",
                "property": {"type": "string", "maxlen": 255},
                "id": 103,
                "type": "obj",
                "desc": '"支持设置开始时间，12/24小时制可随手机设置时间切换；\n支持可选周一至周日；\n时间范围：5m；10m；15m；20m；30m；1h。每分钟上报一次"\n',
            },
            {
                "mode": "rw",
                "code": "sleep_mode",
                "name": "入睡模式/淡出",
                "property": {"type": "string", "maxlen": 255},
                "id": 104,
                "type": "obj",
                "desc": '"支持设置开始时间，12/24小时制可随手机设置切换；\n支持可选周一至周日；\n时间范围：5m；10m；15m；20m；30m；1h。每分钟上报一次"\n',
            },
        ],
    },
    "dSIgaSUra05PwKAp": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "weightcount",
                "name": "weight count",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "time",
                "name": "time",
                "property": {"type": "string", "maxlen": 255},
                "id": 102,
                "type": "obj",
                "desc": "年月日时分秒",
            },
            {
                "mode": "rw",
                "code": "weight",
                "name": "weight",
                "property": {
                    "unit": "g",
                    "min": 0,
                    "max": 180000,
                    "scale": 3,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "LResistance",
                "name": "lefthand_R",
                "property": {
                    "unit": "欧姆",
                    "min": 0,
                    "max": 65535,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "RHR",
                "name": "Righthand_R",
                "property": {
                    "unit": "欧姆",
                    "min": 0,
                    "max": 655435,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "LLR",
                "name": "leftleg_R",
                "property": {
                    "unit": "欧姆",
                    "min": 0,
                    "max": 65535,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "RLR",
                "name": "Rightleg_R",
                "property": {
                    "unit": "欧姆",
                    "min": 0,
                    "max": 65535,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "BR",
                "name": "Body_R",
                "property": {
                    "unit": "欧姆",
                    "min": 0,
                    "max": 65535,
                    "scale": 3,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "battery",
                "name": "电量",
                "property": {"type": "bool"},
                "id": 109,
                "type": "obj",
                "desc": "00/01",
            },
        ],
    },
    "brq2wzq1tvssfuyr": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测-灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "基本-红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测-OSS上传",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测-总开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
        ],
    },
    "e6gggmwauyafassy": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n使直播画面垂直翻转，True打开翻转，false关闭翻转",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
                "desc": "设备设置页面-基本功能设置\n时间水印功能开关，True打开水印，false关闭水印",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
                "desc": "0-2，灵敏度依次增加；仅为灵敏度，0并不是关闭移动侦测报警；规定0为低灵敏度，1为中灵敏度，2为高灵敏度。",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
                "desc": "0:自动\n1:关\n2:开",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
                "desc": "示例：\n---2017.07.08更新---\n单位改为kb\n---\n3503775744|778977280|2718158848\n其中第一字符串是总容量，第二个字符串是已使用的容量，第三个是剩余容量",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
                "desc": "status：sd卡状态，1-正常，2-异常，3-空间不足，4-正在格式化，5-无SD卡；",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
                "desc": "无参数",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
                "desc": 't_start:开始时间；t_end:结束时间。多个时间由";"分隔',
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
                "desc": '该功能实现请参考SDK\n---------------\n{"dp_id","bucket;object;key"}/{"dp_id","bucket;object;"}\n\nbucket:根文件夹；objcet:文件路径；key:加密',
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
                "desc": "返回错误码：\n-2000：SD卡正在格式化\n-2001：SD卡格式化异常\n-2002：无SD卡\n-2003：SD卡错误\n\n//正数为格式化进度",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
                "desc": "True为定时移动侦测，false为全天移动侦测",
            },
            {
                "mode": "ro",
                "code": "doorbell_active",
                "name": "门铃-呼叫",
                "property": {"type": "string", "maxlen": 255},
                "id": 136,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像开关，True为打开，false为关闭\n功能关闭时，不录像到SD卡",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
                "desc": "设备设置页面-存储卡设置\nSD卡录像模式选择，1为事件录像（检测到移动再录像到SD卡），2为连续录像",
            },
            {
                "mode": "ro",
                "code": "doorbell_pic",
                "name": "门铃抓拍图片",
                "id": 154,
                "type": "raw",
                "desc": "用户按下门铃，抓拍图片并上传",
            },
            {
                "mode": "rw",
                "code": "alarm_message",
                "name": "告警消息上报",
                "id": 185,
                "type": "raw",
                "desc": "",
            },
        ],
    },
    "daqzeeihegmsjvbn": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "WindSpeed",
                "name": "风速",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_wind",
                "id": 2,
                "type": "obj",
                "desc": "1-3级风速。可根据产品实际功能进行修改。",
            },
            {
                "mode": "rw",
                "code": "Windmode",
                "name": "风类",
                "property": {"range": ["standard", "sleep", "natural"], "type": "enum"},
                "iconname": "icon-dp_shake",
                "id": 3,
                "type": "obj",
                "desc": "标准风，睡眠风，自然风  开机默认是标准风",
            },
            {
                "mode": "rw",
                "code": "Windleftright",
                "name": "水平风",
                "property": {"type": "bool"},
                "iconname": "icon-dp_loop",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "NowTemp",
                "name": "当前温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Timer",
                "name": "倒计时",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
                    "type": "enum",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "0:取消；1-8小时。可根据产品实际功能进行修改。",
            },
            {
                "mode": "ro",
                "code": "Countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 540,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "negative",
                "name": "负离子",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "负离子开关",
            },
            {
                "mode": "ro",
                "code": "unit",
                "name": "温度单位",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 102,
                "type": "obj",
                "desc": "0=摄氏度  1=华氏度",
            },
        ],
    },
    "qjhnqmbmipjnrv75": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
                "desc": "white：白光模式；colour：彩光模式；scene：场景模式；scene1-4:不同场景模式切换；可根据产品实际功能更改。",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "oedbumjmptbajtqz": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "bright_state",
                "name": "当前亮度级别",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dp_light2",
                "id": 1,
                "trigger": "direct",
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "bright_value",
                "name": "当前亮度值",
                "property": {
                    "unit": "lux",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "7c35xxu0foeqpdka": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "sryo5vtdwhi1r2h9": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Light",
                "name": "灯光",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_time2",
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "dp_mist_grade",
                "name": "雾量",
                "property": {"range": ["small", "big", "off"], "type": "enum"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光值",
                "property": {"type": "string", "maxlen": 255},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "灯光模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene1",
                        "scene2",
                        "scene3",
                        "scene4",
                    ],
                    "type": "enum",
                },
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "lightmode",
                "name": "灯光模式",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "setlight",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
            },
        ],
    },
    "zo7k5xd87yciwk6p": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "overload_alarm",
                "name": "超载预警",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "当电流大于某阈值时，关闭AC输出，并预警",
            },
            {
                "mode": "ro",
                "code": "usb_overload_alarm",
                "name": "USB过流预警",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
                "desc": "当USB电流大于某阈值后，关闭USB输出，并预警",
            },
        ],
    },
    "xuzcvlku": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制",
                "property": {
                    "range": ["open", "stop", "close", "continue"],
                    "type": "enum",
                },
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "开启百分比控制",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_back",
                "name": "电机反向",
                "property": {"range": ["forward", "back"], "type": "enum"},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "work_state",
                "name": "工作状态",
                "property": {"range": ["opening", "closing"], "type": "enum"},
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "故障告警",
                "property": {"label": ["motor_fault"], "type": "bitmap", "maxlen": 1},
                "id": 12,
                "type": "obj",
            },
        ],
    },
    "icygzrleh60pt3ij": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_circle",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_backlight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 16,
                "type": "obj",
            },
        ],
    },
    "fuuwiyxzvauhcofx": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "pause",
                "name": "暂停/继续",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_charge",
                "name": "回充开关",
                "property": {"type": "bool"},
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": ["smart", "chargego", "zone", "pose", "part"],
                    "type": "enum",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "status",
                "name": "当前状态",
                "property": {
                    "range": [
                        "standby",
                        "smart",
                        "zone_clean",
                        "part_clean",
                        "cleaning",
                        "paused",
                        "goto_pos",
                        "pos_arrived",
                        "pos_unarrive",
                        "goto_charge",
                        "charging",
                        "charge_done",
                        "sleep",
                    ],
                    "type": "enum",
                },
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "clean_time",
                "name": "Cleaning time",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 9999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "clean_area",
                "name": "Sweeping area",
                "property": {
                    "unit": "㎡",
                    "min": 0,
                    "max": 9999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "residual_electricity",
                "name": "Electricity",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "suction",
                "name": "Suction",
                "property": {
                    "range": ["strong", "normal", "gentle", "closed"],
                    "type": "enum",
                },
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cistern",
                "name": "Water quantity",
                "property": {
                    "range": ["low", "middle", "high", "closed"],
                    "type": "enum",
                },
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "seek",
                "name": "Looking for machines",
                "property": {"type": "bool"},
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "direction_control",
                "name": "Cleaning direction",
                "property": {
                    "range": ["foward", "backward", "turn_left", "turn_right", "stop"],
                    "type": "enum",
                },
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "reset_map",
                "name": "Reset Map",
                "property": {"type": "bool"},
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "path_data",
                "name": "路径传输",
                "id": 14,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "command_trans",
                "name": "指令传输",
                "id": 15,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "request",
                "name": "请求数据",
                "property": {
                    "range": ["get_map", "get_path", "get_both"],
                    "type": "enum",
                },
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "edge_brush",
                "name": "Residual life of edge brush",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 900,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "reset_edge_brush",
                "name": "Edge brush reset",
                "property": {"type": "bool"},
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "roll_brush",
                "name": "Residual life of roller brush",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 1800,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "reset_roll_brush",
                "name": "Roller reset",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "filter",
                "name": "Remaining life of filter element",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 900,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "reset_filter",
                "name": "Screen reset",
                "property": {"type": "bool"},
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "duster_cloth",
                "name": "Residual life of mop life",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 900,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "reset_duster_cloth",
                "name": "Mop reset",
                "property": {"type": "bool"},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_disturb",
                "name": "Do not disturb switch",
                "property": {"type": "bool"},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "volume_set",
                "name": "Volume Setting ",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "break_clean",
                "name": "Breakpoint continuous scanning",
                "property": {"type": "bool"},
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "故障上报",
                "property": {
                    "label": [
                        "edge_sweep",
                        "middle_sweep",
                        "left_wheel",
                        "right_wheel",
                        "garbage_box",
                        "land_check",
                        "collision",
                    ],
                    "type": "bitmap",
                    "maxlen": 7,
                },
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "ewyqiiav45ecteck": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "Switch",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "start",
                "name": "启动/停止",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "Cooking Mode",
                "property": {
                    "range": [
                        "chips",
                        "drumsticks",
                        "shrimp",
                        "fish",
                        "ribs",
                        "meat",
                        "cake",
                        "steak",
                        "bread",
                        "roast_chicken",
                        "dried_fruits",
                        "sausage",
                        "pizza",
                    ],
                    "type": "enum",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cloud_recipe_number",
                "name": "Cloud Recipe",
                "property": {
                    "min": 0,
                    "max": 999999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "status",
                "name": "设备状态",
                "property": {
                    "range": ["standby", "appointment", "cooking", "done"],
                    "type": "enum",
                },
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cook_temperature",
                "name": "Cooking Temperature",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "Temp current",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "appointment_time",
                "name": "Scheduled Time",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cook_time",
                "name": "Cooking Time",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "remain_time",
                "name": "Remaining Time",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "multistep",
                "name": "Multi-step",
                "id": 11,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "Fault Alarm",
                "property": {"label": ["motor_fault"], "type": "bitmap", "maxlen": 1},
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "pause",
                "name": "Pause",
                "property": {"type": "bool"},
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_unit_convert",
                "name": "Temp unit convert",
                "property": {"range": ["c", "f"], "type": "enum"},
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "preheat",
                "name": "Preheat",
                "property": {"type": "bool"},
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cooking_report",
                "name": "烹饪结果上报",
                "id": 16,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "cooking_history",
                "name": "烹饪历史",
                "property": {
                    "min": 0,
                    "max": 999999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 17,
                "type": "obj",
            },
        ],
    },
    "qoqolwtqzfuhgghq": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "nqvhejakb112obkn": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "7BCNHFTrP6BsTils": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "5EXbeqW1nAwchNSh": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "PowerOnOff",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "SetTemp",
                "name": "设置温度",
                "property": {
                    "unit": "",
                    "min": 40,
                    "max": 400,
                    "scale": 0,
                    "step": 5,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "TempShow",
                "name": "当前温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "SetTime",
                "name": "设置时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "RemainingTime",
                "name": "倒计时显示",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 5999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "TempChanger",
                "name": "温度切换",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "CookBook",
                "name": "菜谱",
                "property": {
                    "range": [
                        "standby",
                        "custom",
                        "fries",
                        "frozen",
                        "nuggets",
                        "poultry",
                        "steak",
                        "fish",
                    ],
                    "type": "enum",
                },
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "start_stop",
                "name": "启动暂停",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
        ],
    },
    "mdetorqftcwsfmvk": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_5",
                "name": "开关5",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_6",
                "name": "开关6",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_5",
                "name": "开关5倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_6",
                "name": "开关6倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 14,
                "type": "obj",
            },
        ],
    },
    "ikfjwqdbpnh154b9": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "doorcontact_state",
                "name": "门磁状态",
                "property": {"type": "bool"},
                "iconname": "icon-menci",
                "id": 1,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dp_battery",
                "id": 3,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "oo2ugbe5sfeposdg": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "pinsvptg45pud3fa": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music", "smooth", "flash"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mic_sense",
                "name": "麦克风灵敏度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "change_speed",
                "name": "变化速度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_type",
                "name": "音乐风格",
                "property": {"range": ["soft", "classic", "rock"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
        ],
    },
    "tsbguim4trl6fa7g": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "over_load",
                "name": "超载预警",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "usb_overload_alarm",
                "name": "USB超载预警",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
            },
        ],
    },
    "x8clzasuxcuxw3wm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "wzyfe2kyxn6tiso7": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "tazmr15qtnkeszbb": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关 2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_circle",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_backlight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 16,
                "type": "obj",
            },
        ],
    },
    "Jm5pbvaDrH4ZjHoT": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": "percent"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "jams1ipuwvvgfak4": {
        "schemaExt": [
            {
                "complexType": "",
                "id": 9,
                "inputStyle": "plain",
                "inputType": "countdown",
            }
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "iconname": "icon-dp_battery",
                "id": 38,
                "type": "obj",
            },
        ],
    },
    "dmio4g59ievwpjl5": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "power_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": ["standby", "smart", "wall_follow", "spiral", "chargego"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "direction_control",
                "name": "方向",
                "property": {
                    "range": ["foward", "backward", "turn_left", "turn_right", "stop"],
                    "type": "enum",
                },
                "iconname": "icon-dp_wind",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "status",
                "name": "工作状态",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6"],
                    "type": "enum",
                },
                "iconname": "icon-dp_dust",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_left",
                "name": "剩余电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_up",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "seek",
                "name": "寻找机器",
                "property": {"type": "bool"},
                "iconname": "icon-dp_curve",
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "clean_record",
                "name": "清扫记录",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "clean_area",
                "name": "清扫面积",
                "property": {
                    "unit": "㎡",
                    "min": 1,
                    "max": 9999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_voice",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "clean_time",
                "name": "清扫时间",
                "property": {
                    "unit": "分",
                    "min": 0,
                    "max": 9999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_warming",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                    ],
                    "type": "bitmap",
                    "maxlen": 19,
                },
                "iconname": "icon-dp_time2",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "map_config",
                "name": "地图参数",
                "iconname": "icon-dp_time",
                "id": 19,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "water_sction",
                "name": "风量\\水量显示",
                "property": {"range": ["low", "nar", "high"], "type": "enum"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "4lq5qbjyhaagznly": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": "percent"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
        ],
    },
    "ykrdxsidvbuvqs4t": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "设备控制",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "iconname": "icon-a_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间",
                "property": {
                    "unit": "s",
                    "min": 10,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "backlight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "cpdqvgpovcwtsanl": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 8, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "设备控制",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "iconname": "icon-a_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "开启百分比控制",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "iconname": "icon-icon-percent",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_back",
                "name": "电机反转",
                "property": {"range": ["forward", "back"], "type": "enum"},
                "iconname": "icon-dp_loop",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间设置",
                "property": {
                    "unit": "s",
                    "min": 1,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "0m1jxjnbneks33ll": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐律动",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "ozh2kyiwl2tacrct": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
            },
        ],
    },
    "naamo0ghl6opgtss": {
        "schemaExt": "[]",
        "schema": [
            {"mode": "ro", "code": "upward", "name": "上行通道", "id": 101, "type": "raw"},
            {"mode": "wr", "code": "down", "name": "下行通道", "id": 102, "type": "raw"},
        ],
    },
    "ip9ganvw": {
        "schemaExt": [
            {"complexType": "duration", "id": 101, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "prm_switch",
                "name": "开合状态",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "j3os8sm7rft3qesu": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "percent1"},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": "percent"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "deetibst": {
        "schemaExt": [
            {"complexType": "duration", "id": 101, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "PIR",
                "name": "检测状态",
                "property": {"type": "bool"},
                "iconname": "icon-yundong",
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "1g3tawnp": {
        "schemaExt": [
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "ro",
                "code": "prm_content",
                "name": "湿度",
                "property": {
                    "unit": "% RH",
                    "min": 0,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "prm_temperature",
                "name": "温度",
                "property": {
                    "unit": "℃",
                    "min": -4000,
                    "max": 20000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "fbvia0apnlnattcy": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": "countdown"},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 18, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 19, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 24, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 25, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "ssuwgkrhhhuyr7gf": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "g56afofns8lpko6v": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box",
                "id": 29,
                "type": "obj",
            },
        ],
    },
    "1jlpstyg": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
        ],
    },
    "pxv3tb0anznpkg27": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "status",
                "name": "窗帘状态",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 1,
                "type": "obj",
            }
        ],
    },
    "jy1fouaotli8f7do": {
        "schemaExt": "[]",
        "schema": [
            {"mode": "ro", "code": "upward", "name": "上行通道", "id": 101, "type": "raw"},
            {"mode": "wr", "code": "down", "name": "下行通道", "id": 102, "type": "raw"},
        ],
    },
    "5oulffwfh7yvajub": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "h19lwmmcfp2tw5nl": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "7jIGJAymiH8OsFFb": {
        "schemaExt": [
            {"complexType": "duration", "id": 101, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "ro",
                "code": "prm_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Battery",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
        ],
    },
    "h8hit5awxfraops2": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "开启百分比控制",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "percent_state",
                "name": "开启百分比状态",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_warming",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["morning", "night"], "type": "enum"},
                "iconname": "icon-dp_notice",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_back",
                "name": "电机反向",
                "property": {"type": "bool"},
                "iconname": "icon-dp_time2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_state",
                "name": "工作状态",
                "property": {"range": ["opening", "closing"], "type": "enum"},
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["motor_fault"], "type": "bitmap", "maxlen": 1},
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "time_total",
                "name": "全程运行时间",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 120000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "14i0aoha05pel0hv": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fengli",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "w8mijl9lbbuh8li4": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sleep_mode",
                "name": "入睡",
                "property": {"type": "raw", "maxlen": "255"},
                "iconname": "icon-dp_sleep",
                "id": 31,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "wakeup_mode",
                "name": "唤醒",
                "property": {"type": "raw", "maxlen": "255"},
                "iconname": "icon-dp_sun",
                "id": 32,
                "type": "raw",
            },
        ],
    },
    "bodmrtza0uy1ahqq": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "gvidzzhwsgnwm4tm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "e9k85bsuxs0ppehx": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music", "DIY"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "speed",
                "name": "速度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "timer",
                "name": "定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "DIY",
                "name": "DIY",
                "property": {"type": "string", "maxlen": 255},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music",
                "name": "音乐",
                "property": {"type": "string", "maxlen": 255},
                "id": 104,
                "type": "obj",
            },
        ],
    },
    "gbm9ata1zrzaez4a": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "gcabrsa6ci0lqptn": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "iu3syfecq16pm8ts": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-a_nav_function",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-taiyang",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "rorsvap65wxnuaqt": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐律动",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "pgsgfzmyxllmda2c": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "5c67nfhgkcacmpkl": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 13, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value_1",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "brightness_min_1",
                "name": "最小亮度",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "led_type_1",
                "name": "光源类型",
                "property": {
                    "range": ["led", "incandescent", "halogen"],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {"range": ["white"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "frr8t2jf42bj19zv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "h6vbhu3ysywrpqeq": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "05z6y05b3ghvcgpv": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 29,
                "type": "obj",
            },
        ],
    },
    "vlu7xq22zayy6bwb": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 8, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 15, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 16, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_usb1",
                "name": "USB开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_usb1",
                "name": "USB1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 15,
                "type": "obj",
            },
        ],
    },
    "mopbcp410y4tyw9i": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "hw50w7qvxluhslkk": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "设置温度",
                "property": {
                    "unit": "℃",
                    "min": 160,
                    "max": 880,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": -20,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": ["cold", "hot", "wet", "wind", "auto"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "windspeed",
                "name": "风速",
                "property": {
                    "range": [
                        "strong",
                        "high",
                        "mid_high",
                        "mid",
                        "mid_low",
                        "low",
                        "mute",
                        "auto",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_wind",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "humidity_current",
                "name": "当前湿度",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_wet",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "E0",
                        "E1",
                        "E2",
                        "E3",
                        "E4",
                        "E5",
                        "E6",
                        "E7",
                        "E8",
                        "E9",
                        "EA",
                        "Eb",
                        "EC",
                        "EE",
                        "EF",
                        "EP",
                        "EU",
                        "EH",
                        "EJ",
                        "En",
                        "Ey",
                        "F9",
                        "FA",
                        "H1",
                        "H2",
                        "P0",
                        "P1",
                        "P2",
                        "P4",
                        "P5",
                    ],
                    "type": "bitmap",
                    "maxlen": 30,
                },
                "iconname": "icon-dp_warming",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "pm25",
                "name": "PM25",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 3000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sleep",
                "name": "睡眠",
                "property": {
                    "range": ["off", "normal", "old", "child"],
                    "type": "enum",
                },
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "markbit",
                "scope": "fault",
                "name": "标识位",
                "property": {
                    "label": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                        "19",
                        "20",
                        "21",
                        "22",
                        "23",
                    ],
                    "type": "bitmap",
                    "maxlen": 24,
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "up_down_sweep",
                "name": "上下扫风",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 113,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "left_right_sweep",
                "name": "左右扫风",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7"],
                    "type": "enum",
                },
                "id": 114,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "totalN",
                "name": "电量整数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 115,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "totalP",
                "name": "电量小数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 116,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "money",
                "name": "省钱看的见",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "energy",
                "name": "电机模式",
                "property": {"range": ["off", "L1", "L2", "L3"], "type": "enum"},
                "id": 120,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault2",
                "scope": "fault",
                "name": "故障报警2",
                "property": {
                    "label": [
                        "P6",
                        "P7",
                        "P8",
                        "P9",
                        "PA",
                        "F0",
                        "F1",
                        "F2",
                        "F3",
                        "F4",
                        "F5",
                        "F6",
                        "F7",
                        "F8",
                        "Fb",
                        "FC",
                        "FE",
                        "FF",
                        "FH",
                        "FP",
                        "FU",
                        "Fj",
                        "Fn",
                        "Fy",
                        "bf",
                        "bc",
                        "bj",
                    ],
                    "type": "bitmap",
                    "maxlen": 27,
                },
                "id": 122,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "boolCode",
                "name": "布尔型",
                "property": {"type": "string", "maxlen": 255},
                "id": 123,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "airquality",
                "name": "空气质量",
                "property": {
                    "range": [
                        "great",
                        "good",
                        "middle",
                        "bad",
                        "verybad",
                        "veryverybad",
                    ],
                    "type": "enum",
                },
                "id": 125,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "up_down_freeze",
                "name": "上下定格",
                "property": {"range": ["0", "1", "2", "3", "4", "5"], "type": "enum"},
                "id": 126,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "left_right_freeze",
                "name": "左右定格",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "8", "6", "7"],
                    "type": "enum",
                },
                "id": 127,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "style",
                "name": "机型",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 128,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "kwh",
                "name": "功率",
                "property": {"range": ["1", "2", "3", "4", "5"], "type": "enum"},
                "id": 129,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "savemoney_temp",
                "name": "定温温度",
                "property": {
                    "unit": "℃",
                    "min": 26,
                    "max": 31,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 130,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "dirty_filter",
                "name": "滤网脏堵",
                "property": {"type": "bool"},
                "id": 131,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "hot_cold_wind",
                "name": "高温风/凉感风",
                "property": {"type": "bool"},
                "id": 132,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "wind",
                "name": "水平摆风/垂直摆风",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 133,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "work_time",
                "name": "运行状态时间",
                "property": {"type": "string", "maxlen": 255},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "run_time",
                "name": "运行时间",
                "property": {
                    "unit": "次",
                    "min": 0,
                    "max": 65525,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 135,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_set_f",
                "name": "华氏度温度",
                "property": {
                    "unit": "℉",
                    "min": 61,
                    "max": 88,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 136,
                "type": "obj",
            },
        ],
    },
    "lyq7o3cpui0mgfky": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "master_mode",
                "name": "主机模式",
                "property": {
                    "range": ["disarmed", "arm", "home", "sos", "alarm"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "delay_set",
                "name": "退出延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-zanting1",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_time",
                "name": "报警时长",
                "property": {
                    "unit": "分钟",
                    "min": 1,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_sound",
                "name": "报警声开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_light",
                "name": "门铃通知",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_ringtone",
                "name": "报警铃音",
                "property": {
                    "range": [
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                        "19",
                        "20",
                        "21",
                        "22",
                        "23",
                        "24",
                        "25",
                        "26",
                        "27",
                        "28",
                        "29",
                        "30",
                        "31",
                        "32",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_notice",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_sound",
                "name": "布撤防提示音",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_light",
                "name": "工作模式指示灯",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_kb_sound",
                "name": "键盘按键音",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_kb_light",
                "name": "键盘背景灯",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "charge_state",
                "name": "主电源状态",
                "property": {"type": "bool"},
                "iconname": "icon-power1",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_battery",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_low_battery",
                "name": "探测器低电量报警",
                "property": {"type": "bool"},
                "iconname": "icon-dianliang",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "zone_attribute",
                "name": "防区属性",
                "property": {
                    "range": [
                        "Normal",
                        "24Hours",
                        "Delay",
                        "Home",
                        "24HoursMute",
                        "HomeDelay",
                        "Off",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-a_fan_auto",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "iconname": "icon-Mute",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_msg",
                "name": "告警信息",
                "id": 26,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_propel",
                "name": "告警推送",
                "property": {"type": "bool"},
                "iconname": "icon-dp_chat",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_delay_time",
                "name": "进入延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_dl_sound",
                "name": "倒计时提示音",
                "property": {"type": "bool"},
                "iconname": "icon-dp_time",
                "id": 29,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "doorbell_volume",
                "name": "门铃音量",
                "property": {
                    "range": ["high", "upper_middle", "lower_middle", "low", "mute"],
                    "type": "enum",
                },
                "iconname": "icon-dp_notice",
                "id": 30,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "night_light",
                "name": "门铃音乐32~58",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                        "19",
                        "20",
                        "21",
                        "22",
                        "23",
                        "24",
                        "25",
                        "26",
                        "27",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-deng",
                "id": 31,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_state",
                "name": "主机状态",
                "property": {"range": ["normal", "alarm"], "type": "enum"},
                "iconname": "icon-dp_shield",
                "id": 32,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "master_information",
                "name": "主机信息",
                "id": 33,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "iconname": "icon-dp_anti-clockwise",
                "id": 34,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_add",
                "name": "添加子设备",
                "property": {"type": "bool"},
                "iconname": "icon-dp_plus",
                "id": 35,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_class",
                "name": "子设备品类",
                "property": {"range": ["0", "1"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 36,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_type",
                "name": "子设备类别",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 37,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_admin",
                "name": "子设备管理",
                "id": 38,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sub_state",
                "name": "子设备状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-shoucang",
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_language",
                "name": "主机语言",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
                    "type": "enum",
                },
                "iconname": "icon-dp_doc",
                "id": 40,
                "type": "obj",
            },
        ],
    },
    "hp6orhaqm6as3jnv": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
                "desc": "增加音乐模式",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
                "desc": "rgbhsv",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
                "desc": "音乐灯",
            },
        ],
    },
    "8e0ahuuexxoabtpl": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {"range": ["white", "colour", "scene"], "type": "enum"},
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "white_color",
                "name": "白光常用",
                "property": {"range": ["White1", "White2", "White3"], "type": "enum"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "full_color",
                "name": "彩光常用",
                "property": {"range": ["Color1", "Color2", "Color3"], "type": "enum"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "wakeup_mode",
                "name": "唤醒模式/淡入",
                "property": {"type": "string", "maxlen": 255},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sleep_mode",
                "name": "入睡模式/淡出",
                "property": {"type": "string", "maxlen": 255},
                "id": 104,
                "type": "obj",
            },
        ],
    },
    "KGbxAXL2": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关状态",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "current_temp",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 700,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "set_temp",
                "name": "设定温度",
                "property": {
                    "unit": "℃",
                    "min": 50,
                    "max": 300,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "motor_opening",
                "name": "电机开度显示",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_power",
                "scope": "fault",
                "name": "电池电量报警",
                "property": {"label": ["bit0"], "type": "bitmap", "maxlen": 1},
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "a_key_home",
                "name": "一键离家",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "prog_mode",
                "name": "编程模式",
                "id": 107,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_switch",
                "name": "编程开关",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "prog_data",
                "name": "编程数据（作废，先别删）",
                "id": 109,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_day_set",
                "name": "历史数据协议（日-设定温度）",
                "id": 110,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "system_time",
                "name": "系统时间同步",
                "id": 111,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_week_set",
                "name": "历史数据协议（周-设定温度）",
                "id": 112,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_month_set",
                "name": "历史数据协议（月-设定温度）",
                "id": 113,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_year_set",
                "name": "历史数据协议（年-设定温度）",
                "id": 114,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_day_now",
                "name": "历史数据协议（日-当前温度）",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_week_now",
                "name": "历史数据协议（周-当前温度）",
                "id": 116,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_month_now",
                "name": "历史数据协议（月-当前温度）",
                "id": 117,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_year_now",
                "name": "历史数据协议（年-当前温度）",
                "id": 118,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_day_pow",
                "name": "历史数据协议（日-电机开度）",
                "id": 119,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_week_pow",
                "name": "历史数据协议（周-电机开度）",
                "id": 120,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_month_pow",
                "name": "历史数据协议（月-电机开度）",
                "id": 121,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_year_pow",
                "name": "历史数据协议（年-电机开度）",
                "id": 122,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_1",
                "name": "编程数据（周一）",
                "id": 123,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_2",
                "name": "编程数据（周二）",
                "id": 124,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_3",
                "name": "编程数据（周三）",
                "id": 125,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_4",
                "name": "编程数据（周四）",
                "id": 126,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_5",
                "name": "编程数据（周五）",
                "id": 127,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_6",
                "name": "编程数据（周六）",
                "id": 128,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_7",
                "name": "编程数据（周日）",
                "id": 129,
                "type": "raw",
            },
        ],
    },
    "sziby8cfmfsqiiz4": {
        "schemaExt": [
            {
                "complexType": "",
                "id": 3,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {
                "complexType": "",
                "id": 4,
                "inputStyle": "plain",
                "inputType": "countdown1",
            },
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-lengnuan",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mode",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_sun",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "a_mode_turbo",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_nav_mode",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "遥控器开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "ilddqqih3tucdk68": {
        "schemaExt": [
            {"complexType": "plain", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "plain", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "percent1"},
            {
                "complexType": "",
                "id": 2,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 3, "inputStyle": "temp", "inputType": "percent"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "Ow3c4uldleET7iYS": {
        "schemaExt": [
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                        "music",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩情景",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓情景",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "7sttaownfnwwskj5": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "kfvq6avy": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "目标温度",
                "property": {
                    "unit": "°C",
                    "min": 50,
                    "max": 300,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "°C",
                    "min": 0,
                    "max": 500,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fangzi",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": ["freeze", "auto", "manual", "install"],
                    "type": "enum",
                },
                "iconname": "icon-fangzi1",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-guanjia",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "window_state",
                "name": "窗户状态",
                "property": {"range": ["open", "close"], "type": "enum"},
                "iconname": "icon-a_function_hs",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "window_check",
                "name": "开窗检测",
                "property": {"type": "bool"},
                "iconname": "icon-baifeng1",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "valve_state",
                "name": "阀门状态",
                "property": {"range": ["open", "close"], "type": "enum"},
                "iconname": "icon-icon-test10",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "valve_check",
                "name": "阀门检测",
                "property": {"type": "bool"},
                "iconname": "icon-dp_down1",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-chongnai",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cloud_temp",
                "name": "温度设置",
                "property": {
                    "unit": "℃",
                    "min": 50,
                    "max": 300,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
        ],
    },
    "sclatjo1jqscmwwe": {
        "schemaExt": [
            {"complexType": "", "id": 6, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 8, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 16, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "ro",
                "code": "gas_sensor_state",
                "name": "燃气检测状态",
                "property": {"range": ["alarm", "normal"], "type": "enum"},
                "iconname": "icon-huoyan",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "gas_sensor_value",
                "name": "燃气检测值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-jiare1",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["fault", "tset"], "type": "bitmap", "maxlen": 2},
                "iconname": "icon-dp_warming",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "iconname": "icon-Mute",
                "id": 16,
                "type": "obj",
            },
        ],
    },
    "i8suxrwhhnkx4egb": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 39, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 40, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 41, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_filter",
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯模式",
                "property": {"range": ["relay", "pos", "none"], "type": "enum"},
                "iconname": "icon-dp_light",
                "id": 40,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 41,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 42,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 43,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-power",
                "id": 44,
                "type": "obj",
            },
        ],
    },
    "umpaavewuxcoyhaw": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 18, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 19, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 24, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 25, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
        ],
    },
    "s2halrzmdadtsabs": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "tkuqtt3xvftrsmpl": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "基本-状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "基本-红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测 ",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "云台-停止转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台-方向控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测开关  ",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "floodlight_switch",
                "name": "灯-开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 138,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡开关 ",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像模式选择   ",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
            },
        ],
    },
    "dno0bo9au1z4b1pv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "aanv4fjtnzbiiz91": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "总开关",
                "property": {"type": "bool"},
                "iconname": "icon-a_mode_turbo",
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "power_status",
                "name": "上电状态设置",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "dev_mode",
                "name": "工作模式",
                "property": {
                    "range": ["selflock", "inching", "interlock"],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "jg_time",
                "name": "点动时间",
                "property": {
                    "unit": "S",
                    "min": 5,
                    "max": 600,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
        ],
    },
    "Dd1hgjFw49ahTjUG": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 1220,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {
                    "range": ["Manual", "Program", "Holiday", "TempProg"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 5,
                },
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "华氏度摄氏度",
                "property": {"type": "bool"},
                "iconname": "icon-a_function_fahrenhei",
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Heating_state",
                "name": "加热",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Ext_temperature",
                "name": "外置温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1580,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Days_Holiday",
                "name": "离家模式-天数",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-p7",
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Settemp_Holiday",
                "name": "离家模式-设置温度",
                "property": {
                    "unit": "",
                    "min": 5,
                    "max": 122,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Hightemp_Protect",
                "name": "高温保护功能",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "LowTemp_Protect",
                "name": "低温保护功能",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "ext_temp_display",
                "name": "外置温度显示功能",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "room_temp_compensate",
                "name": "温度补偿",
                "property": {
                    "unit": "",
                    "min": -180,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-ziyouchengxu",
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "room_temp_zone",
                "name": "室内温度回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ext_temp_zone",
                "name": "外置温度回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 18,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "high_temp_limit",
                "name": "高温保护温度",
                "property": {
                    "unit": "",
                    "min": 35,
                    "max": 158,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 112,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "low_temp_limit",
                "name": "低温保护温度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 113,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "set_temp_max",
                "name": "设置温度最高上限",
                "property": {
                    "unit": "℃",
                    "min": 20,
                    "max": 158,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "set_temp_min",
                "name": "设置温度最低下限",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 59,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 115,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_sensor_type",
                "name": "传感器类型",
                "property": {"range": ["in", "ext", "all"], "type": "enum"},
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "power_state",
                "name": "上电开关机状态",
                "property": {"range": ["keep", "off", "on"], "type": "enum"},
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Prog_Type",
                "name": "编程类型",
                "property": {"range": ["2days", "1days", "0days"], "type": "enum"},
                "id": 118,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday1",
                "name": "编程-工作日参数1",
                "id": 119,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday2",
                "name": "编程-工作日参数2",
                "id": 120,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday1",
                "name": "编程-休息日参数1",
                "id": 121,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday2",
                "name": "编程-休息日参数2",
                "id": 122,
                "type": "raw",
            },
        ],
    },
    "ukytbgdk7q4izixq": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "mdk",
                "name": "门磁开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "vuyw3gn9lcaq4wmv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 38,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯状态设置",
                "property": {"range": ["none", "relay", "pos"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 40,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_time",
                "id": 41,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_clockwise",
                "id": 42,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "id": 43,
                "type": "obj",
            },
        ],
    },
    "pq860vo9ib50jhud": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kwh",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-baojing",
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "d4baqseq69xcqyzi": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "slv3w113z8qzfp5x": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐律动",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "nbsy7PSBnGAJYnvO": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 2,
                "type": "obj",
                "passive": True,
            },
        ],
    },
    "4dl9hkne": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 5, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 12, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 18, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 19, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 32, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 35, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 39, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 104, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 105, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 106, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 107, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "模式",
                "property": {"range": ["manual", "program", "holiday"], "type": "enum"},
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "work_state",
                "name": "工作状态",
                "property": {"range": ["start", "stop"], "type": "enum"},
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "frost",
                "name": "防霜冻功能",
                "property": {"type": "bool"},
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sensor_choose",
                "name": "传感器选择",
                "property": {"range": ["in", "out", "in_out"], "type": "enum"},
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_unit_convert",
                "name": "温标切换",
                "property": {"range": ["c", "f"], "type": "enum"},
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "温度设置",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_set_f",
                "name": "目标温度℉",
                "property": {
                    "unit": "℉",
                    "min": 41,
                    "max": 99,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "holiday_days_set",
                "name": "假日模式天数设置",
                "property": {
                    "unit": "day",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 32,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": -199,
                    "max": 950,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 33,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_correction",
                "name": "温度校准",
                "property": {
                    "unit": "℃/℉",
                    "min": -9,
                    "max": 9,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 35,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current_f",
                "name": "当前温度",
                "property": {
                    "unit": "℉",
                    "min": -40,
                    "max": 2030,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 37,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_days",
                "name": "工作日设置",
                "property": {"range": ["5_2", "6_1", "7"], "type": "enum"},
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "week_program3",
                "name": "周程序3（工作日休息日）",
                "id": 42,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["e1", "e2", "e3", "e4", "e5", "e6"],
                    "type": "bitmap",
                    "maxlen": 6,
                },
                "id": 45,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "floor_temp_c",
                "name": "地板温度",
                "property": {
                    "unit": "℃",
                    "min": -199,
                    "max": 950,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "floor_temp_f",
                "name": "地板温度",
                "property": {
                    "unit": "℉",
                    "min": -40,
                    "max": 2030,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_correction_f",
                "name": "外部传感器校正",
                "property": {
                    "unit": "℃/℉",
                    "min": -9,
                    "max": 9,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_difference",
                "name": "温度回差",
                "property": {
                    "unit": "℃/℉",
                    "min": 1,
                    "max": 9,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "lock_mode",
                "name": "童锁模式",
                "property": {"range": ["no_power", "power"], "type": "enum"},
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "over_temp",
                "name": "高温保护",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 65,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "over_temp_F",
                "name": "高温保护_F",
                "property": {
                    "unit": "℉",
                    "min": 41,
                    "max": 149,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "update_data",
                "name": "刷新数据",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
            },
        ],
    },
    "gqr0wk700cvaaxay": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "白光亮度",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "白光色温",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "kq8vkflzd3rfbsmk": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐律动",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "OHuNZ1j0PAnxZbSP": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 5, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "全部开启或关闭",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
            },
        ],
    },
    "j3yhrl6mmq1xgfdz": {
        "schemaExt": [
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 29,
                "type": "obj",
            },
        ],
    },
    "38oa5lljwmmvacxt": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "0xfnwm9n5xjrp8aa": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "smoke_sensor_state",
                "name": "烟雾检测状态",
                "property": {"range": ["1", "2"], "type": "enum"},
                "iconname": "icon-huoyan",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "checking_result",
                "name": "设备自检结果",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-dp_smile",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "lifecycle",
                "name": "使用寿命",
                "property": {"type": "bool"},
                "iconname": "icon-tongji1",
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_battery",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "iconname": "icon-Mute",
                "id": 16,
                "type": "obj",
            },
        ],
    },
    "njpmyjyykglg2zvm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "电源开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "power_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "清扫模式",
                "property": {
                    "range": [
                        "standby",
                        "random",
                        "smart",
                        "wall_follow",
                        "mop",
                        "spiral",
                        "left_spiral",
                        "right_spiral",
                        "right_bow",
                        "left_bow",
                        "partial_bow",
                        "chargego",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "seek",
                "name": "寻找机器",
                "property": {"type": "bool"},
                "iconname": "icon-dp_curve",
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "clean_switch",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "pause_switch",
                "name": "暂停开关",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "charge_switch",
                "name": "回充开关",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "clean_mode",
                "name": "清扫模式",
                "property": {
                    "range": [
                        "smart",
                        "pose",
                        "zone",
                        "backcharge",
                        "curpointing",
                        "chargego",
                    ],
                    "type": "enum",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "robot_state",
                "name": "当前状态",
                "property": {
                    "range": [
                        "idle",
                        "pointing",
                        "areaing",
                        "totaling",
                        "sweep",
                        "mop",
                        "fault",
                        "pause",
                        "chargring",
                        "tocharge",
                        "fullcharge",
                        "remotectl",
                        "dormant",
                        "curpointing",
                    ],
                    "type": "enum",
                },
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "battery",
                "name": "剩余电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cur_clean_time",
                "name": "清扫时间",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 2147483647,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cur_clean_area",
                "name": "清扫面积",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 2147483647,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "fan_mode",
                "name": "吸力",
                "property": {"range": ["quiet", "auto", "strong"], "type": "enum"},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "water_mode",
                "name": "水量调节",
                "property": {"range": ["low", "mid", "high"], "type": "enum"},
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "remote_ctrl",
                "name": "远程遥控",
                "property": {
                    "range": ["forward", "backward", "left", "right", "stop"],
                    "type": "enum",
                },
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "seek_robot",
                "name": "定位机器人",
                "property": {"type": "bool"},
                "id": 112,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "disturb_switch",
                "name": "勿扰开关",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "volume",
                "name": "音量设置",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "material_reset",
                "name": "耗材复位",
                "property": {
                    "range": [
                        "gettime",
                        "resetsidebrush",
                        "resetmainbrush",
                        "resetfilter",
                    ],
                    "type": "enum",
                },
                "id": 115,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "total_clean_time",
                "name": "总时长",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 2147483647,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "total_clean_area",
                "name": "累计面积",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 2147483647,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "total_clean_count",
                "name": "总次数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 2147483647,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 118,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "side_brush_time",
                "name": "边刷已使用",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 540000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "main_brush_time",
                "name": "主刷剩余",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1080000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 120,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "filter_time",
                "name": "滤芯已使用",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 540000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 121,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "robot_fault",
                "scope": "fault",
                "name": "机器故障",
                "property": {
                    "label": [
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                        "19",
                        "20",
                        "21",
                        "22",
                        "23",
                        "24",
                        "25",
                        "26",
                        "27",
                        "28",
                        "29",
                        "30",
                    ],
                    "type": "bitmap",
                    "maxlen": 30,
                },
                "id": 122,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "path_comm",
                "name": "路径下发上报",
                "id": 123,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "cmd_comm",
                "name": "指令下发",
                "id": 124,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "request_data",
                "name": "请求数据",
                "property": {"range": ["map", "path", "both"], "type": "enum"},
                "id": 125,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "comm_flag",
                "name": "简单通讯",
                "property": {"range": ["1"], "type": "enum"},
                "id": 126,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "comm_raw",
                "name": "复杂通讯",
                "id": 127,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "message_report",
                "name": "消息上报",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                        "19",
                        "20",
                    ],
                    "type": "enum",
                },
                "id": 128,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "reset_map",
                "name": "重制地图",
                "property": {"type": "bool"},
                "id": 129,
                "type": "obj",
            },
            {"mode": "ro", "code": "sn", "name": "设备序列号", "id": 130, "type": "raw"},
            {"mode": "ro", "code": "uuid", "name": "UUID", "id": 131, "type": "raw"},
            {
                "mode": "rw",
                "code": "device_info",
                "name": "获取设备信息",
                "id": 132,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "voice_id",
                "name": "语言包",
                "property": {"range": ["0", "1", "2", "3", "4", "5"], "type": "enum"},
                "id": 133,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "voice_link",
                "name": "语音包链接",
                "id": 134,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "yu_liu",
                "name": "预留",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "yu_liu1",
                "name": "预留",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 136,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "yu_liu2",
                "name": "地毯增压模式",
                "property": {"type": "bool"},
                "id": 137,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "yu_liu3",
                "name": "拖布是否安装",
                "property": {"type": "bool"},
                "id": 138,
                "type": "obj",
            },
        ],
    },
    "0xrwvfytfnpwcjhh": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 35,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1", "2"], "type": "bitmap", "maxlen": 2},
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "TempFloor",
                "name": "地温",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "SensorType",
                "name": "传感器类型",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "TempComp",
                "name": "补偿温度",
                "property": {
                    "unit": "",
                    "min": -9,
                    "max": 9,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "TempActivate",
                "name": "启动温差",
                "property": {
                    "unit": "",
                    "min": 2,
                    "max": 9,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "LoadStatus",
                "name": "负载",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "TempProgram",
                "name": "编程模式",
                "id": 106,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "WindowDetect",
                "name": "开窗检测",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "OptimumStart",
                "name": "最佳启动",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
            },
        ],
    },
    "xruwvmir2e41r9db": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "基本-红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测   ",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "云台-停止转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台-方向控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": " 移动侦测开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_tracking",
                "name": "人体追踪设置",
                "property": {"type": "bool"},
                "id": 161,
                "type": "obj",
            },
        ],
    },
    "gwepglfaw5vg1mfu": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch_1",
                "name": "开光",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value_1",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "brightness_min_1",
                "name": "最小亮度",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_doc",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "led_type_1",
                "name": "光源类型",
                "property": {
                    "range": ["LED", "incandescent", "halogen"],
                    "type": "enum",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {"range": ["white"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 5,
                "type": "obj",
            },
        ],
    },
    "0l6zinzwpitdndi8": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "other",
                "name": "其他",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "number",
                "name": "喂食份数",
                "property": {
                    "unit": "份",
                    "min": 1,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["E1", "E2", "E3"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "feed_error",
                "scope": "fault",
                "name": "喂食故障",
                "property": {"label": ["1", "2"], "type": "bitmap", "maxlen": 2},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "FEED_INFO",
                "name": "喂食计划",
                "id": 104,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sumfed",
                "name": "喂食统计",
                "property": {
                    "unit": "份",
                    "min": 0,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "ttrn0dlxota0rrav": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "d7untfklhtfaaair": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
                "desc": "ov_cr：过流保护",
            },
        ],
    },
    "lgohumyl4xua2fhv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "停止转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台转动",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_timer_switch",
                "name": "移动侦测-模式选择",
                "property": {"type": "bool"},
                "id": 135,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "声音侦测报警开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "声音侦测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "检测到声音",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像-开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像-模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_area_switch",
                "name": "移动侦测报警区域开关",
                "property": {"type": "bool"},
                "id": 168,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_area",
                "name": "移动侦测报警区域",
                "property": {"type": "string", "maxlen": 255},
                "id": 169,
                "type": "obj",
            },
        ],
    },
    "jdk24sq7i07oofqo": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": "countdown1"},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "l1njvstpqgeolatc": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-a_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "白光亮度",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "wj3r4mqycqnhomgt": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "mki13ie507rlry4r": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "灯",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "d1kjmp8eikqhalwv": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "白光亮度",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "白光色温",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "1kvprtma6cbkdxc8": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "master_mode",
                "name": "主机模式",
                "property": {
                    "range": ["disarmed", "arm", "home", "sos"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "delay_set",
                "name": "退出延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-zanting1",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_time",
                "name": "报警时长",
                "property": {
                    "unit": "分钟",
                    "min": 1,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_sound",
                "name": "报警声开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "iconname": "icon-dp_tool",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_sound",
                "name": "布撤防提示音",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "charge_state",
                "name": "主电源状态",
                "property": {"type": "bool"},
                "iconname": "icon-power1",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_battery",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_low_battery",
                "name": "探测器低电量报警",
                "property": {"type": "bool"},
                "iconname": "icon-dianliang",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "zone_attribute",
                "name": "防区属性",
                "property": {
                    "range": [
                        "Normal",
                        "24Hours",
                        "Delay",
                        "Home",
                        "24HoursMute",
                        "HomeDelay",
                        "Off",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-a_fan_auto",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "iconname": "icon-Mute",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_msg",
                "name": "告警信息",
                "id": 26,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_propel",
                "name": "告警推送",
                "property": {"type": "bool"},
                "iconname": "icon-dp_chat",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_delay_time",
                "name": "进入延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_dl_sound",
                "name": "倒计时提示音",
                "property": {"type": "bool"},
                "iconname": "icon-dp_time",
                "id": 29,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_state",
                "name": "主机状态",
                "property": {"range": ["normal", "alarm"], "type": "enum"},
                "iconname": "icon-dp_shield",
                "id": 32,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "master_information",
                "name": "主机信息",
                "id": 33,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "iconname": "icon-dp_anti-clockwise",
                "id": 34,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_add",
                "name": "添加子设备",
                "property": {"type": "bool"},
                "iconname": "icon-dp_plus",
                "id": 35,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_class",
                "name": "子设备品类",
                "property": {"range": ["0", "1"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 36,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_type",
                "name": "子设备类别",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 37,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_admin",
                "name": "子设备管理",
                "id": 38,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sub_state",
                "name": "子设备状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-shoucang",
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_language",
                "name": "主机语言",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
                    "type": "enum",
                },
                "iconname": "icon-dp_doc",
                "id": 40,
                "type": "obj",
            },
        ],
    },
    "PIoTI1dsAKrhnZSP": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
            },
        ],
    },
    "gwoutyracaadn0u4": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
            },
        ],
    },
    "viav1onpzcozfneb": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 16, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 19, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 27, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 39, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 40, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["manual", "eco", "auto"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "work_state",
                "name": "工作状态",
                "property": {
                    "range": ["no_heating", "heating", "window_opened"],
                    "type": "enum",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "frost",
                "name": "防霜冻功能",
                "property": {"type": "bool"},
                "iconname": "icon-chushuang",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "设置温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1000,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "upper_temp",
                "name": "设置温度上限",
                "property": {
                    "unit": "℃",
                    "min": 50,
                    "max": 1000,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-dp_c",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-wendu",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "lower_temp",
                "name": "设置温度下限",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 1000,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-dp_c",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_correction",
                "name": "温度校准",
                "property": {
                    "unit": "",
                    "min": -100,
                    "max": 100,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-wendu1",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "week_program2",
                "name": "周编程（多段式）",
                "iconname": "icon-icon-test6",
                "id": 37,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "iconname": "icon-icon-test12",
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 40,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "high_protect",
                        "low_protect",
                        "int_sensor",
                        "ext_sensor",
                        "battary_low",
                        "device_offline",
                    ],
                    "type": "bitmap",
                    "maxlen": 6,
                },
                "iconname": "icon-dp_notice",
                "id": 45,
                "type": "obj",
            },
        ],
    },
    "amxgrkevr0ckpjvs": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "be0e6lgqtycj0hbm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "txLK09GfKhiKGsy7": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "wifvoilfrqeo6hvu": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "over_current_alarm",
                "name": "过流预警",
                "property": {"type": "bool"},
                "id": 7,
                "type": "obj",
            },
        ],
    },
    "w52qckfmk1hb4jkq": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "dwtduedoammsswzn": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取SD卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "SD卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "格式化存储卡",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_record",
                "name": "移动侦测录像",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "停止云台转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "移动录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_tracking",
                "name": "人体移动追踪",
                "property": {"type": "bool"},
                "id": 161,
                "type": "obj",
            },
        ],
    },
    "judtosuitg5nysm4": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "waq2wj9pjadcg1qc": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "总开关",
                "property": {"type": "bool"},
                "iconname": "icon-a_mode_turbo",
                "id": 13,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "power_status",
                "name": "上电状态设置",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "dev_mode",
                "name": "工作模式",
                "property": {
                    "range": ["selflock", "inching", "interlock"],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "jg_time",
                "name": "点动时间",
                "property": {
                    "unit": "S",
                    "min": 5,
                    "max": 600,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "m6ei1t46nqn0p0p9": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延迟",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
                "passive": True,
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 500000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "over_current_alarm",
                "name": "过流预警",
                "property": {"type": "bool"},
                "id": 7,
                "type": "obj",
            },
        ],
    },
    "idxdl5aimuw9unn8": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "rsmegitozw1sebfg": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 12, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
            },
        ],
    },
    "7l3yuanaxz38j2ta": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_control",
                "name": "switch control",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间设置",
                "property": {
                    "unit": "s",
                    "min": 10,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "BlackLight",
                "name": "BackLight",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "t0khbfohjlazq79e": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "5udnju6mghpuldix": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "doorcontact_state",
                "name": "门磁状态",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 4,
                "type": "obj",
            },
        ],
    },
    "g70xswjhgyjclwdl": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "7mbj2x82tyzxvfxs": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "dmcfgsj8dihmc2gd": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "kchagk8y": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "°C",
                    "min": -400,
                    "max": 2000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 1,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "humidity_value",
                "name": "湿度数值",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 1000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_unit_convert",
                "name": "温标切换",
                "property": {"range": ["c", "f"], "type": "enum"},
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "89qheunzbfsuto8m": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "6jz7sqeuxnhom2rk": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "白光亮度",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "白光色温",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "kksjmhr9nhjudvzo": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "mdk",
                "name": "门磁开关",
                "property": {"type": "bool"},
                "id": 101,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间设置",
                "property": {
                    "unit": "s",
                    "min": 10,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "bfalxcacol0srtg8": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "设备控制 1",
                "property": {
                    "range": ["open", "stop", "close", "continue"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "百分比控制 1",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cur_calibration",
                "name": "行程校准",
                "property": {"range": ["start", "end"], "type": "enum"},
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_back",
                "name": "电机转向 1",
                "property": {"range": ["forward", "back"], "type": "enum"},
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间设置",
                "property": {
                    "unit": "s",
                    "min": 2,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "CpD9wmiMKSU1kO8E": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "n5xmv0gnciypxce7": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 38, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 38,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_time",
                "id": 41,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_clockwise",
                "id": 42,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "id": 43,
                "type": "obj",
            },
        ],
    },
    "axdc1sdmfcbadxwu": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "u7paxtzfoo2giqwb": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "lplun31mo1xaonwz": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ir_send",
                "name": "红外控制下发",
                "property": {"type": "string", "maxlen": 3072},
                "id": 201,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ir_study_code",
                "name": "红外学习值上报",
                "id": 202,
                "type": "raw",
            },
        ],
    },
    "9q3kpj25ei9lay0c": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_tool",
                "id": 29,
                "type": "obj",
            },
        ],
    },
    "kyfqmmyl": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关 2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关 3",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_all",
                "name": "全部开关",
                "property": {"type": "bool"},
                "iconname": "icon-a_mode_turbo",
                "id": 13,
                "type": "obj",
            },
        ],
    },
    "5y81h1twcpctkteu": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "nzqhnsftov1pbxek": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "继电器上电状态",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
        ],
    },
    "qqdverk4av7i6bqa": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_alarm_sound",
                "name": "报警静音",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "charge_state",
                "name": "充电状态",
                "property": {"type": "bool"},
                "iconname": "icon-dianliang",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dianliang",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_low_battery",
                "name": "低电量报警",
                "property": {"type": "bool"},
                "iconname": "icon-baojing",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "alarm_msg",
                "name": "告警信息",
                "iconname": "icon-baojing",
                "id": 26,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "master_state",
                "name": "主机状态",
                "property": {"range": ["normal", "alarm"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 32,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "重启",
                "property": {"type": "bool"},
                "iconname": "icon-AwayArm",
                "id": 34,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "system_volume",
                "name": "系统音量",
                "property": {
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_voice",
                "id": 44,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_active",
                "name": "主动报警",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "Trigger icon-Trigger",
                "id": 45,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "warning_tone",
                "name": "子设备提示音",
                "property": {"type": "string", "maxlen": 255},
                "id": 103,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "9joszxtmoknokvm9": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "zqn20z5gxtloumit": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "设备控制",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "开启百分比控制",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cur_calibration",
                "name": "行程校准",
                "property": {"range": ["start", "end"], "type": "enum"},
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_back",
                "name": "电机反转",
                "property": {"range": ["forward", "back"], "type": "enum"},
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯状态设置",
                "property": {"range": ["relay", "pos", "none"], "type": "enum"},
                "id": 14,
                "type": "obj",
            },
        ],
    },
    "IDkXwcvanigdiTj3": {
        "schemaExt": [
            {"complexType": "plain", "id": 101, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "ro",
                "code": "PIR",
                "name": "PIR",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
        ],
    },
    "bo8wqczeduk1k8jb": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "bubj39lfo0hgdea8": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "ocJQLu8lBkTAKVrg": {
        "schemaExt": [{"complexType": "", "id": 11, "inputStyle": "", "inputType": ""}],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "单插开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
                "desc": "可根据产品实际倒计时功能修改。",
            },
        ],
    },
    "jBtt1AX7VC5KDQyT": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "ajntyr4wk4mw2nzi": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_dust",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_puzzle",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_smile",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "b8cr31hp": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 8, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "jo4pydiansodawgb": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "设备控制",
                "property": {"range": ["on", "stop", "off"], "type": "enum"},
                "iconname": "icon-a_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间",
                "property": {
                    "unit": "s",
                    "min": 10,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "backlight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "8zolzs9d2e74rars": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "设置温度",
                "property": {
                    "unit": "℃",
                    "min": 16,
                    "max": 86,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": -7,
                    "max": 110,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["COOL", "FAN", "DRY", "HEAT"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "windspeed",
                "name": "风速",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_wind",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "温标",
                "property": {"range": ["C", "F"], "type": "enum"},
                "iconname": "icon-dp_half",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "SLEEP",
                "name": "睡眠模式",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Defrost",
                "name": " 制热化霜",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Timer",
                "name": "倒计时",
                "property": {
                    "unit": "小时",
                    "min": 0,
                    "max": 24,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Shake",
                "name": "摆风",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "coutdown",
                "name": "剩余倒计时",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 1440,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Alarm",
                "scope": "fault",
                "name": "故障类型",
                "property": {
                    "label": ["0", "1", "2", "3", "4"],
                    "type": "bitmap",
                    "maxlen": 5,
                },
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "innerdry",
                "name": "机内风干",
                "property": {"type": "bool"},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "model",
                "name": "机型",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 110,
                "type": "obj",
            },
        ],
    },
    "ozdwqerjiheld7ee": {
        "schemaExt": [{"complexType": "", "id": 4, "inputStyle": "", "inputType": ""}],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_spray",
                "name": "喷雾开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {"range": ["low", "high"], "type": "enum"},
                "iconname": "icon-dp_box",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {"range": ["1", "3", "6", "cancel"], "type": "enum"},
                "iconname": "icon-dp_time2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "Diffuser light",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "灯光模式",
                "property": {"range": ["colour", "colourful1"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光值",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["lack_water"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-yanse",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "idnfq7xbx8qewyoa": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐律动",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "pnhld9ypjqqc4yoa": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "f5xnmpd61v1zyuly": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "ah98ns6ff5m7fmgy": {
        "schemaExt": [
            {
                "complexType": "",
                "id": 22,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 23, "inputStyle": "temp", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shezhi",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "遥控器开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "wp8r872adwnxvqac": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "t7lv6lhqhr49iaat": {
        "schemaExt": [
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 105, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "switch",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "TamperedAlarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Battery",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "state",
                "name": "状态",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
            },
        ],
    },
    "h6db0we4dkvmnmgr": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "agiuf79utadawzud": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
            },
        ],
    },
    "py9zrqqb4qgjwynh": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "doorcontact_state",
                "name": "门磁状态",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "m4viuhaiez8qjswh": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关 2",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关 3",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-dp_circle",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_backlight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 16,
                "type": "obj",
            },
        ],
    },
    "nOtxbOfJNNVSatZD": {
        "schemaExt": [
            {"complexType": "", "id": 131, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 136, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "Spraymode",
                "name": "喷雾模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 123,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Spraytime",
                "name": "喷雾定时",
                "property": {"range": ["1", "2", "3", "4", "5"], "type": "enum"},
                "id": 124,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "lightswitch",
                "name": "灯光开关",
                "property": {"type": "bool"},
                "id": 125,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "lightcolour",
                "name": "灯光颜色",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "8"],
                    "type": "enum",
                },
                "id": 126,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sprayswitch",
                "name": "喷雾开关",
                "property": {"type": "bool"},
                "id": 127,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "id": 128,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "gradient",
                "name": "渐\n\n变",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 129,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "brightanddark",
                "name": "明暗",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 130,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 131,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "BELL_Switch",
                "name": "蜂鸣器开关",
                "property": {"type": "bool"},
                "id": 132,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "id": 133,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Refresh",
                "name": "定时刷新",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 135,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "灯光亮度调节",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 136,
                "type": "obj",
            },
        ],
    },
    "jjglrmqe391d5tb1": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 38,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_clockwise",
                "id": 42,
                "type": "obj",
            },
        ],
    },
    "swzsEKMZ4LhVRRz2": {
        "schemaExt": [
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "percent"}
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light",
                "id": 3,
                "type": "obj",
            },
        ],
    },
    "km2egjtmjjacagpw": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐律动",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "dugf0e4ere6aih9u": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "i5e3a4qxcsthszin": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "doorbell_active",
                "name": "门铃-呼叫",
                "property": {"type": "string", "maxlen": 255},
                "id": 136,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "doorbell_pic",
                "name": "门铃抓拍图片",
                "id": 154,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "basic_device_volume",
                "name": "设备音量控制",
                "property": {
                    "min": 1,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-setting",
                "id": 160,
                "type": "obj",
            },
        ],
    },
    "8wiww11rd7p0fcxv": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "EenFSF51jvtG69d3": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测报警灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取SD卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "SD卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "格式化存储卡",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测图片/视频上传",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "停止云台转动",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台控制",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "0"],
                    "type": "enum",
                },
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动侦测报警功能开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "分贝检测功能开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "分贝检测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "分贝报警通道",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
            },
        ],
    },
    "mw27s3tus4bb7nz3": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "master_mode",
                "name": "主机模式",
                "property": {
                    "range": ["disarmed", "arm", "home", "sos"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "delay_set",
                "name": "退出延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-zanting1",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_time",
                "name": "报警时长",
                "property": {
                    "unit": "分钟",
                    "min": 1,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_sound",
                "name": "报警声开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "iconname": "icon-dp_tool",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_sound",
                "name": "布撤防提示音",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "charge_state",
                "name": "主电源状态",
                "property": {"type": "bool"},
                "iconname": "icon-power1",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_battery",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_low_battery",
                "name": "探测器低电量报警",
                "property": {"type": "bool"},
                "iconname": "icon-dianliang",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_call_number",
                "name": "报警电话号码",
                "id": 18,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "alarm_sms_number",
                "name": "报警短信号码",
                "id": 19,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_call",
                "name": "报警电话",
                "property": {"type": "bool"},
                "iconname": "icon-guanjia",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_sms",
                "name": "报警短信",
                "property": {"type": "bool"},
                "iconname": "icon-dp_doc2",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "call_looptimes",
                "name": "未接听重复拨打次数",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-p12",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "telnet_state",
                "name": "电话网络状态",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-fengli",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "zone_attribute",
                "name": "防区属性",
                "property": {
                    "range": [
                        "Normal",
                        "24Hours",
                        "Delay",
                        "Home",
                        "24HoursMute",
                        "HomeDelay",
                        "Off",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-a_fan_auto",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "iconname": "icon-Mute",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_msg",
                "name": "告警信息",
                "id": 26,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_propel",
                "name": "告警推送",
                "property": {"type": "bool"},
                "iconname": "icon-dp_chat",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_delay_time",
                "name": "进入延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_dl_sound",
                "name": "倒计时提示音",
                "property": {"type": "bool"},
                "iconname": "icon-dp_time",
                "id": 29,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_state",
                "name": "主机状态",
                "property": {"range": ["normal", "alarm"], "type": "enum"},
                "iconname": "icon-dp_shield",
                "id": 32,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "master_information",
                "name": "主机信息",
                "id": 33,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "iconname": "icon-dp_anti-clockwise",
                "id": 34,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_add",
                "name": "添加子设备",
                "property": {"type": "bool"},
                "iconname": "icon-dp_plus",
                "id": 35,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_class",
                "name": "子设备品类",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 36,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_type",
                "name": "子设备类别",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 37,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_admin",
                "name": "子设备管理",
                "id": 38,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sub_state",
                "name": "子设备状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-shoucang",
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_language",
                "name": "主机语言",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
                    "type": "enum",
                },
                "iconname": "icon-dp_doc",
                "id": 40,
                "type": "obj",
            },
        ],
    },
    "ey0bctrrjxsq6q6m": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "ivxfweclfhvra3ym": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {"range": ["white", "colour", "scene"], "type": "enum"},
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "aacztutbu69gdpdf": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "设备控制",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "iconname": "icon-a_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_backlight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 7,
                "type": "obj",
            },
        ],
    },
    "OvdBjC0PhzfdNnNX": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "alarm",
                "name": "alarm",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Battery",
                "name": "电池上报",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
        ],
    },
    "xepfchcvdyvhx6s3": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "声音侦测报警开关",
                "property": {"type": "bool"},
                "id": 139,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "声音侦测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 140,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "检测到声音",
                "property": {"type": "string", "maxlen": 255},
                "id": 141,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
            },
        ],
    },
    "aij6c2v1pga9rizz": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent1"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "a476raq2": {
        "schemaExt": [
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": " "}
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "prm_content",
                "name": "湿度",
                "property": {
                    "unit": "% RH",
                    "min": 0,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-jiare1",
                "id": 101,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "prm_temperature",
                "name": "温度",
                "property": {
                    "unit": "℃",
                    "min": -2000,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "k7oooui6xpei6ny4": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motor_speed",
                "name": "马达转速",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "laser_switch",
                "name": "激光灯开关",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "rgb_switch",
                "name": "RGB开关",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
        ],
    },
    "fthu3wguzoqdayzp": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "设备控制",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "iconname": "icon-a_power",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "百分比控制",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "iconname": "icon-icon-percent",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "cur_calibration",
                "name": "行程校准",
                "property": {"range": ["start", "end"], "type": "enum"},
                "iconname": "icon-dp_loop",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "switch_backlight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "cdm9acyiqmpuzfyl": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "hvg8mueqejd87zz3": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent1"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "countdown1"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "bwht23eja1qscbku": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "gu4vs8axzlw5ptw3": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 5,
                    "max": 700,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 900,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {
                    "range": ["Manual", "Program", "Holiday", "TempProg"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ChildLock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["1", "2", "3", "4", "5"],
                    "type": "bitmap",
                    "maxlen": 5,
                },
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "C_F",
                "name": "华氏度摄氏度",
                "property": {"type": "bool"},
                "iconname": "icon-a_function_fahrenhei",
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Heating_state",
                "name": "加热",
                "property": {"type": "bool"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Ext_temperature",
                "name": "外置温度",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 900,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Days_Holiday",
                "name": "离家模式-天数",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-p7",
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Settemp_Holiday",
                "name": "离家模式-设置温度",
                "property": {
                    "unit": "",
                    "min": 5,
                    "max": 122,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Hightemp_Protect",
                "name": "高温保护功能",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "LowTemp_Protect",
                "name": "低温保护功能",
                "property": {"type": "bool"},
                "id": 107,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "ext_temp_display",
                "name": "外置温度显示功能",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "room_temp_compensate",
                "name": "温度补偿",
                "property": {
                    "unit": "",
                    "min": -180,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-ziyouchengxu",
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "room_temp_zone",
                "name": "室内温度回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 180,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ext_temp_zone",
                "name": "外置温度回差",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 18,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "high_temp_limit",
                "name": "高温保护温度",
                "property": {
                    "unit": "",
                    "min": 20,
                    "max": 70,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 112,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "low_temp_limit",
                "name": "低温保护温度",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 113,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "set_temp_max",
                "name": "设置温度最高上限",
                "property": {
                    "unit": "℃",
                    "min": 20,
                    "max": 70,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "set_temp_min",
                "name": "设置温度最低下限",
                "property": {
                    "unit": "℃",
                    "min": 1,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 115,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_sensor_type",
                "name": "传感器类型",
                "property": {"range": ["in", "ext", "all"], "type": "enum"},
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "power_state",
                "name": "上电开关机状态",
                "property": {"range": ["keep", "off", "on"], "type": "enum"},
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Prog_Type",
                "name": "编程类型",
                "property": {"range": ["2days", "1days", "0days"], "type": "enum"},
                "id": 118,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday1",
                "name": "编程-工作日参数1",
                "id": 119,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "Prog_Workday2",
                "name": "编程-工作日参数2",
                "id": 120,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday1",
                "name": "编程-休息日参数1",
                "id": 121,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "Prog_Restday2",
                "name": "编程-休息日参数2",
                "id": 122,
                "type": "raw",
            },
        ],
    },
    "feuxr1kzudmfpigo": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "omikaosjrcobyms5": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-a_nav_function",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-taiyang",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "ifjsnis9w47caamw": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-a_nav_function",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-taiyang",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "2d9cr59gcncoocar": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "kel2azofc71sluhw": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "5qgTY0iW2rHUe61k": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "目标温度",
                "property": {
                    "unit": "°C",
                    "min": 0,
                    "max": 37,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "°C",
                    "min": -20,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "eco",
                "name": "ECO模式",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["fault1", "fault2", "fault3"],
                    "type": "bitmap",
                    "maxlen": 3,
                },
                "id": 13,
                "type": "obj",
            },
        ],
    },
    "zWpmiNWIMKJNHOUq": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "status",
                "name": "开关状态",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
                "desc": "1:正在开启中，2:正在关闭中，3:停止",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "模式",
                "property": {"range": ["01", "02", "03"], "type": "enum"},
                "id": 101,
                "type": "obj",
                "desc": "开始／暂停／关闭",
            },
        ],
    },
    "jubomtsieown5u1z": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "id": 27,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "itdnurelstpzdgpd": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "pir_state",
                "name": "人体感应状态",
                "property": {"range": ["pir"], "type": "enum"},
                "iconname": "icon-yundong",
                "id": 1,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
            },
        ],
    },
    "rviyyhbek17aamye": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 6, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-a_nav_fan",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "fan_speed",
                "name": "风速",
                "property": {"range": ["1", "2", "3", "4", "5"], "type": "enum"},
                "iconname": "icon-fengli",
                "id": 3,
                "type": "obj",
                "desc": "可根据实际档位需求扩展",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6"],
                    "type": "enum",
                },
                "iconname": "icon-dp_time2",
                "id": 6,
                "type": "obj",
                "desc": "0：取消\n1：1小时\n2：2小时\n.....",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "baf9tt9lb8t5uc7z": {
        "schemaExt": [
            {"complexType": "plain", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "plain", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "percent1"},
            {
                "complexType": "",
                "id": 2,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 3, "inputStyle": "temp", "inputType": "percent"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "remote_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "4zxd7cwb6oj8rttv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_4",
                "name": "开关4",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_4",
                "name": "开关4倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 12,
                "type": "obj",
            },
        ],
    },
    "ily6yaiza2eytgnc": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 38, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "id": 38,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯模式",
                "property": {"range": ["relay", "pos", "none"], "type": "enum"},
                "id": 40,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "id": 41,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 42,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 43,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "id": 44,
                "type": "obj",
            },
        ],
    },
    "j0zozzoarutv0nu1": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 38, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 46, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kW·h",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 80000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "min": 0,
                    "max": 100000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "min": 0,
                    "max": 100000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "故障上报",
                "property": {
                    "label": ["ov_cr", "ov_vol", "ov_pwr", "ls_cr", "ls_vol", "ls_pow"],
                    "type": "bitmap",
                    "maxlen": 6,
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "id": 38,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 41,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 42,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_overcharge",
                "name": "过充保护",
                "property": {"type": "bool"},
                "id": 46,
                "type": "obj",
            },
        ],
    },
    "ven08ot7x16qxbty": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "iconname": "icon-dp_box",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯模式",
                "property": {"range": ["relay", "pos", "none"], "type": "enum"},
                "iconname": "icon-dp_box2",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_backlight",
                "name": "背光开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_loop",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_nav_mode",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-power",
                "id": 19,
                "type": "obj",
            },
        ],
    },
    "b25mh8sxawsgndck": {
        "schemaExt": "[]",
        "schema": [
            {"mode": "ro", "code": "upward", "name": "上行通道", "id": 101, "type": "raw"},
            {"mode": "wr", "code": "down", "name": "下行通道", "id": 102, "type": "raw"},
        ],
    },
    "kdi2o9m6": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 9,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
            {"complexType": "", "id": 27, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 28, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯状态设置",
                "property": {"range": ["none", "relay"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "nalfcwjtrlpdi6my": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "lieerjyy6l4ykjor": {
        "schemaExt": "[]",
        "schema": [
            {"mode": "ro", "code": "upward", "name": "上行通道", "id": 101, "type": "raw"},
            {"mode": "wr", "code": "down", "name": "下行通道", "id": 102, "type": "raw"},
        ],
    },
    "4uda5q41rx27vwq8": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value_1",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 2,
                "type": "obj",
            },
        ],
    },
    "gswrpjab2vfawful": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
                "desc": "",
            },
        ],
    },
    "y4jnobxh": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            }
        ],
    },
    "s8gkrkxk": {
        "schemaExt": [
            {
                "complexType": "",
                "id": 3,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {
                "complexType": "",
                "id": 7,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 7,
                "type": "obj",
            },
        ],
    },
    "5pjaupbqpdk7uxhf": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "toidnjcqfwlzqnlp": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "延时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "5q9r5qdi1ledkucx": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "power_go",
                "name": "清扫开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": [
                        "standby",
                        "smart",
                        "wall_follow",
                        "spiral",
                        "chargego",
                        "random",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "direction_control",
                "name": "方向",
                "property": {
                    "range": ["foward", "backward", "turn_left", "turn_right", "stop"],
                    "type": "enum",
                },
                "iconname": "icon-dp_wind",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "status",
                "name": "工作状态",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6"],
                    "type": "enum",
                },
                "iconname": "icon-dp_dust",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_left",
                "name": "剩余电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_up",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "seek",
                "name": "寻找机器",
                "property": {"type": "bool"},
                "iconname": "icon-dp_curve",
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "clean_record",
                "name": "清扫记录",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_direction",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "clean_area",
                "name": "清扫面积",
                "property": {
                    "unit": "㎡",
                    "min": 0,
                    "max": 9999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_voice",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "clean_time",
                "name": "清扫时间",
                "property": {
                    "unit": "分",
                    "min": 0,
                    "max": 9999,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_warming",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                        "13",
                        "14",
                        "15",
                        "16",
                        "17",
                        "18",
                    ],
                    "type": "bitmap",
                    "maxlen": 19,
                },
                "iconname": "icon-dp_time2",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "map_config",
                "name": "地图参数",
                "iconname": "icon-dp_time",
                "id": 19,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "water_sction",
                "name": "风量\\水量显示",
                "property": {"range": ["low", "nar", "high"], "type": "enum"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_unseen",
                "name": "机箱温度",
                "property": {
                    "unit": "℃",
                    "min": -30000,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "Yaw_unseen",
                "name": "航向角",
                "property": {
                    "unit": "",
                    "min": -30000,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "IIC_ERROR_unseen",
                "name": "IIC_ERROR_COUNT",
                "property": {
                    "unit": "",
                    "min": -30000,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "RobotLog_unseen",
                "name": "RobotLog",
                "property": {"type": "string", "maxlen": 255},
                "id": 105,
                "type": "obj",
            },
        ],
    },
    "nukamwgjml5yv88e": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "min": 1,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-setting",
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "iconname": "icon-setting",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "min": -20000,
                    "max": 200000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-setting",
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "decibel_switch",
                "name": "声音侦测报警开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 139,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "decibel_sensitivity",
                "name": "声音侦测灵敏度",
                "property": {"range": ["0", "1"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 140,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "decibel_upload",
                "name": "检测到声音",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 141,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 151,
                "type": "obj",
            },
        ],
    },
    "riwp3k79": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 3,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 4, "inputStyle": "temp", "inputType": "percent"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "fcdjzz3s": {
        "schemaExt": [
            {"complexType": "plain", "id": 1, "inputStyle": "", "inputType": ""}
        ],
        "schema": [
            {
                "mode": "ro",
                "code": "pir_state",
                "name": "检测到无人",
                "property": {"range": ["pir", "nopir"], "type": "enum"},
                "id": 1,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "id": 5,
                "type": "obj",
            },
        ],
    },
    "el5kt5im": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 3,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 4, "inputStyle": "temp", "inputType": "percent"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "klt8d3jvormoxgfc": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "iconname": "icon-qiangli",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "iconname": "icon-a_mode_basement",
                "id": 2,
                "type": "raw",
            },
            {
                "mode": "wr",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-tianjia",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
            },
            {
                "mode": "wr",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
            },
            {
                "mode": "wr",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
            },
        ],
    },
    "whpb9yts": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
        ],
    },
    "mTHAoDxdmZLe4tfW": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "countdown"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 4, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 5, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 6, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_on",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "sec",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 2,
                "type": "obj",
                "passive": True,
            },
            {
                "mode": "ro",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "度",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 3,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 100,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 2500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 6,
                "type": "obj",
            },
        ],
    },
    "ybibkckonoqrggin": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_tool",
                "id": 29,
                "type": "obj",
            },
        ],
    },
    "llb6ogbwtvlvtdvv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐律动",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_tool",
                "id": 29,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "rhythm_mode",
                "name": "生物节律",
                "property": {"type": "raw", "maxlen": 128},
                "iconname": "icon-dp_time3",
                "id": 30,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "sleep_mode",
                "name": "入睡计划",
                "property": {"type": "raw", "maxlen": "255"},
                "iconname": "icon-dp_sleep",
                "id": 31,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "wakeup_mode",
                "name": "唤醒计划",
                "property": {"type": "raw", "maxlen": "255"},
                "iconname": "icon-dp_sun",
                "id": 32,
                "type": "raw",
            },
        ],
    },
    "tqxfeoshql8wvfs2": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box",
                "id": 29,
                "type": "obj",
            },
        ],
    },
    "vd43bbfq": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 8, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "control",
                "name": "设备控制",
                "property": {"range": ["open", "stop", "close"], "type": "enum"},
                "iconname": "icon-a_power",
                "id": 1,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "percent_control",
                "name": "百分比控制",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 10,
                    "type": "value",
                },
                "iconname": "icon-icon-percent",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cur_calibration",
                "name": "行程校准",
                "property": {"range": ["start", "end"], "type": "enum"},
                "iconname": "icon-dp_loop",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_back",
                "name": "电机转向",
                "property": {"range": ["forward", "back"], "type": "enum"},
                "iconname": "icon-dp_loop",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "tr_timecon",
                "name": "行程时间设置",
                "property": {
                    "unit": "s",
                    "min": 1,
                    "max": 120,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "6agmomauevaw5zav": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
        ],
    },
    "nobhkdmuof1zhgle": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 14, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 15, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "设备重启状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "iconname": "icon-dp_box",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "light_mode",
                "name": "指示灯模式",
                "property": {"range": ["relay", "pos", "none"], "type": "enum"},
                "iconname": "icon-dp_box2",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_loop",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_nav_mode",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-power",
                "id": 19,
                "type": "obj",
            },
        ],
    },
    "4uf3d0ax": {
        "schemaExt": [
            {
                "complexType": "",
                "id": 9,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
            {
                "complexType": "",
                "id": 10,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
            {
                "complexType": "",
                "id": 11,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "eezg88jbmo5e4r4m": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_timer_setting",
                "name": "移动侦测定时设置",
                "property": {"type": "string", "maxlen": 255},
                "id": 114,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
            },
        ],
    },
    "30433rqaco1yfzli": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 5, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 8, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 19, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "level",
                "name": "工作模式",
                "property": {"range": ["high", "low", "wind"], "type": "enum"},
                "iconname": "icon-a_mode_turbo",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "shake",
                "name": "左右摇头",
                "property": {"type": "bool"},
                "iconname": "icon-dp_loop",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "work_state",
                "name": "工作状态",
                "property": {"range": ["on", "off"], "type": "enum"},
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_set",
                "name": "定时",
                "property": {"range": ["cancel", "2h", "4h", "8h"], "type": "enum"},
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 1440,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Up_down_shake",
                "name": "上下摇头",
                "property": {"type": "bool"},
                "iconname": "icon-zidong",
                "id": 101,
                "type": "obj",
            },
        ],
    },
    "1obwwnmq": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 3, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 9,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
            {
                "complexType": "",
                "id": 10,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
            {
                "complexType": "",
                "id": 11,
                "inputStyle": "plain",
                "inputType": "countdown",
            },
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "dbou1ap4": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 3,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 4, "inputStyle": "temp", "inputType": "percent"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "umogr7zxxujjpjgd": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_indicator",
                "name": "状态指示灯",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "画面翻转",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "时间水印",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "获取存储卡容量",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡状态",
                "property": {
                    "min": 1,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-setting",
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡格式化",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "检测到移动",
                "iconname": "icon-setting",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "ptz_stop",
                "name": "停止转动",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "格式化状态",
                "property": {
                    "min": -20000,
                    "max": 200000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-setting",
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ptz_control",
                "name": "云台转动",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
                    "type": "enum",
                },
                "iconname": "icon-setting",
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": "移动报警开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡录像开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "录像模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "iconname": "icon-setting",
                "id": 151,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_tracking",
                "name": "移动追踪开关",
                "property": {"type": "bool"},
                "iconname": "icon-setting",
                "id": 161,
                "type": "obj",
            },
        ],
    },
    "cxpvxcjm5npquvb3": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 14},
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 14},
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 44},
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "faTxEvzfxVTokBAm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene_1",
                        "scene_2",
                        "scene_3",
                        "scene_4",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_box2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_filter",
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景模式数",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_list",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_1",
                "name": "柔光模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-FanSpeed",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_2",
                "name": "缤纷模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_3",
                "name": "炫彩模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_flower",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flash_scene_4",
                "name": "斑斓模式",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-a_mode_turbo",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "flashscreen",
                "name": "新场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_house",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "lrafpuxfyw66jahl": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "bbhptoflokgp9j1s": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "喷雾开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "Light",
                "name": "灯光",
                "property": {"type": "bool"},
                "iconname": "icon-dp_light",
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["1"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-dp_warming",
                "id": 12,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "countdown_left",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "分钟",
                    "min": 0,
                    "max": 360,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "dp_mist_time",
                "name": "喷雾倒计时",
                "property": {"range": ["1h", "3h", "6h", "ON"], "type": "enum"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "dp_mist_grade",
                "name": "雾量设置",
                "property": {"range": ["small", "big"], "type": "enum"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光模式数",
                "property": {"type": "string", "maxlen": 255},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "灯光模式",
                "property": {
                    "range": [
                        "white",
                        "colour",
                        "scene",
                        "scene1",
                        "scene2",
                        "scene3",
                        "scene4",
                    ],
                    "type": "enum",
                },
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "lightmode",
                "name": "灯光模式",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 110,
                "type": "obj",
            },
        ],
    },
    "zeogfyu0hadzxdyc": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "c88teujp": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "window_check",
                "name": "开窗检测",
                "property": {"type": "bool"},
                "iconname": "icon-dp_shake",
                "id": 8,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "frost",
                "name": "防霜冻功能",
                "property": {"type": "bool"},
                "iconname": "icon-chushuang",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_correction",
                "name": "温度校准",
                "property": {
                    "unit": "",
                    "min": -6,
                    "max": 6,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-wendu1",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_lock",
                "id": 40,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "current_temp",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 700,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "set_temp",
                "name": "设定温度",
                "property": {
                    "unit": "℃",
                    "min": 50,
                    "max": 300,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "motor_opening",
                "name": "加热时间",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_power",
                "scope": "fault",
                "name": "电池电量报警",
                "property": {"label": ["bit0"], "type": "bitmap", "maxlen": 1},
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "a_key_home",
                "name": "离家",
                "property": {"type": "bool"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "prog_mode",
                "name": "编程模式",
                "id": 107,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_switch",
                "name": "编程开关",
                "property": {"type": "bool"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "prog_data",
                "name": "编程数据（作废，先别删）",
                "id": 109,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_day_set",
                "name": "历史数据协议（日-设定温度）",
                "id": 110,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "system_time",
                "name": "系统时间同步",
                "id": 111,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_week_set",
                "name": "历史数据协议（周-设定温度）",
                "id": 112,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_month_set",
                "name": "历史数据协议（月-设定温度）",
                "id": 113,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_year_set",
                "name": "历史数据协议（年-设定温度）",
                "id": 114,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_day_now",
                "name": "历史数据协议（日-当前温度）",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_week_now",
                "name": "历史数据协议（周-当前温度）",
                "id": 116,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_month_now",
                "name": "历史数据协议（月-当前温度）",
                "id": 117,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_year_now",
                "name": "历史数据协议（年-当前温度）",
                "id": 118,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_day_pow",
                "name": "历史数据协议（日-电机开度）",
                "id": 119,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_week_pow",
                "name": "历史数据协议（周-电机开度）",
                "id": 120,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_month_pow",
                "name": "历史数据协议（月-电机开度）",
                "id": 121,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "historical_year_pow",
                "name": "历史数据协议（年-电机开度）",
                "id": 122,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_1",
                "name": "编程数据（周一）",
                "id": 123,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_2",
                "name": "编程数据（周二）",
                "id": 124,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_3",
                "name": "编程数据（周三）",
                "id": 125,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_4",
                "name": "编程数据（周四）",
                "id": 126,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_5",
                "name": "编程数据（周五）",
                "id": 127,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_6",
                "name": "编程数据（周六）",
                "id": 128,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "prog_data_7",
                "name": "编程数据（周日）",
                "id": 129,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "water_sca",
                "name": "防水垢",
                "property": {"type": "bool"},
                "id": 130,
                "type": "obj",
            },
        ],
    },
    "49qchf10": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 2, "inputStyle": "", "inputType": ""},
            {
                "complexType": "",
                "id": 3,
                "inputStyle": "bright",
                "inputType": "percent1",
            },
            {"complexType": "", "id": 4, "inputStyle": "temp", "inputType": "percent"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 43200,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "8wq8cNNPt1bbXgYC": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "position",
                "name": "窗帘位置",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_loop",
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mach_operate",
                "name": "电机操作",
                "property": {"range": ["ZZ", "FZ", "STOP"], "type": "enum"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "opposite",
                "name": "反向",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
        ],
    },
    "qq682bmeu0blilwj": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 7, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 7,
                "type": "obj",
            },
        ],
    },
    "rM6YG2U2W0QF88YM": {
        "schemaExt": [
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 10, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 11, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_3",
                "name": "开关3",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_3",
                "name": "开关3倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 11,
                "type": "obj",
            },
        ],
    },
    "nsejtoyyazhxtxx8": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 38, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 39, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 44, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-tongji2",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 38,
                "type": "obj",
            },
        ],
    },
    "1oritrbfwyxuuwp5": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "Movement Detect",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "doorbell_active",
                "name": "门铃-呼叫",
                "property": {"type": "string", "maxlen": 255},
                "id": 136,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "wireless_electricity",
                "name": "低功耗-电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 145,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "wireless_powermode",
                "name": "低功耗-供电方式",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 146,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "wireless_lowpower",
                "name": "低功耗-低电报警",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 50,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 147,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "wireless_awake",
                "name": "低功耗-唤醒状态",
                "property": {"type": "bool"},
                "id": 149,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "pir_switch",
                "name": "PIR-Switch",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 152,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "doorbell_pic",
                "name": "Door Bell Ring",
                "id": 154,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "cus_alarm",
                "name": " 有人尝试拆除设备",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 231,
                "type": "obj",
            },
        ],
    },
    "63s9mjrkzs6ejl1w": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_direction",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-gaodiyin",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "1004r3jvtu4q4ofn": {
        "schemaExt": "[]",
        "schema": [
            {"mode": "ro", "code": "upward", "name": "上行通道", "id": 101, "type": "raw"},
            {"mode": "wr", "code": "down", "name": "下行通道", "id": 102, "type": "raw"},
        ],
    },
    "g9dcx8f1lhgts2bq": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "basic_flip",
                "name": "基本-录制画面翻转",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_osd",
                "name": "基本-视频osd功能",
                "property": {"type": "bool"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_sensitivity",
                "name": "移动侦测灵敏度",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "basic_nightvision",
                "name": "基本-红外夜视",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_storge",
                "name": "存储卡-获取卡容量",
                "property": {"type": "string", "maxlen": 255},
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "sd_status",
                "name": "存储卡-卡状态",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 5,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sd_format",
                "name": "存储卡-格式化",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "movement_detect_pic",
                "name": "移动侦测   ",
                "id": 115,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sd_format_state",
                "name": "存储卡-格式化状态",
                "property": {
                    "unit": "",
                    "min": -20000,
                    "max": 20000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "motion_switch",
                "name": " 移动侦测开关",
                "property": {"type": "bool"},
                "id": 134,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_switch",
                "name": "SD卡开关",
                "property": {"type": "bool"},
                "id": 150,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "record_mode",
                "name": "SD卡录像模式选择",
                "property": {"range": ["1", "2"], "type": "enum"},
                "id": 151,
                "type": "obj",
            },
        ],
    },
    "nsmxubagz8ecz5ii": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "2cw1khkiumrz0rzo": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "watersensor_state",
                "name": "水浸检测状态",
                "property": {"range": ["1", "2"], "type": "enum"},
                "iconname": "icon-a_water",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dianliang",
                "id": 4,
                "type": "obj",
            },
        ],
    },
    "vtA4pDd6PLUZzXgZ": {
        "schemaExt": [
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 102, "inputStyle": "", "inputType": ""},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": ""},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "prm_content",
                "name": "湿度",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 500,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "prm_temperature",
                "name": "温度",
                "property": {
                    "unit": "℃",
                    "min": -20,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "bsck4bhwubkpggmb": {
        "schemaExt": [
            {"complexType": "", "id": 101, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 103, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 104, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 105, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 106, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 107, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 110, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 111, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 112, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 113, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 114, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "True",
                "name": "状态",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "iconname": "icon-tcl_function_hs",
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bj",
                "name": "报警",
                "property": {"type": "bool"},
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "kg",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bjsc",
                "name": "报警时长",
                "property": {
                    "unit": "分钟",
                    "min": 1,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bjy",
                "name": "报警音",
                "property": {
                    "range": ["1", "2", "3", "4", "5", "6", "7", "8"],
                    "type": "enum",
                },
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "yl",
                "name": "音量",
                "property": {"range": ["0", "25", "50", "100"], "type": "enum"},
                "id": 107,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "xxpj",
                "name": "学习配件",
                "property": {"range": ["1", "2", "3"], "type": "enum"},
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ykqts",
                "name": "遥控器提示",
                "property": {"type": "bool"},
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cgqts",
                "name": "传感器提示",
                "property": {"type": "bool"},
                "id": 112,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cmys",
                "name": "出门延时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 600,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 113,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "hjys",
                "name": "回家延时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 600,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 114,
                "type": "obj",
            },
            {"mode": "rw", "code": "y1", "name": "遥控器", "id": 115, "type": "raw"},
            {"mode": "rw", "code": "pjts", "name": "配件推送", "id": 116, "type": "raw"},
            {"mode": "rw", "code": "c1", "name": "传感器", "id": 120, "type": "raw"},
            {"mode": "ro", "code": "pjls", "name": "配件历史记录", "id": 121, "type": "raw"},
        ],
    },
    "fjb4mpljed4mkfke": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kwh",
                    "min": 0,
                    "max": 50000,
                    "scale": 3,
                    "step": 100,
                    "type": "value",
                },
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 30000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 50000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "test_bit",
                "name": "产测结果位",
                "property": {
                    "min": 0,
                    "max": 5,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "voltage_coe",
                "name": "电压校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electric_coe",
                "name": "电流校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "power_coe",
                "name": "功率校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity_coe",
                "name": "电量校准系数",
                "property": {
                    "min": 0,
                    "max": 1000000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["ov_cr", "ov_vol", "ov_pwr", "ls_cr", "ls_vol", "ls_pow"],
                    "type": "bitmap",
                    "maxlen": 6,
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 41,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "id": 42,
                "type": "obj",
            },
        ],
    },
    "7twdxl5f0juwt0e4": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "ir_send",
                "name": "红外控制下发",
                "property": {"type": "string", "maxlen": 3072},
                "id": 201,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "ir_study_code",
                "name": "红外学习值上报",
                "id": 202,
                "type": "raw",
            },
        ],
    },
    "a6djabzmpbbp62gw": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 17, "inputStyle": "", "inputType": "plain"},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "add_ele",
                "name": "增加电量",
                "property": {
                    "unit": "kwh",
                    "min": 0,
                    "max": 999999990,
                    "scale": 3,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-battery",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_current",
                "name": "当前电流",
                "property": {
                    "unit": "mA",
                    "min": 0,
                    "max": 80000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-Ele",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_power",
                "name": "当前功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 190000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_tool",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cur_voltage",
                "name": "当前电压",
                "property": {
                    "unit": "V",
                    "min": 0,
                    "max": 5000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_function_turbo",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "name": "故障告警",
                "property": {"label": ["ov_cr"], "type": "bitmap", "maxlen": 1},
                "iconname": "icon-baojing",
                "id": 26,
                "type": "obj",
            },
        ],
    },
    "qzktzhehinzsz2je": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "wr",
                "code": "control",
                "name": "控制命令",
                "property": {
                    "range": ["send_ir", "study", "study_exit", "study_key"],
                    "type": "enum",
                },
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "study_code",
                "name": "学习编码",
                "id": 2,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "ir_code",
                "name": "红外编码",
                "property": {"type": "string", "maxlen": 255},
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "key_code",
                "name": "码库按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "key_code2",
                "name": "码库按键参数2",
                "property": {"type": "string", "maxlen": 255},
                "id": 5,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "key_code3",
                "name": "码库按键参数3",
                "property": {"type": "string", "maxlen": 255},
                "id": 6,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "key_study",
                "name": "来自学习参数下发",
                "id": 7,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "key_study2",
                "name": "来自学习参数下发2",
                "id": 8,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "key_study3",
                "name": "来自学习参数下发3",
                "id": 9,
                "type": "raw",
            },
            {
                "mode": "wr",
                "code": "delay_time",
                "name": "红外码发送延时",
                "property": {
                    "unit": "ms",
                    "min": 0,
                    "max": 65535,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_code4",
                "name": "新按键参数",
                "property": {"type": "string", "maxlen": 255},
                "id": 11,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "key_study4",
                "name": "新学习参数",
                "id": 12,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "type",
                "name": "码库标识",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 13,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "switch_power",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "模式",
                "property": {"range": ["0", "1", "2", "3", "4"], "type": "enum"},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "temperature",
                "name": "温度",
                "property": {
                    "unit": "",
                    "min": 16,
                    "max": 30,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "fan",
                "name": "风量",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "swing",
                "name": "摆风",
                "property": {"type": "bool"},
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ir_send",
                "name": "红外控制下发",
                "property": {"type": "string", "maxlen": 3072},
                "id": 201,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "ir_study_code",
                "name": "红外学习值上报",
                "id": 202,
                "type": "raw",
            },
        ],
    },
    "riuj5xzs": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "prm_content",
                "name": "湿度",
                "property": {
                    "unit": "% RH",
                    "min": 0,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 101,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery",
                "name": "电池电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 220,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 102,
                "trigger": "direct",
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "prm_temperature",
                "name": "温度",
                "property": {
                    "unit": "℃",
                    "min": -2000,
                    "max": 10000,
                    "scale": 2,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "9fhsrjFBVdKGKFvA": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "open_close_stop",
                "name": "开关停窗帘",
                "property": {"range": ["open", "close", "stop"], "type": "enum"},
                "id": 101,
                "type": "obj",
            }
        ],
    },
    "rrkgmc7lgadir7hc": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_power",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "jeaxp72v": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "temp_set",
                "name": "目标温度",
                "property": {
                    "unit": "°C",
                    "min": 50,
                    "max": 300,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "iconname": "icon-set",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temp_current",
                "name": "当前温度",
                "property": {
                    "unit": "°C",
                    "min": 0,
                    "max": 500,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-fangzi",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "工作模式",
                "property": {
                    "range": ["freeze", "auto", "manual", "install"],
                    "type": "enum",
                },
                "iconname": "icon-fangzi1",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-guanjia",
                "id": 7,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "window_state",
                "name": "窗户状态",
                "property": {"range": ["open", "close"], "type": "enum"},
                "iconname": "icon-a_function_hs",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "window_check",
                "name": "窗户检测开关",
                "property": {"type": "bool"},
                "iconname": "icon-baifeng1",
                "id": 18,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "valve_state",
                "name": "阀门状态",
                "property": {"range": ["open", "close"], "type": "enum"},
                "iconname": "icon-icon-test10",
                "id": 19,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "valve_check",
                "name": "阀门检测开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_down1",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-chongnai",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cloud_temp",
                "name": "云定时温度设置",
                "property": {
                    "unit": "",
                    "min": 50,
                    "max": 300,
                    "scale": 1,
                    "step": 5,
                    "type": "value",
                },
                "id": 102,
                "type": "obj",
            },
        ],
    },
    "jg1vvqb7bp8pzvht": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "watersensor_state",
                "name": "水浸检测状态",
                "property": {"range": ["alarm", "normal"], "type": "enum"},
                "iconname": "icon-a_water",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
            },
        ],
    },
    "jnsi4cycuuij2z1q": {
        "schemaExt": "[]",
        "schema": [
            {"mode": "ro", "code": "upward", "name": "上行通道", "id": 101, "type": "raw"},
            {"mode": "wr", "code": "down", "name": "下行通道", "id": 102, "type": "raw"},
        ],
    },
    "muushnich7dcbbxi": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music", "wakeup"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "rfec5nw012yeqrbh": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "uukoy7legkbonvns": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "master_mode",
                "name": "主机模式",
                "property": {
                    "range": ["disarmed", "arm", "home", "sos"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "delay_set",
                "name": "退出延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-zanting1",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_time",
                "name": "报警时长",
                "property": {
                    "unit": "分钟",
                    "min": 1,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_sound",
                "name": "报警声开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "iconname": "icon-dp_tool",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "charge_state",
                "name": "主电源状态",
                "property": {"type": "bool"},
                "iconname": "icon-power1",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_battery",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_low_battery",
                "name": "探测器低电量报警",
                "property": {"type": "bool"},
                "iconname": "icon-dianliang",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_call_number",
                "name": "报警电话号码",
                "id": 18,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "alarm_sms_number",
                "name": "报警短信号码",
                "id": 19,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_call",
                "name": "报警电话",
                "property": {"type": "bool"},
                "iconname": "icon-guanjia",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_sms",
                "name": "报警短信",
                "property": {"type": "bool"},
                "iconname": "icon-dp_doc2",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "call_looptimes",
                "name": "未接听重复拨打次数",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 10,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-p12",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "telnet_state",
                "name": "电话网络状态",
                "property": {"range": ["1", "2", "3", "4"], "type": "enum"},
                "iconname": "icon-fengli",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "zone_attribute",
                "name": "防区属性",
                "property": {
                    "range": [
                        "Normal",
                        "24Hours",
                        "Delay",
                        "Home",
                        "24HoursMute",
                        "HomeDelay",
                        "Off",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-a_fan_auto",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "iconname": "icon-Mute",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_msg",
                "name": "告警信息",
                "id": 26,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_propel",
                "name": "告警推送",
                "property": {"type": "bool"},
                "iconname": "icon-dp_chat",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_delay_time",
                "name": "进入延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_dl_sound",
                "name": "倒计时提示音",
                "property": {"type": "bool"},
                "iconname": "icon-dp_time",
                "id": 29,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_state",
                "name": "主机状态",
                "property": {"range": ["normal", "alarm"], "type": "enum"},
                "iconname": "icon-dp_shield",
                "id": 32,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "master_information",
                "name": "主机信息",
                "id": 33,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "iconname": "icon-dp_anti-clockwise",
                "id": 34,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_add",
                "name": "添加子设备",
                "property": {"type": "bool"},
                "iconname": "icon-dp_plus",
                "id": 35,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_class",
                "name": "子设备品类",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 36,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_type",
                "name": "子设备类别",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 37,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_admin",
                "name": "子设备管理",
                "id": 38,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sub_state",
                "name": "子设备状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-shoucang",
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_language",
                "name": "主机语言",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_doc",
                "id": 40,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "notification_msg",
                "name": "通知信息",
                "id": 101,
                "type": "raw",
            },
        ],
    },
    "livkeaqwethpf8gu": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "iconname": "icon-dp_battery",
                "id": 38,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_remote",
                "name": "遥控器开关",
                "property": {"type": "bool"},
                "id": 45,
                "type": "obj",
            },
        ],
    },
    "h3dxaxyttimidvb6": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["0", "1", "2"], "type": "enum"},
                "iconname": "icon-zhuangtai",
                "id": 38,
                "type": "obj",
            },
        ],
    },
    "vlwssw0gz9idp5ip": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 23, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 34, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 39, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "music_data",
                "name": "音乐律动",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "debug_data",
                "name": "调试",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_tool",
                "id": 29,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "rhythm_mode",
                "name": "生物节律",
                "property": {"type": "raw", "maxlen": 128},
                "iconname": "icon-dp_time3",
                "id": 30,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "sleep_mode",
                "name": "入睡计划",
                "property": {"type": "raw", "maxlen": "255"},
                "iconname": "icon-dp_sleep",
                "id": 31,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "wakeup_mode",
                "name": "唤醒计划",
                "property": {"type": "raw", "maxlen": "255"},
                "iconname": "icon-dp_sun",
                "id": 32,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "power_memory",
                "name": "断电记忆",
                "property": {"type": "raw", "maxlen": "255"},
                "iconname": "icon-dp_lightning",
                "id": 33,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "do_not_disturb",
                "name": "通电勿扰",
                "property": {"type": "bool"},
                "iconname": "icon-dp_sleep",
                "id": 34,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_power",
                "name": "替代功率",
                "property": {
                    "unit": "W",
                    "min": 0,
                    "max": 5000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 39,
                "type": "obj",
            },
        ],
    },
    "xja97vhr9m34u7fd": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "led_switch",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 25,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_light2",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 255,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_mode_heat",
                "id": 4,
                "type": "obj",
            },
        ],
    },
    "0s283bsace15fdyv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "冷暖值",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "gaqwaxdc7kxq2mci": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power3",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time3",
                "id": 9,
                "type": "obj",
            },
        ],
    },
    "eqawocgihdayi3af": {
        "schemaExt": [
            {"complexType": "", "id": 20, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 21, "inputStyle": "", "inputType": "plain"},
            {"complexType": "", "id": 22, "inputStyle": "", "inputType": "percent"},
            {"complexType": "", "id": 26, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "jorlvalcdf5lz6qa": {
        "schemaExt": [
            {"complexType": "", "id": 1, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 9, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 38, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 40, "inputStyle": "", "inputType": " "},
            {"complexType": "", "id": 41, "inputStyle": "", "inputType": " "},
        ],
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "relay_status",
                "name": "上电状态设置",
                "property": {"range": ["off", "on", "memory"], "type": "enum"},
                "iconname": "icon-dp_battery",
                "id": 38,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "child_lock",
                "name": "童锁",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 41,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cycle_time",
                "name": "循环定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_loop",
                "id": 42,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "random_time",
                "name": "随机定时",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_circle",
                "id": 43,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_inching",
                "name": "点动开关",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_circle",
                "id": 44,
                "type": "obj",
            },
        ],
    },
    "zdfukzob6j9n2lqv": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "ro",
                "code": "pir_state",
                "name": "人体感应状态",
                "property": {"range": ["pir"], "type": "enum"},
                "iconname": "icon-yundong",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_state",
                "name": "电池电量状态",
                "property": {"range": ["low", "middle", "high"], "type": "enum"},
                "iconname": "icon-dianliang",
                "id": 3,
                "type": "obj",
            },
        ],
    },
    "mpwzeznnzehynwds": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_powe",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "白光亮度",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "temp_value",
                "name": "白光色温",
                "property": {
                    "min": 0,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_half",
                "id": 23,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光颜色",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "情景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-shoucang",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music_data",
                "name": "音乐灯",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_mic",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "ds0wzlm6yvp8b9rm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["white", "colour", "scene", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_light",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_data",
                "name": "场景",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown",
                "name": "倒计时剩余时间",
                "property": {
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 26,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-setting",
                "id": 28,
                "type": "obj",
            },
        ],
    },
    "mwsduy02h7s7gljf": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "master_mode",
                "name": "主机模式",
                "property": {
                    "range": ["disarmed", "arm", "home", "sos"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "delay_set",
                "name": "退出延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-zanting1",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_time",
                "name": "报警时长",
                "property": {
                    "unit": "分钟",
                    "min": 1,
                    "max": 60,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-a_nav_timer",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_sound",
                "name": "报警声开关",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "temper_alarm",
                "name": "防拆报警",
                "property": {"type": "bool"},
                "iconname": "icon-dp_tool",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_sound",
                "name": "布撤防提示音",
                "property": {"type": "bool"},
                "iconname": "icon-power",
                "id": 10,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "charge_state",
                "name": "主电源状态",
                "property": {"type": "bool"},
                "iconname": "icon-power1",
                "id": 15,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "battery_percentage",
                "name": "电池电量",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_battery",
                "id": 16,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_low_battery",
                "name": "探测器低电量报警",
                "property": {"type": "bool"},
                "iconname": "icon-dianliang",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "zone_attribute",
                "name": "防区属性",
                "property": {
                    "range": [
                        "Normal",
                        "24Hours",
                        "Delay",
                        "Home",
                        "24HoursMute",
                        "HomeDelay",
                        "Off",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-a_fan_auto",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "muffling",
                "name": "消音",
                "property": {"type": "bool"},
                "iconname": "icon-Mute",
                "id": 25,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_msg",
                "name": "告警信息",
                "id": 26,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "switch_alarm_propel",
                "name": "告警推送",
                "property": {"type": "bool"},
                "iconname": "icon-dp_chat",
                "id": 27,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "alarm_delay_time",
                "name": "进入延时",
                "property": {
                    "unit": "秒",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-timer1",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_mode_dl_sound",
                "name": "倒计时提示音",
                "property": {"type": "bool"},
                "iconname": "icon-dp_time",
                "id": 29,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_state",
                "name": "主机状态",
                "property": {"range": ["normal", "alarm"], "type": "enum"},
                "iconname": "icon-dp_shield",
                "id": 32,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "master_information",
                "name": "主机信息",
                "id": 33,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂设置",
                "property": {"type": "bool"},
                "iconname": "icon-dp_anti-clockwise",
                "id": 34,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_add",
                "name": "添加子设备",
                "property": {"type": "bool"},
                "iconname": "icon-dp_plus",
                "id": 35,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_class",
                "name": "子设备品类",
                "property": {"range": ["0", "1"], "type": "enum"},
                "iconname": "icon-dp_direction",
                "id": 36,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_type",
                "name": "子设备类别",
                "property": {
                    "range": [
                        "0",
                        "1",
                        "2",
                        "3",
                        "4",
                        "5",
                        "6",
                        "7",
                        "8",
                        "9",
                        "10",
                        "11",
                        "12",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-dp_list",
                "id": 37,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sub_admin",
                "name": "子设备管理",
                "id": 38,
                "type": "raw",
            },
            {
                "mode": "ro",
                "code": "sub_state",
                "name": "子设备状态",
                "property": {"range": ["0", "1", "2", "3"], "type": "enum"},
                "iconname": "icon-shoucang",
                "id": 39,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "master_language",
                "name": "主机语言",
                "property": {
                    "range": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
                    "type": "enum",
                },
                "iconname": "icon-dp_doc",
                "id": 40,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "notification_msg",
                "name": "通知信息",
                "id": 101,
                "type": "raw",
            },
        ],
    },
    "i6hyjg3af7doaswm": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "电源开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cleanarea",
                "name": "清洁面积",
                "property": {
                    "unit": "㎡",
                    "min": 0,
                    "max": 10000,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_house",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": [
                        "FAULT_CLIFF",
                        "FAULT_IMP",
                        "FAULT_WHL",
                        "FAULT_BRUSH",
                        "FAULT_FAN",
                        "FAULT_ROLLBRUSH",
                        "FAULT_LOWPOWER",
                        "FAULT_GIVEUP",
                        "FAULT_NODUST",
                        "FAULT_NONE",
                    ],
                    "type": "bitmap",
                    "maxlen": 10,
                },
                "iconname": "icon-dp_warming",
                "id": 17,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "workstatus",
                "name": "工作状态",
                "property": {
                    "range": [
                        "SLEEP",
                        "HALTING",
                        "CLEANING",
                        "CLEAN_COMP",
                        "FIND_STA",
                        "CHARGING_STA",
                        "CHARGING_DC",
                        "CHARG_COMP",
                    ],
                    "type": "enum",
                },
                "id": 101,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "cleanmode",
                "name": "清扫模式",
                "property": {
                    "range": [
                        "clean_auto",
                        "clean_random",
                        "clean_wall",
                        "clean_spot",
                        "clean_sroom",
                        "find_sta",
                        "null",
                    ],
                    "type": "enum",
                },
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "fanstatus",
                "name": "风力调节",
                "property": {
                    "range": ["FANHALTING", "FANNORAM", "FANMAX"],
                    "type": "enum",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "movedirect",
                "name": "方向控制",
                "property": {
                    "range": [
                        "MoveForward",
                        "MoveBackward",
                        "MoveLeft",
                        "MoveRight",
                        "stop",
                    ],
                    "type": "enum",
                },
                "id": 105,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "cleantime",
                "name": "时间",
                "property": {
                    "unit": "min",
                    "min": 0,
                    "max": 300,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 107,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "electricity",
                "name": "剩余电量",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 100,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 108,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "MaterialLife_Brush",
                "name": "耗材计时(边刷)",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 109,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "MaterialLife_Rollbru",
                "name": "耗材计时(滚刷)",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 110,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "MaterialLife_HEPA",
                "name": "耗材计时(滤网)",
                "property": {
                    "unit": "%",
                    "min": 0,
                    "max": 100,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 111,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "CleanSwtich",
                "name": "启动/暂停",
                "property": {"range": ["0", "1"], "type": "enum"},
                "id": 112,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "ResetBrush",
                "name": "复位耗材（边刷）剩余时间？",
                "property": {"type": "bool"},
                "id": 113,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "ResetRollbrush",
                "name": "复位耗材（滚刷）剩余时间？",
                "property": {"type": "bool"},
                "id": 114,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "ResetHepa",
                "name": "复位耗材（滤网）剩余时间？",
                "property": {"type": "bool"},
                "id": 115,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "FindRobot",
                "name": "寻回扫地机",
                "property": {"type": "bool"},
                "id": 116,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "unused",
                "name": "无效",
                "property": {
                    "range": [
                        "clean_auto",
                        "clean_random",
                        "clean_wall",
                        "clean_spot",
                        "clean_sroom",
                        "find_sta",
                    ],
                    "type": "enum",
                },
                "id": 117,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "RobotModel",
                "name": "设备型号",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 999999999,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 118,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "DataSample",
                "name": "数据采集",
                "property": {
                    "unit": "",
                    "min": 0,
                    "max": 999999999,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 119,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "g_waterlevel",
                "name": "水量调节",
                "property": {
                    "range": ["water_small", "water_auto", "water_big"],
                    "type": "enum",
                },
                "id": 120,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "sn",
                "name": "SN",
                "property": {"type": "string", "maxlen": 255},
                "id": 130,
                "type": "obj",
            },
        ],
    },
    "vrtzqkyie5fvpkgo": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "meal_plan",
                "name": "喂食计划",
                "iconname": "icon-dp_time3",
                "id": 1,
                "type": "raw",
            },
            {
                "mode": "rw",
                "code": "manual_feed",
                "name": "手动喂食",
                "property": {
                    "min": 1,
                    "max": 12,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-icon-test13",
                "id": 3,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "feed_state",
                "name": "喂食状态",
                "property": {
                    "range": [
                        "standby",
                        "no_food",
                        "error_ir",
                        "feed_timeout",
                        "feeding",
                    ],
                    "type": "enum",
                },
                "iconname": "icon-zhuangtai",
                "id": 4,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "factory_reset",
                "name": "恢复出厂",
                "property": {"type": "bool"},
                "iconname": "icon-a_nav_mode",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "fault",
                "scope": "fault",
                "name": "故障告警",
                "property": {
                    "label": ["no_food", "error_ir", "feed_timeout", "battery_low"],
                    "type": "bitmap",
                    "maxlen": 4,
                },
                "iconname": "icon-dp_notice",
                "id": 14,
                "type": "obj",
            },
            {
                "mode": "ro",
                "code": "feed_report",
                "name": "喂食结果上报",
                "property": {
                    "min": 0,
                    "max": 12,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "id": 15,
                "trigger": "direct",
                "type": "obj",
            },
        ],
    },
    "65ng6s5uyiiczyc0": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_led",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power",
                "id": 20,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "work_mode",
                "name": "模式",
                "property": {
                    "range": ["color", "dynamic_mod", "scene_mod", "music"],
                    "type": "enum",
                },
                "iconname": "icon-dp_mode",
                "id": 21,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "bright_value",
                "name": "亮度值",
                "property": {
                    "min": 10,
                    "max": 1000,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-liangdu1",
                "id": 22,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "colour_data",
                "name": "彩光",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-yanse",
                "id": 24,
                "type": "obj",
            },
            {
                "mode": "wr",
                "code": "control_data",
                "name": "调节",
                "property": {"type": "string", "maxlen": 255},
                "iconname": "icon-dp_box2",
                "id": 28,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "music",
                "name": "音乐模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 102,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "RGB_order",
                "name": "线序调整",
                "property": {
                    "unit": "",
                    "min": 1,
                    "max": 6,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 103,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "LED_QTY",
                "name": "灯带点数",
                "property": {
                    "unit": "",
                    "min": 10,
                    "max": 200,
                    "scale": 1,
                    "step": 1,
                    "type": "value",
                },
                "id": 104,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "dynamic_mod",
                "name": "灯带模式",
                "property": {"type": "string", "maxlen": 255},
                "id": 106,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "scene_mod",
                "name": "场景模式",
                "property": {
                    "range": ["CJ_YD", "CJ_QC", "CJ_WA", "CJ_XK", "CJ_JH", "CJ_YS"],
                    "type": "enum",
                },
                "id": 108,
                "type": "obj",
            },
        ],
    },
    "kzxlnxqjxoz6ak5a": {
        "schemaExt": "[]",
        "schema": [
            {
                "mode": "rw",
                "code": "switch_1",
                "name": "开关1",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "switch_2",
                "name": "开关2",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 2,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_1",
                "name": "开关1倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 9,
                "type": "obj",
            },
            {
                "mode": "rw",
                "code": "countdown_2",
                "name": "开关2倒计时",
                "property": {
                    "unit": "s",
                    "min": 0,
                    "max": 86400,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_time2",
                "id": 10,
                "type": "obj",
            },
        ],
    },
    "QgDtdkPRBJ9g360K": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 10,
                    "max": 49,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {"range": ["1", "2", "off"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Shake",
                "name": "摇头",
                "property": {"type": "bool"},
                "iconname": "icon-dp_shake",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ]
    },
    "20qAGCEd0AxowwTA": {
        "schema": [
            {
                "mode": "rw",
                "code": "power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "targetTemp",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 10,
                    "max": 49,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "actualTemp",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "mode",
                "name": "模式",
                "property": {"range": ["m", "p"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "setting",
                "name": "模式",
                "property": {"range": ["off", "low", "mid", "high"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 101,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "standby_eco",
                "name": "模式",
                "property": {"type": "bool"},
                "iconname": "icon-dp_mode",
                "id": 102,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "unknown",
                "name": "模式",
                "property": {"type": "bool"},
                "iconname": "icon-dp_mode",
                "id": 12,
                "type": "obj",
                "desc": "",
            },
        ]
    },
    "ieseydavgrxw1qvp": {
        "schema": [
            {
                "mode": "rw",
                "code": "Power",
                "name": "开关",
                "property": {"type": "bool"},
                "iconname": "icon-dp_power2",
                "id": 1,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "TempSet",
                "name": "目标温度",
                "property": {
                    "unit": "℃",
                    "min": 10,
                    "max": 49,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_temp",
                "id": 2,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "ro",
                "code": "TempCurrent",
                "name": "当前温度",
                "property": {
                    "unit": "℃",
                    "min": 0,
                    "max": 50,
                    "scale": 0,
                    "step": 1,
                    "type": "value",
                },
                "iconname": "icon-dp_sun",
                "id": 3,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Mode",
                "name": "模式",
                "property": {"range": ["auto", "50_per", "100_per", "off"], "type": "enum"},
                "iconname": "icon-dp_mode",
                "id": 4,
                "type": "obj",
                "desc": "",
            },
            {
                "mode": "rw",
                "code": "Shake",
                "name": "摇头",
                "property": {"type": "bool"},
                "iconname": "icon-dp_shake",
                "id": 7,
                "type": "obj",
                "desc": "",
            },
        ]
    },
}